Class: Google::Apis::ContaineranalysisV1::BaseImage
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::BaseImage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
BaseImage describes a base image of a container image.
Instance Attribute Summary collapse
-
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
-
#name ⇒ String
The name of the base image.
-
#registry ⇒ String
The registry in which the base image is from.
-
#repository ⇒ String
The repository name in which the base image is from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BaseImage
constructor
A new instance of BaseImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BaseImage
Returns a new instance of BaseImage.
285 286 287 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
Corresponds to the JSON property layerCount
268 269 270 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 268 def layer_count @layer_count end |
#name ⇒ String
The name of the base image.
Corresponds to the JSON property name
273 274 275 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 273 def name @name end |
#registry ⇒ String
The registry in which the base image is from.
Corresponds to the JSON property registry
278 279 280 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 278 def registry @registry end |
#repository ⇒ String
The repository name in which the base image is from.
Corresponds to the JSON property repository
283 284 285 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 283 def repository @repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
290 291 292 293 294 295 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 290 def update!(**args) @layer_count = args[:layer_count] if args.key?(:layer_count) @name = args[:name] if args.key?(:name) @registry = args[:registry] if args.key?(:registry) @repository = args[:repository] if args.key?(:repository) end |