Class: Google::Apis::ContaineranalysisV1::BuildProvenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Provenance of a build. Contains all information needed to verify the full details about the build from source to completion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BuildProvenance

Returns a new instance of BuildProvenance.



742
743
744
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_optionsHash<String,String>

Special options applied to this build. This is a catch-all field where build providers can enter any desired additional details. Corresponds to the JSON property buildOptions

Returns:

  • (Hash<String,String>)


678
679
680
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 678

def build_options
  @build_options
end

#builder_versionString

Version string of the builder at the time this build was executed. Corresponds to the JSON property builderVersion

Returns:

  • (String)


683
684
685
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 683

def builder_version
  @builder_version
end

#built_artifactsArray<Google::Apis::ContaineranalysisV1::Artifact>

Output of the build. Corresponds to the JSON property builtArtifacts



688
689
690
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 688

def built_artifacts
  @built_artifacts
end

#commandsArray<Google::Apis::ContaineranalysisV1::Command>

Commands requested by the build. Corresponds to the JSON property commands



693
694
695
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 693

def commands
  @commands
end

#create_timeString

Time at which the build was created. Corresponds to the JSON property createTime

Returns:

  • (String)


698
699
700
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 698

def create_time
  @create_time
end

#creatorString

E-mail address of the user who initiated this build. Note that this was the user's e-mail address at the time the build was initiated; this address may not represent the same end-user for all time. Corresponds to the JSON property creator

Returns:

  • (String)


705
706
707
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 705

def creator
  @creator
end

#end_timeString

Time at which execution of the build was finished. Corresponds to the JSON property endTime

Returns:

  • (String)


710
711
712
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 710

def end_time
  @end_time
end

#idString

Required. Unique identifier of the build. Corresponds to the JSON property id

Returns:

  • (String)


715
716
717
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 715

def id
  @id
end

#logs_uriString

URI where any logs for this provenance were written. Corresponds to the JSON property logsUri

Returns:

  • (String)


720
721
722
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 720

def logs_uri
  @logs_uri
end

#project_idString

ID of the project. Corresponds to the JSON property projectId

Returns:

  • (String)


725
726
727
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 725

def project_id
  @project_id
end

#source_provenanceGoogle::Apis::ContaineranalysisV1::Source

Source describes the location of the source used for the build. Corresponds to the JSON property sourceProvenance



730
731
732
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 730

def source_provenance
  @source_provenance
end

#start_timeString

Time at which execution of the build was started. Corresponds to the JSON property startTime

Returns:

  • (String)


735
736
737
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 735

def start_time
  @start_time
end

#trigger_idString

Trigger identifier if the build was triggered automatically; empty if not. Corresponds to the JSON property triggerId

Returns:

  • (String)


740
741
742
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 740

def trigger_id
  @trigger_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 747

def update!(**args)
  @build_options = args[:build_options] if args.key?(:build_options)
  @builder_version = args[:builder_version] if args.key?(:builder_version)
  @built_artifacts = args[:built_artifacts] if args.key?(:built_artifacts)
  @commands = args[:commands] if args.key?(:commands)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @end_time = args[:end_time] if args.key?(:end_time)
  @id = args[:id] if args.key?(:id)
  @logs_uri = args[:logs_uri] if args.key?(:logs_uri)
  @project_id = args[:project_id] if args.key?(:project_id)
  @source_provenance = args[:source_provenance] if args.key?(:source_provenance)
  @start_time = args[:start_time] if args.key?(:start_time)
  @trigger_id = args[:trigger_id] if args.key?(:trigger_id)
end