Class: Google::Apis::ContaineranalysisV1::Completeness

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Indicates that the builder claims certain fields in this message to be complete.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Completeness

Returns a new instance of Completeness.



1312
1313
1314
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argumentsBoolean Also known as: arguments?

If true, the builder claims that recipe.arguments is complete, meaning that all external inputs are properly captured in the recipe. Corresponds to the JSON property arguments

Returns:

  • (Boolean)


1296
1297
1298
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1296

def arguments
  @arguments
end

#environmentBoolean Also known as: environment?

If true, the builder claims that recipe.environment is claimed to be complete. Corresponds to the JSON property environment

Returns:

  • (Boolean)


1302
1303
1304
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1302

def environment
  @environment
end

#materialsBoolean Also known as: materials?

If true, the builder claims that materials are complete, usually through some controls to prevent network access. Sometimes called "hermetic". Corresponds to the JSON property materials

Returns:

  • (Boolean)


1309
1310
1311
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1309

def materials
  @materials
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1317
1318
1319
1320
1321
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1317

def update!(**args)
  @arguments = args[:arguments] if args.key?(:arguments)
  @environment = args[:environment] if args.key?(:environment)
  @materials = args[:materials] if args.key?(:materials)
end