Class: Google::Apis::ContaineranalysisV1::ComplianceNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ComplianceNote

Returns a new instance of ComplianceNote.



1422
1423
1424
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1422

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cis_benchmarkGoogle::Apis::ContaineranalysisV1::CisBenchmark

A compliance check that is a CIS benchmark. Corresponds to the JSON property cisBenchmark



1384
1385
1386
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1384

def cis_benchmark
  @cis_benchmark
end

#descriptionString

A description about this compliance check. Corresponds to the JSON property description

Returns:

  • (String)


1389
1390
1391
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1389

def description
  @description
end

#impactString

Corresponds to the JSON property impact

Returns:

  • (String)


1394
1395
1396
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1394

def impact
  @impact
end

#rationaleString

A rationale for the existence of this compliance check. Corresponds to the JSON property rationale

Returns:

  • (String)


1399
1400
1401
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1399

def rationale
  @rationale
end

#remediationString

A description of remediation steps if the compliance check fails. Corresponds to the JSON property remediation

Returns:

  • (String)


1404
1405
1406
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1404

def remediation
  @remediation
end

#scan_instructionsString

Serialized scan instructions with a predefined format. Corresponds to the JSON property scanInstructions NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1410
1411
1412
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1410

def scan_instructions
  @scan_instructions
end

#titleString

The title that identifies this compliance check. Corresponds to the JSON property title

Returns:

  • (String)


1415
1416
1417
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1415

def title
  @title
end

#versionArray<Google::Apis::ContaineranalysisV1::ComplianceVersion>

The OS and config versions the benchmark applies to. Corresponds to the JSON property version



1420
1421
1422
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1420

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1427

def update!(**args)
  @cis_benchmark = args[:cis_benchmark] if args.key?(:cis_benchmark)
  @description = args[:description] if args.key?(:description)
  @impact = args[:impact] if args.key?(:impact)
  @rationale = args[:rationale] if args.key?(:rationale)
  @remediation = args[:remediation] if args.key?(:remediation)
  @scan_instructions = args[:scan_instructions] if args.key?(:scan_instructions)
  @title = args[:title] if args.key?(:title)
  @version = args[:version] if args.key?(:version)
end