Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Go module to upload to Artifact Registry upon successful completion of all build steps. A module refers to all dependencies in a go.mod file.
Instance Attribute Summary collapse
-
#module_path ⇒ String
Optional.
-
#module_version ⇒ String
Optional.
-
#repository_location ⇒ String
Optional.
-
#repository_name ⇒ String
Optional.
-
#repository_project_id ⇒ String
Optional.
-
#source_path ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule.
1625 1626 1627 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#module_path ⇒ String
Optional. The Go module's "module path". e.g. example.com/foo/v2
Corresponds to the JSON property modulePath
1590 1591 1592 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1590 def module_path @module_path end |
#module_version ⇒ String
Optional. The Go module's semantic version in the form vX.Y.Z. e.g. v0.1.1 Pre-
release identifiers can also be added by appending a dash and dot separated
ASCII alphanumeric characters and hyphens. e.g. v0.2.3-alpha.x.12m.5
Corresponds to the JSON property moduleVersion
1597 1598 1599 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1597 def module_version @module_version end |
#repository_location ⇒ String
Optional. Location of the Artifact Registry repository. i.e. us-east1 Defaults
to the build’s location.
Corresponds to the JSON property repositoryLocation
1603 1604 1605 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1603 def repository_location @repository_location end |
#repository_name ⇒ String
Optional. Artifact Registry repository name. Specified Go modules will be
zipped and uploaded to Artifact Registry with this location as a prefix. e.g.
my-go-repo
Corresponds to the JSON property repositoryName
1610 1611 1612 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1610 def repository_name @repository_name end |
#repository_project_id ⇒ String
Optional. Project ID of the Artifact Registry repository. Defaults to the
build project.
Corresponds to the JSON property repositoryProjectId
1616 1617 1618 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1616 def repository_project_id @repository_project_id end |
#source_path ⇒ String
Optional. Source path of the go.mod file in the build's workspace. If not
specified, this will default to the current directory. e.g. ~/code/go/
mypackage
Corresponds to the JSON property sourcePath
1623 1624 1625 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1623 def source_path @source_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1630 1631 1632 1633 1634 1635 1636 1637 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1630 def update!(**args) @module_path = args[:module_path] if args.key?(:module_path) @module_version = args[:module_version] if args.key?(:module_version) @repository_location = args[:repository_location] if args.key?(:repository_location) @repository_name = args[:repository_name] if args.key?(:repository_name) @repository_project_id = args[:repository_project_id] if args.key?(:repository_project_id) @source_path = args[:source_path] if args.key?(:source_path) end |