Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A fatal problem encountered during the execution of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo.



2225
2226
2227
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Explains the failure issue in more detail using hard-coded text. Corresponds to the JSON property detail

Returns:

  • (String)


2218
2219
2220
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2218

def detail
  @detail
end

#typeString

The name of the failure. Corresponds to the JSON property type

Returns:

  • (String)


2223
2224
2225
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2223

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2230
2231
2232
2233
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2230

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @type = args[:type] if args.key?(:type)
end