Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Location of the source in a 2nd-gen Google Cloud Build repository resource.
Instance Attribute Summary collapse
-
#dir ⇒ String
Optional.
-
#repository ⇒ String
Required.
-
#revision ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository.
2526 2527 2528 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dir ⇒ String
Optional. Directory, relative to the source root, in which to run the build.
Corresponds to the JSON property dir
2512 2513 2514 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2512 def dir @dir end |
#repository ⇒ String
Required. Name of the Google Cloud Build repository, formatted as projects/*/
locations/*/connections/*/repositories/*.
Corresponds to the JSON property repository
2518 2519 2520 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2518 def repository @repository end |
#revision ⇒ String
Required. The revision to fetch from the Git repository such as a branch, a
tag, a commit SHA, or any Git ref.
Corresponds to the JSON property revision
2524 2525 2526 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2524 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2531 2532 2533 2534 2535 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2531 def update!(**args) @dir = args[:dir] if args.key?(:dir) @repository = args[:repository] if args.key?(:repository) @revision = args[:revision] if args.key?(:revision) end |