Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Volume describes a Docker container volume which is mounted into build steps in order to persist files across build step execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Volume

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Volume.



3726
3727
3728
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the volume to mount. Volume names must be unique per build step and must be valid names for Docker volumes. Each named volume must be used by at least two build steps. Corresponds to the JSON property name

Returns:

  • (String)


3717
3718
3719
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3717

def name
  @name
end

#pathString

Path at which to mount the volume. Paths must be absolute and cannot conflict with other volume paths on the same build step or with certain reserved volume paths. Corresponds to the JSON property path

Returns:

  • (String)


3724
3725
3726
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3724

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3731
3732
3733
3734
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3731

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
end