Class: Google::Apis::ContaineranalysisV1::CvsSv3

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Common Vulnerability Scoring System version 3. For details, see https://www. first.org/cvss/specification-document

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CvsSv3

Returns a new instance of CvsSv3.



1167
1168
1169
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attack_complexityString

Corresponds to the JSON property attackComplexity

Returns:

  • (String)


1114
1115
1116
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1114

def attack_complexity
  @attack_complexity
end

#attack_vectorString

Base Metrics Represents the intrinsic characteristics of a vulnerability that are constant over time and across user environments. Corresponds to the JSON property attackVector

Returns:

  • (String)


1120
1121
1122
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1120

def attack_vector
  @attack_vector
end

#availability_impactString

Corresponds to the JSON property availabilityImpact

Returns:

  • (String)


1125
1126
1127
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1125

def availability_impact
  @availability_impact
end

#base_scoreFloat

The base score is a function of the base metric scores. Corresponds to the JSON property baseScore

Returns:

  • (Float)


1130
1131
1132
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1130

def base_score
  @base_score
end

#confidentiality_impactString

Corresponds to the JSON property confidentialityImpact

Returns:

  • (String)


1135
1136
1137
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1135

def confidentiality_impact
  @confidentiality_impact
end

#exploitability_scoreFloat

Corresponds to the JSON property exploitabilityScore

Returns:

  • (Float)


1140
1141
1142
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1140

def exploitability_score
  @exploitability_score
end

#impact_scoreFloat

Corresponds to the JSON property impactScore

Returns:

  • (Float)


1145
1146
1147
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1145

def impact_score
  @impact_score
end

#integrity_impactString

Corresponds to the JSON property integrityImpact

Returns:

  • (String)


1150
1151
1152
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1150

def integrity_impact
  @integrity_impact
end

#privileges_requiredString

Corresponds to the JSON property privilegesRequired

Returns:

  • (String)


1155
1156
1157
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1155

def privileges_required
  @privileges_required
end

#scopeString

Corresponds to the JSON property scope

Returns:

  • (String)


1160
1161
1162
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1160

def scope
  @scope
end

#user_interactionString

Corresponds to the JSON property userInteraction

Returns:

  • (String)


1165
1166
1167
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1165

def user_interaction
  @user_interaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1172

def update!(**args)
  @attack_complexity = args[:attack_complexity] if args.key?(:attack_complexity)
  @attack_vector = args[:attack_vector] if args.key?(:attack_vector)
  @availability_impact = args[:availability_impact] if args.key?(:availability_impact)
  @base_score = args[:base_score] if args.key?(:base_score)
  @confidentiality_impact = args[:confidentiality_impact] if args.key?(:confidentiality_impact)
  @exploitability_score = args[:exploitability_score] if args.key?(:exploitability_score)
  @impact_score = args[:impact_score] if args.key?(:impact_score)
  @integrity_impact = args[:integrity_impact] if args.key?(:integrity_impact)
  @privileges_required = args[:privileges_required] if args.key?(:privileges_required)
  @scope = args[:scope] if args.key?(:scope)
  @user_interaction = args[:user_interaction] if args.key?(:user_interaction)
end