Class: Google::Apis::ContaineranalysisV1::Cvss

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Cvss

Returns a new instance of Cvss.



1038
1039
1040
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attack_complexityString

Corresponds to the JSON property attackComplexity

Returns:

  • (String)


980
981
982
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 980

def attack_complexity
  @attack_complexity
end

#attack_vectorString

Base Metrics Represents the intrinsic characteristics of a vulnerability that are constant over time and across user environments. Corresponds to the JSON property attackVector

Returns:

  • (String)


986
987
988
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 986

def attack_vector
  @attack_vector
end

#authenticationString

Corresponds to the JSON property authentication

Returns:

  • (String)


991
992
993
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 991

def authentication
  @authentication
end

#availability_impactString

Corresponds to the JSON property availabilityImpact

Returns:

  • (String)


996
997
998
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 996

def availability_impact
  @availability_impact
end

#base_scoreFloat

The base score is a function of the base metric scores. Corresponds to the JSON property baseScore

Returns:

  • (Float)


1001
1002
1003
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1001

def base_score
  @base_score
end

#confidentiality_impactString

Corresponds to the JSON property confidentialityImpact

Returns:

  • (String)


1006
1007
1008
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1006

def confidentiality_impact
  @confidentiality_impact
end

#exploitability_scoreFloat

Corresponds to the JSON property exploitabilityScore

Returns:

  • (Float)


1011
1012
1013
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1011

def exploitability_score
  @exploitability_score
end

#impact_scoreFloat

Corresponds to the JSON property impactScore

Returns:

  • (Float)


1016
1017
1018
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1016

def impact_score
  @impact_score
end

#integrity_impactString

Corresponds to the JSON property integrityImpact

Returns:

  • (String)


1021
1022
1023
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1021

def integrity_impact
  @integrity_impact
end

#privileges_requiredString

Corresponds to the JSON property privilegesRequired

Returns:

  • (String)


1026
1027
1028
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1026

def privileges_required
  @privileges_required
end

#scopeString

Corresponds to the JSON property scope

Returns:

  • (String)


1031
1032
1033
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1031

def scope
  @scope
end

#user_interactionString

Corresponds to the JSON property userInteraction

Returns:

  • (String)


1036
1037
1038
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1036

def user_interaction
  @user_interaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1043

def update!(**args)
  @attack_complexity = args[:attack_complexity] if args.key?(:attack_complexity)
  @attack_vector = args[:attack_vector] if args.key?(:attack_vector)
  @authentication = args[:authentication] if args.key?(:authentication)
  @availability_impact = args[:availability_impact] if args.key?(:availability_impact)
  @base_score = args[:base_score] if args.key?(:base_score)
  @confidentiality_impact = args[:confidentiality_impact] if args.key?(:confidentiality_impact)
  @exploitability_score = args[:exploitability_score] if args.key?(:exploitability_score)
  @impact_score = args[:impact_score] if args.key?(:impact_score)
  @integrity_impact = args[:integrity_impact] if args.key?(:integrity_impact)
  @privileges_required = args[:privileges_required] if args.key?(:privileges_required)
  @scope = args[:scope] if args.key?(:scope)
  @user_interaction = args[:user_interaction] if args.key?(:user_interaction)
end