Class: Google::Apis::ContaineranalysisV1::DeploymentOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::DeploymentOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
The period during which some deployable was active in a runtime.
Instance Attribute Summary collapse
-
#address ⇒ String
Address of the runtime element hosting this deployment.
-
#config ⇒ String
Configuration used to create this deployment.
-
#deploy_time ⇒ String
Required.
-
#platform ⇒ String
Platform hosting this deployment.
-
#resource_uri ⇒ Array<String>
Output only.
-
#undeploy_time ⇒ String
End of the lifetime of this deployment.
-
#user_email ⇒ String
Identity of the user that triggered this deployment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeploymentOccurrence
constructor
A new instance of DeploymentOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeploymentOccurrence
Returns a new instance of DeploymentOccurrence.
3874 3875 3876 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Address of the runtime element hosting this deployment.
Corresponds to the JSON property address
3841 3842 3843 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3841 def address @address end |
#config ⇒ String
Configuration used to create this deployment.
Corresponds to the JSON property config
3846 3847 3848 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3846 def config @config end |
#deploy_time ⇒ String
Required. Beginning of the lifetime of this deployment.
Corresponds to the JSON property deployTime
3851 3852 3853 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3851 def deploy_time @deploy_time end |
#platform ⇒ String
Platform hosting this deployment.
Corresponds to the JSON property platform
3856 3857 3858 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3856 def platform @platform end |
#resource_uri ⇒ Array<String>
Output only. Resource URI for the artifact being deployed taken from the
deployable field with the same name.
Corresponds to the JSON property resourceUri
3862 3863 3864 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3862 def resource_uri @resource_uri end |
#undeploy_time ⇒ String
End of the lifetime of this deployment.
Corresponds to the JSON property undeployTime
3867 3868 3869 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3867 def undeploy_time @undeploy_time end |
#user_email ⇒ String
Identity of the user that triggered this deployment.
Corresponds to the JSON property userEmail
3872 3873 3874 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3872 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3879 3880 3881 3882 3883 3884 3885 3886 3887 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3879 def update!(**args) @address = args[:address] if args.key?(:address) @config = args[:config] if args.key?(:config) @deploy_time = args[:deploy_time] if args.key?(:deploy_time) @platform = args[:platform] if args.key?(:platform) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time) @user_email = args[:user_email] if args.key?(:user_email) end |