Class: Google::Apis::ContaineranalysisV1::Detail

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A detail for a distro and package affected by this vulnerability and its associated fix (if one is available).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Detail

Returns a new instance of Detail.



3969
3970
3971
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3969

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_cpe_uriString

Required. The CPE URI this vulnerability affects. Corresponds to the JSON property affectedCpeUri

Returns:

  • (String)


3893
3894
3895
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3893

def affected_cpe_uri
  @affected_cpe_uri
end

#affected_packageString

Required. The package this vulnerability affects. Corresponds to the JSON property affectedPackage

Returns:

  • (String)


3898
3899
3900
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3898

def affected_package
  @affected_package
end

#affected_version_endGoogle::Apis::ContaineranalysisV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property affectedVersionEnd



3903
3904
3905
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3903

def affected_version_end
  @affected_version_end
end

#affected_version_startGoogle::Apis::ContaineranalysisV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property affectedVersionStart



3908
3909
3910
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3908

def affected_version_start
  @affected_version_start
end

#descriptionString

A vendor-specific description of this vulnerability. Corresponds to the JSON property description

Returns:

  • (String)


3913
3914
3915
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3913

def description
  @description
end

#fixed_cpe_uriString

The distro recommended CPE URI to update to that contains a fix for this vulnerability. It is possible for this to be different from the affected_cpe_uri. Corresponds to the JSON property fixedCpeUri

Returns:

  • (String)


3920
3921
3922
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3920

def fixed_cpe_uri
  @fixed_cpe_uri
end

#fixed_packageString

The distro recommended package to update to that contains a fix for this vulnerability. It is possible for this to be different from the affected_package. Corresponds to the JSON property fixedPackage

Returns:

  • (String)


3927
3928
3929
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3927

def fixed_package
  @fixed_package
end

#fixed_versionGoogle::Apis::ContaineranalysisV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property fixedVersion



3932
3933
3934
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3932

def fixed_version
  @fixed_version
end

#is_obsoleteBoolean Also known as: is_obsolete?

Whether this detail is obsolete. Occurrences are expected not to point to obsolete details. Corresponds to the JSON property isObsolete

Returns:

  • (Boolean)


3938
3939
3940
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3938

def is_obsolete
  @is_obsolete
end

#package_typeString

The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.). Corresponds to the JSON property packageType

Returns:

  • (String)


3945
3946
3947
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3945

def package_type
  @package_type
end

#severity_nameString

The distro assigned severity of this vulnerability. Corresponds to the JSON property severityName

Returns:

  • (String)


3950
3951
3952
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3950

def severity_name
  @severity_name
end

#sourceString

The source from which the information in this Detail was obtained. Corresponds to the JSON property source

Returns:

  • (String)


3955
3956
3957
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3955

def source
  @source
end

#source_update_timeString

The time this information was last changed at the source. This is an upstream timestamp from the underlying information source - e.g. Ubuntu security tracker. Corresponds to the JSON property sourceUpdateTime

Returns:

  • (String)


3962
3963
3964
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3962

def source_update_time
  @source_update_time
end

#vendorString

The name of the vendor of the product. Corresponds to the JSON property vendor

Returns:

  • (String)


3967
3968
3969
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3967

def vendor
  @vendor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3974

def update!(**args)
  @affected_cpe_uri = args[:affected_cpe_uri] if args.key?(:affected_cpe_uri)
  @affected_package = args[:affected_package] if args.key?(:affected_package)
  @affected_version_end = args[:affected_version_end] if args.key?(:affected_version_end)
  @affected_version_start = args[:affected_version_start] if args.key?(:affected_version_start)
  @description = args[:description] if args.key?(:description)
  @fixed_cpe_uri = args[:fixed_cpe_uri] if args.key?(:fixed_cpe_uri)
  @fixed_package = args[:fixed_package] if args.key?(:fixed_package)
  @fixed_version = args[:fixed_version] if args.key?(:fixed_version)
  @is_obsolete = args[:is_obsolete] if args.key?(:is_obsolete)
  @package_type = args[:package_type] if args.key?(:package_type)
  @severity_name = args[:severity_name] if args.key?(:severity_name)
  @source = args[:source] if args.key?(:source)
  @source_update_time = args[:source_update_time] if args.key?(:source_update_time)
  @vendor = args[:vendor] if args.key?(:vendor)
end