Class: Google::Apis::ContaineranalysisV1::Distribution
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Distribution
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
This represents a particular channel of distribution for a given package. E.g., Debian's jessie-backports dpkg mirror.
Instance Attribute Summary collapse
-
#architecture ⇒ String
The CPU architecture for which packages in this distribution channel were built.
-
#cpe_uri ⇒ String
Required.
-
#description ⇒ String
The distribution channel-specific description of this package.
-
#latest_version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
-
#maintainer ⇒ String
A freeform string denoting the maintainer of this package.
-
#url ⇒ String
The distribution channel-specific homepage for this package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Distribution
constructor
A new instance of Distribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Distribution
Returns a new instance of Distribution.
4116 4117 4118 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4116 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
The CPU architecture for which packages in this distribution channel were
built.
Corresponds to the JSON property architecture
4088 4089 4090 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4088 def architecture @architecture end |
#cpe_uri ⇒ String
Required. The cpe_uri in CPE format
denoting the package manager version distributing a package.
Corresponds to the JSON property cpeUri
4094 4095 4096 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4094 def cpe_uri @cpe_uri end |
#description ⇒ String
The distribution channel-specific description of this package.
Corresponds to the JSON property description
4099 4100 4101 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4099 def description @description end |
#latest_version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property latestVersion
4104 4105 4106 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4104 def latest_version @latest_version end |
#maintainer ⇒ String
A freeform string denoting the maintainer of this package.
Corresponds to the JSON property maintainer
4109 4110 4111 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4109 def maintainer @maintainer end |
#url ⇒ String
The distribution channel-specific homepage for this package.
Corresponds to the JSON property url
4114 4115 4116 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4114 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4121 4122 4123 4124 4125 4126 4127 4128 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4121 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @description = args[:description] if args.key?(:description) @latest_version = args[:latest_version] if args.key?(:latest_version) @maintainer = args[:maintainer] if args.key?(:maintainer) @url = args[:url] if args.key?(:url) end |