Class: Google::Apis::ContaineranalysisV1::ExportSbomResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

The response from a call to ExportSBOM.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportSbomResponse

Returns a new instance of ExportSbomResponse.



4311
4312
4313
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4311

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discovery_occurrenceString

The name of the discovery occurrence in the form "projects/project_id/ occurrences/OCCURRENCE_ID It can be used to track the progress of the SBOM export. Corresponds to the JSON property discoveryOccurrence

Returns:

  • (String)


4309
4310
4311
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4309

def discovery_occurrence
  @discovery_occurrence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4316
4317
4318
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4316

def update!(**args)
  @discovery_occurrence = args[:discovery_occurrence] if args.key?(:discovery_occurrence)
end