Class: Google::Apis::ContaineranalysisV1::Fingerprint
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Fingerprint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
A set of properties that uniquely identify a given Docker image.
Instance Attribute Summary collapse
-
#v1_name ⇒ String
Required.
-
#v2_blob ⇒ Array<String>
Required.
-
#v2_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Fingerprint
constructor
A new instance of Fingerprint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Fingerprint
Returns a new instance of Fingerprint.
4511 4512 4513 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4511 def initialize(**args) update!(**args) end |
Instance Attribute Details
#v1_name ⇒ String
Required. The layer ID of the final layer in the Docker image's v1
representation.
Corresponds to the JSON property v1Name
4497 4498 4499 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4497 def v1_name @v1_name end |
#v2_blob ⇒ Array<String>
Required. The ordered list of v2 blobs that represent a given image.
Corresponds to the JSON property v2Blob
4502 4503 4504 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4502 def v2_blob @v2_blob end |
#v2_name ⇒ String
Output only. The name of the image's v2 blobs computed via: [bottom] :=
v2_blobbottom := sha256(v2_blob[N] + " " + v2_name[N+1]) Only the name of the
final blob is kept.
Corresponds to the JSON property v2Name
4509 4510 4511 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4509 def v2_name @v2_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4516 4517 4518 4519 4520 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4516 def update!(**args) @v1_name = args[:v1_name] if args.key?(:v1_name) @v2_blob = args[:v2_blob] if args.key?(:v2_blob) @v2_name = args[:v2_name] if args.key?(:v2_name) end |