Class: Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Describes where the config file that kicked off the build came from. This is effectively a pointer to the source where buildConfig came from.
Instance Attribute Summary collapse
-
#digest ⇒ Hash<String,String>
Corresponds to the JSON property
digest. -
#entry_point ⇒ String
Corresponds to the JSON property
entryPoint. -
#uri ⇒ String
Corresponds to the JSON property
uri.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource
constructor
A new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource
Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource.
4753 4754 4755 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4753 def initialize(**args) update!(**args) end |
Instance Attribute Details
#digest ⇒ Hash<String,String>
Corresponds to the JSON property digest
4741 4742 4743 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4741 def digest @digest end |
#entry_point ⇒ String
Corresponds to the JSON property entryPoint
4746 4747 4748 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4746 def entry_point @entry_point end |
#uri ⇒ String
Corresponds to the JSON property uri
4751 4752 4753 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4751 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4758 4759 4760 4761 4762 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4758 def update!(**args) @digest = args[:digest] if args.key?(:digest) @entry_point = args[:entry_point] if args.key?(:entry_point) @uri = args[:uri] if args.key?(:uri) end |