Class: Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Identifies the event that kicked off the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation.



4785
4786
4787
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_sourceGoogle::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource

Describes where the config file that kicked off the build came from. This is effectively a pointer to the source where buildConfig came from. Corresponds to the JSON property configSource



4773
4774
4775
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4773

def config_source
  @config_source
end

#environmentHash<String,Object>

Corresponds to the JSON property environment

Returns:

  • (Hash<String,Object>)


4778
4779
4780
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4778

def environment
  @environment
end

#parametersHash<String,Object>

Corresponds to the JSON property parameters

Returns:

  • (Hash<String,Object>)


4783
4784
4785
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4783

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4790
4791
4792
4793
4794
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4790

def update!(**args)
  @config_source = args[:config_source] if args.key?(:config_source)
  @environment = args[:environment] if args.key?(:environment)
  @parameters = args[:parameters] if args.key?(:parameters)
end