Class: Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial.



4853
4854
4855
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4853

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


4846
4847
4848
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4846

def digest
  @digest
end

#uriString

Corresponds to the JSON property uri

Returns:

  • (String)


4851
4852
4853
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4851

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4858
4859
4860
4861
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4858

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @uri = args[:uri] if args.key?(:uri)
end