Class: Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Other properties of the build.
Instance Attribute Summary collapse
-
#build_finished_on ⇒ String
Corresponds to the JSON property
buildFinishedOn. -
#build_invocation_id ⇒ String
Corresponds to the JSON property
buildInvocationId. -
#build_started_on ⇒ String
Corresponds to the JSON property
buildStartedOn. -
#completeness ⇒ Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaCompleteness
Indicates that the builder claims certain fields in this message to be complete.
-
#reproducible ⇒ Boolean
(also: #reproducible?)
Corresponds to the JSON property
reproducible.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
constructor
A new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata.
4841 4842 4843 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4841 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build_finished_on ⇒ String
Corresponds to the JSON property buildFinishedOn
4817 4818 4819 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4817 def build_finished_on @build_finished_on end |
#build_invocation_id ⇒ String
Corresponds to the JSON property buildInvocationId
4822 4823 4824 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4822 def build_invocation_id @build_invocation_id end |
#build_started_on ⇒ String
Corresponds to the JSON property buildStartedOn
4827 4828 4829 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4827 def build_started_on @build_started_on end |
#completeness ⇒ Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaCompleteness
Indicates that the builder claims certain fields in this message to be
complete.
Corresponds to the JSON property completeness
4833 4834 4835 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4833 def completeness @completeness end |
#reproducible ⇒ Boolean Also known as: reproducible?
Corresponds to the JSON property reproducible
4838 4839 4840 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4838 def reproducible @reproducible end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4846 4847 4848 4849 4850 4851 4852 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4846 def update!(**args) @build_finished_on = args[:build_finished_on] if args.key?(:build_finished_on) @build_invocation_id = args[:build_invocation_id] if args.key?(:build_invocation_id) @build_started_on = args[:build_started_on] if args.key?(:build_started_on) @completeness = args[:completeness] if args.key?(:completeness) @reproducible = args[:reproducible] if args.key?(:reproducible) end |