Class: Google::Apis::ContaineranalysisV1::LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LayerDetails

Returns a new instance of LayerDetails.



5334
5335
5336
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::ContaineranalysisV1::BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



5310
5311
5312
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5310

def base_images
  @base_images
end

#chain_idString

The layer chain ID (sha256 hash) of the layer in the container image. https:// github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid Corresponds to the JSON property chainId

Returns:

  • (String)


5316
5317
5318
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5316

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


5322
5323
5324
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5322

def command
  @command
end

#diff_idString

The diff ID (typically a sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


5327
5328
5329
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5327

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


5332
5333
5334
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5332

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5339
5340
5341
5342
5343
5344
5345
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5339

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end