Class: Google::Apis::ContaineranalysisV1::License

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

License information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ License

Returns a new instance of License.



5306
5307
5308
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentsString

Comments Corresponds to the JSON property comments

Returns:

  • (String)


5296
5297
5298
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5296

def comments
  @comments
end

#expressionString

Often a single license can be used to represent the licensing terms. Sometimes it is necessary to include a choice of one or more licenses or some combination of license identifiers. Examples: "LGPL-2.1-only OR MIT", "LGPL-2. 1-only AND MIT", "GPL-2.0-or-later WITH Bison-exception-2.2". Corresponds to the JSON property expression

Returns:

  • (String)


5304
5305
5306
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5304

def expression
  @expression
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5311
5312
5313
5314
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5311

def update!(**args)
  @comments = args[:comments] if args.key?(:comments)
  @expression = args[:expression] if args.key?(:expression)
end