Class: Google::Apis::ContaineranalysisV1::Location
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Location
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
An occurrence of a particular package installation found within a system's
filesystem. E.g., glibc was found in /var/lib/dpkg/status.
Instance Attribute Summary collapse
-
#cpe_uri ⇒ String
Deprecated.
-
#path ⇒ String
The path from which we gathered that this package/version is installed.
-
#version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Location
constructor
A new instance of Location.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Location
Returns a new instance of Location.
5471 5472 5473 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5471 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpe_uri ⇒ String
Deprecated. The CPE URI in CPE format
Corresponds to the JSON property cpeUri
5459 5460 5461 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5459 def cpe_uri @cpe_uri end |
#path ⇒ String
The path from which we gathered that this package/version is installed.
Corresponds to the JSON property path
5464 5465 5466 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5464 def path @path end |
#version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property version
5469 5470 5471 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5469 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5476 5477 5478 5479 5480 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5476 def update!(**args) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @path = args[:path] if args.key?(:path) @version = args[:version] if args.key?(:version) end |