Class: Google::Apis::ContaineranalysisV1::Metadata
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Metadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Other properties of the build.
Instance Attribute Summary collapse
-
#build_finished_on ⇒ String
The timestamp of when the build completed.
-
#build_invocation_id ⇒ String
Identifies the particular build invocation, which can be useful for finding associated logs or other ad-hoc analysis.
-
#build_started_on ⇒ String
The timestamp of when the build started.
-
#completeness ⇒ Google::Apis::ContaineranalysisV1::Completeness
Indicates that the builder claims certain fields in this message to be complete.
-
#reproducible ⇒ Boolean
(also: #reproducible?)
If true, the builder claims that running the recipe on materials will produce bit-for-bit identical output.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Metadata
constructor
A new instance of Metadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Metadata
Returns a new instance of Metadata.
5488 5489 5490 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5488 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build_finished_on ⇒ String
The timestamp of when the build completed.
Corresponds to the JSON property buildFinishedOn
5461 5462 5463 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5461 def build_finished_on @build_finished_on end |
#build_invocation_id ⇒ String
Identifies the particular build invocation, which can be useful for finding
associated logs or other ad-hoc analysis. The value SHOULD be globally unique,
per in-toto Provenance spec.
Corresponds to the JSON property buildInvocationId
5468 5469 5470 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5468 def build_invocation_id @build_invocation_id end |
#build_started_on ⇒ String
The timestamp of when the build started.
Corresponds to the JSON property buildStartedOn
5473 5474 5475 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5473 def build_started_on @build_started_on end |
#completeness ⇒ Google::Apis::ContaineranalysisV1::Completeness
Indicates that the builder claims certain fields in this message to be
complete.
Corresponds to the JSON property completeness
5479 5480 5481 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5479 def completeness @completeness end |
#reproducible ⇒ Boolean Also known as: reproducible?
If true, the builder claims that running the recipe on materials will produce
bit-for-bit identical output.
Corresponds to the JSON property reproducible
5485 5486 5487 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5485 def reproducible @reproducible end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5493 5494 5495 5496 5497 5498 5499 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5493 def update!(**args) @build_finished_on = args[:build_finished_on] if args.key?(:build_finished_on) @build_invocation_id = args[:build_invocation_id] if args.key?(:build_invocation_id) @build_started_on = args[:build_started_on] if args.key?(:build_started_on) @completeness = args[:completeness] if args.key?(:completeness) @reproducible = args[:reproducible] if args.key?(:reproducible) end |