Class: Google::Apis::ContaineranalysisV1::PackageNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

PackageNote represents a particular package version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageNote

Returns a new instance of PackageNote.



6084
6085
6086
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6084

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The CPU architecture for which packages in this distribution channel were built. Architecture will be blank for language packages. Corresponds to the JSON property architecture

Returns:

  • (String)


6028
6029
6030
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6028

def architecture
  @architecture
end

#cpe_uriString

The cpe_uri in CPE format denoting the package manager version distributing a package. The cpe_uri will be blank for language packages. Corresponds to the JSON property cpeUri

Returns:

  • (String)


6035
6036
6037
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6035

def cpe_uri
  @cpe_uri
end

#descriptionString

The description of this package. Corresponds to the JSON property description

Returns:

  • (String)


6040
6041
6042
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6040

def description
  @description
end

#digestArray<Google::Apis::ContaineranalysisV1::Digest>

Hash value, typically a file digest, that allows unique identification a specific package. Corresponds to the JSON property digest



6046
6047
6048
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6046

def digest
  @digest
end

#distributionArray<Google::Apis::ContaineranalysisV1::Distribution>

Deprecated. The various channels by which a package is distributed. Corresponds to the JSON property distribution



6051
6052
6053
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6051

def distribution
  @distribution
end

#licenseGoogle::Apis::ContaineranalysisV1::License

License information. Corresponds to the JSON property license



6056
6057
6058
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6056

def license
  @license
end

#maintainerString

A freeform text denoting the maintainer of this package. Corresponds to the JSON property maintainer

Returns:

  • (String)


6061
6062
6063
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6061

def maintainer
  @maintainer
end

#nameString

Required. Immutable. The name of the package. Corresponds to the JSON property name

Returns:

  • (String)


6066
6067
6068
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6066

def name
  @name
end

#package_typeString

The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.). Corresponds to the JSON property packageType

Returns:

  • (String)


6072
6073
6074
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6072

def package_type
  @package_type
end

#urlString

The homepage for this package. Corresponds to the JSON property url

Returns:

  • (String)


6077
6078
6079
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6077

def url
  @url
end

#versionGoogle::Apis::ContaineranalysisV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property version



6082
6083
6084
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6082

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6089
6090
6091
6092
6093
6094
6095
6096
6097
6098
6099
6100
6101
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6089

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @description = args[:description] if args.key?(:description)
  @digest = args[:digest] if args.key?(:digest)
  @distribution = args[:distribution] if args.key?(:distribution)
  @license = args[:license] if args.key?(:license)
  @maintainer = args[:maintainer] if args.key?(:maintainer)
  @name = args[:name] if args.key?(:name)
  @package_type = args[:package_type] if args.key?(:package_type)
  @url = args[:url] if args.key?(:url)
  @version = args[:version] if args.key?(:version)
end