Class: Google::Apis::ContaineranalysisV1::Product
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Product
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Product contains information about a product and how to uniquely identify it.
Instance Attribute Summary collapse
-
#generic_uri ⇒ String
Contains a URI which is vendor-specific.
-
#id ⇒ String
Token that identifies a product so that it can be referred to from other parts in the document.
-
#name ⇒ String
Name of the product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Product
constructor
A new instance of Product.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Product
Returns a new instance of Product.
6263 6264 6265 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6263 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generic_uri ⇒ String
Contains a URI which is vendor-specific. Example: The artifact repository URL
of an image.
Corresponds to the JSON property genericUri
6249 6250 6251 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6249 def generic_uri @generic_uri end |
#id ⇒ String
Token that identifies a product so that it can be referred to from other parts
in the document. There is no predefined format as long as it uniquely
identifies a group in the context of the current document.
Corresponds to the JSON property id
6256 6257 6258 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6256 def id @id end |
#name ⇒ String
Name of the product.
Corresponds to the JSON property name
6261 6262 6263 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6261 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6268 6269 6270 6271 6272 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6268 def update!(**args) @generic_uri = args[:generic_uri] if args.key?(:generic_uri) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) end |