Class: Google::Apis::ContaineranalysisV1::SbomReferenceIntotoPredicate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A predicate which describes the SBOM being referenced.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SbomReferenceIntotoPredicate

Returns a new instance of SbomReferenceIntotoPredicate.



6368
6369
6370
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6368

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

A map of algorithm to digest of the contents of the SBOM. Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


6351
6352
6353
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6351

def digest
  @digest
end

#locationString

The location of the SBOM. Corresponds to the JSON property location

Returns:

  • (String)


6356
6357
6358
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6356

def location
  @location
end

#mime_typeString

The mime type of the SBOM. Corresponds to the JSON property mimeType

Returns:

  • (String)


6361
6362
6363
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6361

def mime_type
  @mime_type
end

#referrer_idString

The person or system referring this predicate to the consumer. Corresponds to the JSON property referrerId

Returns:

  • (String)


6366
6367
6368
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6366

def referrer_id
  @referrer_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6373
6374
6375
6376
6377
6378
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6373

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @location = args[:location] if args.key?(:location)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @referrer_id = args[:referrer_id] if args.key?(:referrer_id)
end