Class: Google::Apis::ContaineranalysisV1::SecretLocation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::SecretLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
The location of the secret.
Instance Attribute Summary collapse
-
#file_location ⇒ Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation
Indicates the location at which a package was found.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecretLocation
constructor
A new instance of SecretLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecretLocation
Returns a new instance of SecretLocation.
6378 6379 6380 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_location ⇒ Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation
Indicates the location at which a package was found.
Corresponds to the JSON property fileLocation
6376 6377 6378 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6376 def file_location @file_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6383 6384 6385 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6383 def update!(**args) @file_location = args[:file_location] if args.key?(:file_location) end |