Class: Google::Apis::ContaineranalysisV1::SlsaCompleteness

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Indicates that the builder claims certain fields in this message to be complete.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaCompleteness

Returns a new instance of SlsaCompleteness.



7157
7158
7159
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argumentsBoolean Also known as: arguments?

If true, the builder claims that recipe.arguments is complete, meaning that all external inputs are properly captured in the recipe. Corresponds to the JSON property arguments

Returns:

  • (Boolean)


7141
7142
7143
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7141

def arguments
  @arguments
end

#environmentBoolean Also known as: environment?

If true, the builder claims that recipe.environment is claimed to be complete. Corresponds to the JSON property environment

Returns:

  • (Boolean)


7147
7148
7149
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7147

def environment
  @environment
end

#materialsBoolean Also known as: materials?

If true, the builder claims that materials are complete, usually through some controls to prevent network access. Sometimes called "hermetic". Corresponds to the JSON property materials

Returns:

  • (Boolean)


7154
7155
7156
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7154

def materials
  @materials
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7162
7163
7164
7165
7166
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7162

def update!(**args)
  @arguments = args[:arguments] if args.key?(:arguments)
  @environment = args[:environment] if args.key?(:environment)
  @materials = args[:materials] if args.key?(:materials)
end