Class: Google::Apis::ContaineranalysisV1::SlsaMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Other properties of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaMetadata

Returns a new instance of SlsaMetadata.



7079
7080
7081
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_finished_onString

The timestamp of when the build completed. Corresponds to the JSON property buildFinishedOn

Returns:

  • (String)


7052
7053
7054
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7052

def build_finished_on
  @build_finished_on
end

#build_invocation_idString

Identifies the particular build invocation, which can be useful for finding associated logs or other ad-hoc analysis. The value SHOULD be globally unique, per in-toto Provenance spec. Corresponds to the JSON property buildInvocationId

Returns:

  • (String)


7059
7060
7061
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7059

def build_invocation_id
  @build_invocation_id
end

#build_started_onString

The timestamp of when the build started. Corresponds to the JSON property buildStartedOn

Returns:

  • (String)


7064
7065
7066
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7064

def build_started_on
  @build_started_on
end

#completenessGoogle::Apis::ContaineranalysisV1::SlsaCompleteness

Indicates that the builder claims certain fields in this message to be complete. Corresponds to the JSON property completeness



7070
7071
7072
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7070

def completeness
  @completeness
end

#reproducibleBoolean Also known as: reproducible?

If true, the builder claims that running the recipe on materials will produce bit-for-bit identical output. Corresponds to the JSON property reproducible

Returns:

  • (Boolean)


7076
7077
7078
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7076

def reproducible
  @reproducible
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7084
7085
7086
7087
7088
7089
7090
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7084

def update!(**args)
  @build_finished_on = args[:build_finished_on] if args.key?(:build_finished_on)
  @build_invocation_id = args[:build_invocation_id] if args.key?(:build_invocation_id)
  @build_started_on = args[:build_started_on] if args.key?(:build_started_on)
  @completeness = args[:completeness] if args.key?(:completeness)
  @reproducible = args[:reproducible] if args.key?(:reproducible)
end