Class: Google::Apis::ContaineranalysisV1::SlsaProvenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenance

Returns a new instance of SlsaProvenance.



7245
7246
7247
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builderGoogle::Apis::ContaineranalysisV1::SlsaBuilder

required Corresponds to the JSON property builder



7224
7225
7226
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7224

def builder
  @builder
end

#materialsArray<Google::Apis::ContaineranalysisV1::Material>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials



7232
7233
7234
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7232

def materials
  @materials
end

#metadataGoogle::Apis::ContaineranalysisV1::SlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



7237
7238
7239
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7237

def 
  @metadata
end

#recipeGoogle::Apis::ContaineranalysisV1::SlsaRecipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



7243
7244
7245
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7243

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7250
7251
7252
7253
7254
7255
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7250

def update!(**args)
  @builder = args[:builder] if args.key?(:builder)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end