Class: Google::Apis::ContaineranalysisV1::SlsaProvenanceZeroTwo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

See full explanation of fields at slsa.dev/provenance/v0.2.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenanceZeroTwo

Returns a new instance of SlsaProvenanceZeroTwo.



6770
6771
6772
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6770

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_configHash<String,Object>

Corresponds to the JSON property buildConfig

Returns:

  • (Hash<String,Object>)


6742
6743
6744
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6742

def build_config
  @build_config
end

#build_typeString

Corresponds to the JSON property buildType

Returns:

  • (String)


6747
6748
6749
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6747

def build_type
  @build_type
end

#builderGoogle::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance. Corresponds to the JSON property builder



6753
6754
6755
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6753

def builder
  @builder
end

#invocationGoogle::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation

Identifies the event that kicked off the build. Corresponds to the JSON property invocation



6758
6759
6760
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6758

def invocation
  @invocation
end

#materialsArray<Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial>

Corresponds to the JSON property materials



6763
6764
6765
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6763

def materials
  @materials
end

#metadataGoogle::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



6768
6769
6770
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6768

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6775
6776
6777
6778
6779
6780
6781
6782
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6775

def update!(**args)
  @build_config = args[:build_config] if args.key?(:build_config)
  @build_type = args[:build_type] if args.key?(:build_type)
  @builder = args[:builder] if args.key?(:builder)
  @invocation = args[:invocation] if args.key?(:invocation)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
end