Class: Google::Apis::ContaineranalysisV1::SourceContext

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A SourceContext is a reference to a tree of files. A SourceContext together with a path point to a unique revision of a single file or directory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceContext

Returns a new instance of SourceContext.



7342
7343
7344
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7342

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_repoGoogle::Apis::ContaineranalysisV1::CloudRepoSourceContext

A CloudRepoSourceContext denotes a particular revision in a Google Cloud Source Repo. Corresponds to the JSON property cloudRepo



7324
7325
7326
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7324

def cloud_repo
  @cloud_repo
end

#gerritGoogle::Apis::ContaineranalysisV1::GerritSourceContext

A SourceContext referring to a Gerrit project. Corresponds to the JSON property gerrit



7329
7330
7331
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7329

def gerrit
  @gerrit
end

#gitGoogle::Apis::ContaineranalysisV1::GitSourceContext

A GitSourceContext denotes a particular revision in a third party Git repository (e.g., GitHub). Corresponds to the JSON property git



7335
7336
7337
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7335

def git
  @git
end

#labelsHash<String,String>

Labels with user defined metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7340
7341
7342
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7340

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7347
7348
7349
7350
7351
7352
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7347

def update!(**args)
  @cloud_repo = args[:cloud_repo] if args.key?(:cloud_repo)
  @gerrit = args[:gerrit] if args.key?(:gerrit)
  @git = args[:git] if args.key?(:git)
  @labels = args[:labels] if args.key?(:labels)
end