Class: Google::Apis::ContaineranalysisV1::UpgradeNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

An Upgrade Note represents a potential upgrade of a package to a given version. For each package version combination (i.e. bash 4.0, bash 4.1, bash 4.1.2), there will be an Upgrade Note. For Windows, windows_update field represents the information related to the update.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeNote

Returns a new instance of UpgradeNote.



7583
7584
7585
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#distributionsArray<Google::Apis::ContaineranalysisV1::UpgradeDistribution>

Metadata about the upgrade for each specific operating system. Corresponds to the JSON property distributions



7563
7564
7565
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7563

def distributions
  @distributions
end

#packageString

Required for non-Windows OS. The package this Upgrade is for. Corresponds to the JSON property package

Returns:

  • (String)


7568
7569
7570
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7568

def package
  @package
end

#versionGoogle::Apis::ContaineranalysisV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property version



7573
7574
7575
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7573

def version
  @version
end

#windows_updateGoogle::Apis::ContaineranalysisV1::WindowsUpdate

Windows Update represents the metadata about the update for the Windows operating system. The fields in this message come from the Windows Update API documented at https://docs.microsoft.com/en-us/windows/win32/api/wuapi/nn- wuapi-iupdate. Corresponds to the JSON property windowsUpdate



7581
7582
7583
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7581

def windows_update
  @windows_update
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7588
7589
7590
7591
7592
7593
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7588

def update!(**args)
  @distributions = args[:distributions] if args.key?(:distributions)
  @package = args[:package] if args.key?(:package)
  @version = args[:version] if args.key?(:version)
  @windows_update = args[:windows_update] if args.key?(:windows_update)
end