Class: Google::Apis::ContaineranalysisV1::UpgradeOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability). For Windows, both distribution and windows_update contain information for the Windows update.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeOccurrence

Returns a new instance of UpgradeOccurrence.



7759
7760
7761
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#distributionGoogle::Apis::ContaineranalysisV1::UpgradeDistribution

The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities. Corresponds to the JSON property distribution



7739
7740
7741
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7739

def distribution
  @distribution
end

#packageString

Required for non-Windows OS. The package this Upgrade is for. Corresponds to the JSON property package

Returns:

  • (String)


7744
7745
7746
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7744

def package
  @package
end

#parsed_versionGoogle::Apis::ContaineranalysisV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property parsedVersion



7749
7750
7751
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7749

def parsed_version
  @parsed_version
end

#windows_updateGoogle::Apis::ContaineranalysisV1::WindowsUpdate

Windows Update represents the metadata about the update for the Windows operating system. The fields in this message come from the Windows Update API documented at https://docs.microsoft.com/en-us/windows/win32/api/wuapi/nn- wuapi-iupdate. Corresponds to the JSON property windowsUpdate



7757
7758
7759
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7757

def windows_update
  @windows_update
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7764
7765
7766
7767
7768
7769
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7764

def update!(**args)
  @distribution = args[:distribution] if args.key?(:distribution)
  @package = args[:package] if args.key?(:package)
  @parsed_version = args[:parsed_version] if args.key?(:parsed_version)
  @windows_update = args[:windows_update] if args.key?(:windows_update)
end