Class: Google::Apis::ContaineranalysisV1::VexAssessment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

VexAssessment provides all publisher provided Vex information that is related to this vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VexAssessment

Returns a new instance of VexAssessment.



7756
7757
7758
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7756

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cveString

Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking number for the vulnerability. Deprecated: Use vulnerability_id instead to denote CVEs. Corresponds to the JSON property cve

Returns:

  • (String)


7714
7715
7716
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7714

def cve
  @cve
end

#impactsArray<String>

Contains information about the impact of this vulnerability, this will change with time. Corresponds to the JSON property impacts

Returns:

  • (Array<String>)


7720
7721
7722
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7720

def impacts
  @impacts
end

#justificationGoogle::Apis::ContaineranalysisV1::Justification

Justification provides the justification when the state of the assessment if NOT_AFFECTED. Corresponds to the JSON property justification



7726
7727
7728
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7726

def justification
  @justification
end

#note_nameString

The VulnerabilityAssessment note from which this VexAssessment was generated. This will be of the form: projects/[PROJECT_ID]/notes/[NOTE_ID]. Corresponds to the JSON property noteName

Returns:

  • (String)


7732
7733
7734
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7732

def note_name
  @note_name
end

Holds a list of references associated with this vulnerability item and assessment. Corresponds to the JSON property relatedUris



7738
7739
7740
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7738

def related_uris
  @related_uris
end

#remediationsArray<Google::Apis::ContaineranalysisV1::Remediation>

Specifies details on how to handle (and presumably, fix) a vulnerability. Corresponds to the JSON property remediations



7743
7744
7745
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7743

def remediations
  @remediations
end

#stateString

Provides the state of this Vulnerability assessment. Corresponds to the JSON property state

Returns:

  • (String)


7748
7749
7750
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7748

def state
  @state
end

#vulnerability_idString

The vulnerability identifier for this Assessment. Will hold one of common identifiers e.g. CVE, GHSA etc. Corresponds to the JSON property vulnerabilityId

Returns:

  • (String)


7754
7755
7756
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7754

def vulnerability_id
  @vulnerability_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7761

def update!(**args)
  @cve = args[:cve] if args.key?(:cve)
  @impacts = args[:impacts] if args.key?(:impacts)
  @justification = args[:justification] if args.key?(:justification)
  @note_name = args[:note_name] if args.key?(:note_name)
  @related_uris = args[:related_uris] if args.key?(:related_uris)
  @remediations = args[:remediations] if args.key?(:remediations)
  @state = args[:state] if args.key?(:state)
  @vulnerability_id = args[:vulnerability_id] if args.key?(:vulnerability_id)
end