Class: Google::Apis::ContaineranalysisV1::VulnerabilityAssessmentNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A single VulnerabilityAssessmentNote represents one particular product's vulnerability assessment for one CVE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityAssessmentNote

Returns a new instance of VulnerabilityAssessmentNote.



7845
7846
7847
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7845

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assessmentGoogle::Apis::ContaineranalysisV1::Assessment

Assessment provides all information that is related to a single vulnerability for this product. Corresponds to the JSON property assessment



7812
7813
7814
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7812

def assessment
  @assessment
end

#language_codeString

Identifies the language used by this document, corresponding to IETF BCP 47 / RFC 5646. Corresponds to the JSON property languageCode

Returns:

  • (String)


7818
7819
7820
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7818

def language_code
  @language_code
end

#long_descriptionString

A detailed description of this Vex. Corresponds to the JSON property longDescription

Returns:

  • (String)


7823
7824
7825
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7823

def long_description
  @long_description
end

#productGoogle::Apis::ContaineranalysisV1::Product

Product contains information about a product and how to uniquely identify it. Corresponds to the JSON property product



7828
7829
7830
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7828

def product
  @product
end

#publisherGoogle::Apis::ContaineranalysisV1::Publisher

Publisher contains information about the publisher of this Note. Corresponds to the JSON property publisher



7833
7834
7835
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7833

def publisher
  @publisher
end

#short_descriptionString

A one sentence description of this Vex. Corresponds to the JSON property shortDescription

Returns:

  • (String)


7838
7839
7840
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7838

def short_description
  @short_description
end

#titleString

The title of the note. E.g. Vex-Debian-11.4 Corresponds to the JSON property title

Returns:

  • (String)


7843
7844
7845
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7843

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7850
7851
7852
7853
7854
7855
7856
7857
7858
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7850

def update!(**args)
  @assessment = args[:assessment] if args.key?(:assessment)
  @language_code = args[:language_code] if args.key?(:language_code)
  @long_description = args[:long_description] if args.key?(:long_description)
  @product = args[:product] if args.key?(:product)
  @publisher = args[:publisher] if args.key?(:publisher)
  @short_description = args[:short_description] if args.key?(:short_description)
  @title = args[:title] if args.key?(:title)
end