Class: Google::Apis::ContaineranalysisV1::VulnerabilityNote
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::VulnerabilityNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
A security vulnerability that can be found in resources.
Instance Attribute Summary collapse
-
#advisory_publish_time ⇒ String
The time this advisory was published by the source.
-
#cvss_score ⇒ Float
The CVSS score of this vulnerability.
-
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1::Cvss
Common Vulnerability Scoring System.
-
#cvss_v3 ⇒ Google::Apis::ContaineranalysisV1::CvsSv3
Common Vulnerability Scoring System version 3.
-
#cvss_v4 ⇒ Google::Apis::ContaineranalysisV1::Cvss
Common Vulnerability Scoring System.
-
#cvss_version ⇒ String
CVSS version used to populate cvss_score and severity.
-
#details ⇒ Array<Google::Apis::ContaineranalysisV1::Detail>
Details of all known distros and packages affected by this vulnerability.
-
#severity ⇒ String
The note provider assigned severity of this vulnerability.
-
#source_update_time ⇒ String
The time this information was last changed at the source.
-
#windows_details ⇒ Array<Google::Apis::ContaineranalysisV1::WindowsDetail>
Windows details get their own format because the information format and model don't match a normal detail.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityNote
constructor
A new instance of VulnerabilityNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityNote
Returns a new instance of VulnerabilityNote.
8052 8053 8054 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8052 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advisory_publish_time ⇒ String
The time this advisory was published by the source.
Corresponds to the JSON property advisoryPublishTime
7992 7993 7994 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7992 def advisory_publish_time @advisory_publish_time end |
#cvss_score ⇒ Float
The CVSS score of this vulnerability. CVSS score is on a scale of 0 - 10 where
0 indicates low severity and 10 indicates high severity.
Corresponds to the JSON property cvssScore
7998 7999 8000 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7998 def cvss_score @cvss_score end |
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1::Cvss
Common Vulnerability Scoring System. For details, see https://www.first.org/
cvss/specification-document This is a message we will try to use for storing
various versions of CVSS rather than making a separate proto for storing a
specific version.
Corresponds to the JSON property cvssV2
8006 8007 8008 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8006 def cvss_v2 @cvss_v2 end |
#cvss_v3 ⇒ Google::Apis::ContaineranalysisV1::CvsSv3
Common Vulnerability Scoring System version 3. For details, see https://www.
first.org/cvss/specification-document
Corresponds to the JSON property cvssV3
8012 8013 8014 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8012 def cvss_v3 @cvss_v3 end |
#cvss_v4 ⇒ Google::Apis::ContaineranalysisV1::Cvss
Common Vulnerability Scoring System. For details, see https://www.first.org/
cvss/specification-document This is a message we will try to use for storing
various versions of CVSS rather than making a separate proto for storing a
specific version.
Corresponds to the JSON property cvssV4
8020 8021 8022 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8020 def cvss_v4 @cvss_v4 end |
#cvss_version ⇒ String
CVSS version used to populate cvss_score and severity.
Corresponds to the JSON property cvssVersion
8025 8026 8027 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8025 def cvss_version @cvss_version end |
#details ⇒ Array<Google::Apis::ContaineranalysisV1::Detail>
Details of all known distros and packages affected by this vulnerability.
Corresponds to the JSON property details
8030 8031 8032 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8030 def details @details end |
#severity ⇒ String
The note provider assigned severity of this vulnerability.
Corresponds to the JSON property severity
8035 8036 8037 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8035 def severity @severity end |
#source_update_time ⇒ String
The time this information was last changed at the source. This is an upstream
timestamp from the underlying information source - e.g. Ubuntu security
tracker.
Corresponds to the JSON property sourceUpdateTime
8042 8043 8044 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8042 def source_update_time @source_update_time end |
#windows_details ⇒ Array<Google::Apis::ContaineranalysisV1::WindowsDetail>
Windows details get their own format because the information format and model
don't match a normal detail. Specifically Windows updates are done as patches,
thus Windows vulnerabilities really are a missing package, rather than a
package being at an incorrect version.
Corresponds to the JSON property windowsDetails
8050 8051 8052 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8050 def windows_details @windows_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8057 8058 8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8057 def update!(**args) @advisory_publish_time = args[:advisory_publish_time] if args.key?(:advisory_publish_time) @cvss_score = args[:cvss_score] if args.key?(:cvss_score) @cvss_v2 = args[:cvss_v2] if args.key?(:cvss_v2) @cvss_v3 = args[:cvss_v3] if args.key?(:cvss_v3) @cvss_v4 = args[:cvss_v4] if args.key?(:cvss_v4) @cvss_version = args[:cvss_version] if args.key?(:cvss_version) @details = args[:details] if args.key?(:details) @severity = args[:severity] if args.key?(:severity) @source_update_time = args[:source_update_time] if args.key?(:source_update_time) @windows_details = args[:windows_details] if args.key?(:windows_details) end |