Class: Google::Apis::ContaineranalysisV1::VulnerabilityOccurrencesSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A summary of how many vulnerability occurrences there are per resource and severity type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityOccurrencesSummary

Returns a new instance of VulnerabilityOccurrencesSummary.



8100
8101
8102
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countsArray<Google::Apis::ContaineranalysisV1::FixableTotalByDigest>

A listing by resource of the number of fixable and total vulnerabilities. Corresponds to the JSON property counts



8091
8092
8093
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8091

def counts
  @counts
end

#unreachableArray<String>

Unordered list. Unreachable regions. Populated for requests from the global region when return_partial_success is set. Format: projects/[PROJECT_ID]/ locations/[LOCATION] Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


8098
8099
8100
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8098

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8105
8106
8107
8108
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 8105

def update!(**args)
  @counts = args[:counts] if args.key?(:counts)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end