Class: Google::Apis::ContaineranalysisV1::BuildOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::BuildOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Details of a build occurrence.
Instance Attribute Summary collapse
-
#in_toto_slsa_provenance_v1 ⇒ Google::Apis::ContaineranalysisV1::InTotoSlsaProvenanceV1
In-Toto Slsa Provenance V1 represents a slsa provenance meeting the slsa spec, wrapped in an in-toto statement.
-
#intoto_provenance ⇒ Google::Apis::ContaineranalysisV1::InTotoProvenance
Deprecated.
-
#intoto_statement ⇒ Google::Apis::ContaineranalysisV1::InTotoStatement
Spec defined at https://github.com/in-toto/attestation/tree/main/spec# statement The serialized InTotoStatement will be stored as Envelope.payload.
-
#provenance ⇒ Google::Apis::ContaineranalysisV1::BuildProvenance
Provenance of a build.
-
#provenance_bytes ⇒ String
Serialized JSON representation of the provenance, used in generating the build signature in the corresponding build note.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BuildOccurrence
constructor
A new instance of BuildOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BuildOccurrence
Returns a new instance of BuildOccurrence.
643 644 645 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 643 def initialize(**args) update!(**args) end |
Instance Attribute Details
#in_toto_slsa_provenance_v1 ⇒ Google::Apis::ContaineranalysisV1::InTotoSlsaProvenanceV1
In-Toto Slsa Provenance V1 represents a slsa provenance meeting the slsa spec,
wrapped in an in-toto statement. This allows for direct jsonification of a to-
spec in-toto slsa statement with a to-spec slsa provenance.
Corresponds to the JSON property inTotoSlsaProvenanceV1
610 611 612 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 610 def in_toto_slsa_provenance_v1 @in_toto_slsa_provenance_v1 end |
#intoto_provenance ⇒ Google::Apis::ContaineranalysisV1::InTotoProvenance
Deprecated. See InTotoStatement for the replacement. In-toto Provenance
representation as defined in spec.
Corresponds to the JSON property intotoProvenance
616 617 618 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 616 def intoto_provenance @intoto_provenance end |
#intoto_statement ⇒ Google::Apis::ContaineranalysisV1::InTotoStatement
Spec defined at https://github.com/in-toto/attestation/tree/main/spec#
statement The serialized InTotoStatement will be stored as Envelope.payload.
Envelope.payloadType is always "application/vnd.in-toto+json".
Corresponds to the JSON property intotoStatement
623 624 625 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 623 def intoto_statement @intoto_statement end |
#provenance ⇒ Google::Apis::ContaineranalysisV1::BuildProvenance
Provenance of a build. Contains all information needed to verify the full
details about the build from source to completion.
Corresponds to the JSON property provenance
629 630 631 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 629 def provenance @provenance end |
#provenance_bytes ⇒ String
Serialized JSON representation of the provenance, used in generating the build
signature in the corresponding build note. After verifying the signature,
provenance_bytes can be unmarshalled and compared to the provenance to
confirm that it is unchanged. A base64-encoded string representation of the
provenance bytes is used for the signature in order to interoperate with
openssl which expects this format for signature verification. The serialized
form is captured both to avoid ambiguity in how the provenance is marshalled
to json as well to prevent incompatibilities with future changes.
Corresponds to the JSON property provenanceBytes
641 642 643 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 641 def provenance_bytes @provenance_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
648 649 650 651 652 653 654 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 648 def update!(**args) @in_toto_slsa_provenance_v1 = args[:in_toto_slsa_provenance_v1] if args.key?(:in_toto_slsa_provenance_v1) @intoto_provenance = args[:intoto_provenance] if args.key?(:intoto_provenance) @intoto_statement = args[:intoto_statement] if args.key?(:intoto_statement) @provenance = args[:provenance] if args.key?(:provenance) @provenance_bytes = args[:provenance_bytes] if args.key?(:provenance_bytes) end |