Class: Google::Apis::ContaineranalysisV1::Command
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Command
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Command describes a step performed as part of the build pipeline.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Command-line arguments used when executing this command.
-
#dir ⇒ String
Working directory (relative to project source root) used when running this command.
-
#env ⇒ Array<String>
Environment variables set before running this command.
-
#id ⇒ String
Optional unique identifier for this command, used in wait_for to reference this command as a dependency.
-
#name ⇒ String
Required.
-
#wait_for ⇒ Array<String>
The ID(s) of the command(s) that this command depends on.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Command
constructor
A new instance of Command.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Command
Returns a new instance of Command.
1228 1229 1230 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Command-line arguments used when executing this command.
Corresponds to the JSON property args
1198 1199 1200 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1198 def args @args end |
#dir ⇒ String
Working directory (relative to project source root) used when running this
command.
Corresponds to the JSON property dir
1204 1205 1206 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1204 def dir @dir end |
#env ⇒ Array<String>
Environment variables set before running this command.
Corresponds to the JSON property env
1209 1210 1211 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1209 def env @env end |
#id ⇒ String
Optional unique identifier for this command, used in wait_for to reference
this command as a dependency.
Corresponds to the JSON property id
1215 1216 1217 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1215 def id @id end |
#name ⇒ String
Required. Name of the command, as presented on the command line, or if the
command is packaged as a Docker container, as presented to docker pull.
Corresponds to the JSON property name
1221 1222 1223 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1221 def name @name end |
#wait_for ⇒ Array<String>
The ID(s) of the command(s) that this command depends on.
Corresponds to the JSON property waitFor
1226 1227 1228 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1226 def wait_for @wait_for end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1233 1234 1235 1236 1237 1238 1239 1240 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1233 def update!(**args) @args = args[:args] if args.key?(:args) @dir = args[:dir] if args.key?(:dir) @env = args[:env] if args.key?(:env) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @wait_for = args[:wait_for] if args.key?(:wait_for) end |