Class: Google::Apis::ContaineranalysisV1::ComplianceNote
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::ComplianceNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Instance Attribute Summary collapse
-
#cis_benchmark ⇒ Google::Apis::ContaineranalysisV1::CisBenchmark
A compliance check that is a CIS benchmark.
-
#description ⇒ String
A description about this compliance check.
-
#impact ⇒ String
Corresponds to the JSON property
impact. -
#rationale ⇒ String
A rationale for the existence of this compliance check.
-
#remediation ⇒ String
A description of remediation steps if the compliance check fails.
-
#scan_instructions ⇒ String
Serialized scan instructions with a predefined format.
-
#title ⇒ String
The title that identifies this compliance check.
-
#version ⇒ Array<Google::Apis::ContaineranalysisV1::ComplianceVersion>
The OS and config versions the benchmark applies to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ComplianceNote
constructor
A new instance of ComplianceNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ComplianceNote
Returns a new instance of ComplianceNote.
1331 1332 1333 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cis_benchmark ⇒ Google::Apis::ContaineranalysisV1::CisBenchmark
A compliance check that is a CIS benchmark.
Corresponds to the JSON property cisBenchmark
1293 1294 1295 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1293 def cis_benchmark @cis_benchmark end |
#description ⇒ String
A description about this compliance check.
Corresponds to the JSON property description
1298 1299 1300 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1298 def description @description end |
#impact ⇒ String
Corresponds to the JSON property impact
1303 1304 1305 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1303 def impact @impact end |
#rationale ⇒ String
A rationale for the existence of this compliance check.
Corresponds to the JSON property rationale
1308 1309 1310 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1308 def rationale @rationale end |
#remediation ⇒ String
A description of remediation steps if the compliance check fails.
Corresponds to the JSON property remediation
1313 1314 1315 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1313 def remediation @remediation end |
#scan_instructions ⇒ String
Serialized scan instructions with a predefined format.
Corresponds to the JSON property scanInstructions
NOTE: Values are automatically base64 encoded/decoded in the client library.
1319 1320 1321 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1319 def scan_instructions @scan_instructions end |
#title ⇒ String
The title that identifies this compliance check.
Corresponds to the JSON property title
1324 1325 1326 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1324 def title @title end |
#version ⇒ Array<Google::Apis::ContaineranalysisV1::ComplianceVersion>
The OS and config versions the benchmark applies to.
Corresponds to the JSON property version
1329 1330 1331 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1329 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1336 def update!(**args) @cis_benchmark = args[:cis_benchmark] if args.key?(:cis_benchmark) @description = args[:description] if args.key?(:description) @impact = args[:impact] if args.key?(:impact) @rationale = args[:rationale] if args.key?(:rationale) @remediation = args[:remediation] if args.key?(:remediation) @scan_instructions = args[:scan_instructions] if args.key?(:scan_instructions) @title = args[:title] if args.key?(:title) @version = args[:version] if args.key?(:version) end |