Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
ApprovalResult describes the decision and associated metadata of a manual approval of a build.
Instance Attribute Summary collapse
-
#approval_time ⇒ String
Output only.
-
#approver_account ⇒ String
Output only.
-
#comment ⇒ String
Optional.
-
#decision ⇒ String
Required.
-
#url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult.
1509 1510 1511 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1509 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_time ⇒ String
Output only. The time when the approval decision was made.
Corresponds to the JSON property approvalTime
1483 1484 1485 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1483 def approval_time @approval_time end |
#approver_account ⇒ String
Output only. Email of the user that called the ApproveBuild API to approve or
reject a build at the time that the API was called.
Corresponds to the JSON property approverAccount
1489 1490 1491 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1489 def approver_account @approver_account end |
#comment ⇒ String
Optional. An optional comment for this manual approval result.
Corresponds to the JSON property comment
1494 1495 1496 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1494 def comment @comment end |
#decision ⇒ String
Required. The decision of this manual approval.
Corresponds to the JSON property decision
1499 1500 1501 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1499 def decision @decision end |
#url ⇒ String
Optional. An optional URL tied to this manual approval result. This field is
essentially the same as comment, except that it will be rendered by the UI
differently. An example use case is a link to an external job that approved
this Build.
Corresponds to the JSON property url
1507 1508 1509 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1507 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1514 1515 1516 1517 1518 1519 1520 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1514 def update!(**args) @approval_time = args[:approval_time] if args.key?(:approval_time) @approver_account = args[:approver_account] if args.key?(:approver_account) @comment = args[:comment] if args.key?(:comment) @decision = args[:decision] if args.key?(:decision) @url = args[:url] if args.key?(:url) end |