Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Artifacts produced by a build that should be uploaded upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts.



1598
1599
1600
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generic_artifactsArray<Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact>

Optional. A list of generic artifacts to be uploaded to Artifact Registry upon successful completion of all build steps. If any artifacts fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property genericArtifacts



1539
1540
1541
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1539

def generic_artifacts
  @generic_artifacts
end

#go_modulesArray<Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule>

Optional. A list of Go modules to be uploaded to Artifact Registry upon successful completion of all build steps. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property goModules



1546
1547
1548
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1546

def go_modules
  @go_modules
end

#imagesArray<String>

A list of images to be pushed upon the successful completion of all build steps. The images will be pushed using the builder service account's credentials. The digests of the pushed images will be stored in the Build resource's results field. If any of the images fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property images

Returns:

  • (Array<String>)


1555
1556
1557
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1555

def images
  @images
end

#maven_artifactsArray<Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact>

A list of Maven artifacts to be uploaded to Artifact Registry upon successful completion of all build steps. Artifacts in the workspace matching specified paths globs will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any artifacts fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property mavenArtifacts



1564
1565
1566
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1564

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsNpmPackage>

A list of npm packages to be uploaded to Artifact Registry upon successful completion of all build steps. Npm packages in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any packages fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property npmPackages



1573
1574
1575
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1573

def npm_packages
  @npm_packages
end

#objectsGoogle::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsArtifactObjects

Files in the workspace to upload to Cloud Storage upon successful completion of all build steps. Corresponds to the JSON property objects



1579
1580
1581
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1579

def objects
  @objects
end

#ociArray<Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsOci>

Optional. A list of OCI images to be uploaded to Artifact Registry upon successful completion of all build steps. OCI images in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any images fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property oci



1588
1589
1590
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1588

def oci
  @oci
end

#python_packagesArray<Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsPythonPackage>

A list of Python packages to be uploaded to Artifact Registry upon successful completion of all build steps. The build service account credentials will be used to perform the upload. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property pythonPackages



1596
1597
1598
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1596

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1603

def update!(**args)
  @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @objects = args[:objects] if args.key?(:objects)
  @oci = args[:oci] if args.key?(:oci)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end