Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsOci
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsOci
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
OCI image to upload to Artifact Registry upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#file ⇒ String
Required.
-
#registry_path ⇒ String
Required.
-
#tags ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsOci
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsOci.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsOci
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsOci.
1765 1766 1767 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1765 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file ⇒ String
Required. Path on the local file system where to find the container to upload.
e.g. /workspace/my-image.tar
Corresponds to the JSON property file
1752 1753 1754 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1752 def file @file end |
#registry_path ⇒ String
Required. Registry path to upload the container to. e.g. us-east1-docker.pkg.
dev/my-project/my-repo/my-image
Corresponds to the JSON property registryPath
1758 1759 1760 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1758 def registry_path @registry_path end |
#tags ⇒ Array<String>
Optional. Tags to apply to the uploaded image. e.g. latest, 1.0.0
Corresponds to the JSON property tags
1763 1764 1765 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1763 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1770 1771 1772 1773 1774 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1770 def update!(**args) @file = args[:file] if args.key?(:file) @registry_path = args[:registry_path] if args.key?(:registry_path) @tags = args[:tags] if args.key?(:tags) end |