Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Optional arguments to enable specific features of builds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions.



2294
2295
2296
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2294

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automap_substitutionsBoolean Also known as: automap_substitutions?

Option to include built-in and custom substitutions as env variables for all build steps. Corresponds to the JSON property automapSubstitutions

Returns:

  • (Boolean)


2185
2186
2187
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2185

def automap_substitutions
  @automap_substitutions
end

#default_logs_bucket_behaviorString

Optional. Option to specify how default logs buckets are setup. Corresponds to the JSON property defaultLogsBucketBehavior

Returns:

  • (String)


2191
2192
2193
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2191

def default_logs_bucket_behavior
  @default_logs_bucket_behavior
end

#disk_size_gbFixnum

Requested disk size for the VM that runs the build. Note that this is NOT " disk free"; some of the space will be used by the operating system and build utilities. Also note that this is the minimum disk size that will be allocated for the build -- the build may run with a larger disk than requested. At present, the maximum disk size is 4000GB; builds that request more than the maximum are rejected with an error. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


2201
2202
2203
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2201

def disk_size_gb
  @disk_size_gb
end

#dynamic_substitutionsBoolean Also known as: dynamic_substitutions?

Option to specify whether or not to apply bash style string operations to the substitutions. NOTE: this is always enabled for triggered builds and cannot be overridden in the build configuration file. Corresponds to the JSON property dynamicSubstitutions

Returns:

  • (Boolean)


2208
2209
2210
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2208

def dynamic_substitutions
  @dynamic_substitutions
end

#enable_structured_loggingBoolean Also known as: enable_structured_logging?

Optional. Option to specify whether structured logging is enabled. If true, JSON-formatted logs are parsed as structured logs. Corresponds to the JSON property enableStructuredLogging

Returns:

  • (Boolean)


2215
2216
2217
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2215

def enable_structured_logging
  @enable_structured_logging
end

#envArray<String>

A list of global environment variable definitions that will exist for all build steps in this build. If a variable is defined in both globally and in a build step, the variable will use the build step value. The elements are of the form "KEY=VALUE" for the environment variable "KEY" being given the value " VALUE". Corresponds to the JSON property env

Returns:

  • (Array<String>)


2225
2226
2227
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2225

def env
  @env
end

#log_streaming_optionString

Option to define build log streaming behavior to Cloud Storage. Corresponds to the JSON property logStreamingOption

Returns:

  • (String)


2230
2231
2232
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2230

def log_streaming_option
  @log_streaming_option
end

#loggingString

Option to specify the logging mode, which determines if and where build logs are stored. Corresponds to the JSON property logging

Returns:

  • (String)


2236
2237
2238
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2236

def logging
  @logging
end

#machine_typeString

Compute Engine machine type on which to run the build. Corresponds to the JSON property machineType

Returns:

  • (String)


2241
2242
2243
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2241

def machine_type
  @machine_type
end

#poolGoogle::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptionsPoolOption

Details about how a build should be executed on a WorkerPool. See running builds in a private pool for more information. Corresponds to the JSON property pool



2248
2249
2250
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2248

def pool
  @pool
end

#pubsub_topicString

Optional. Option to specify the Pub/Sub topic to receive build status updates. Corresponds to the JSON property pubsubTopic

Returns:

  • (String)


2253
2254
2255
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2253

def pubsub_topic
  @pubsub_topic
end

#requested_verify_optionString

Requested verifiability options. Corresponds to the JSON property requestedVerifyOption

Returns:

  • (String)


2258
2259
2260
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2258

def requested_verify_option
  @requested_verify_option
end

#secret_envArray<String>

A list of global environment variables, which are encrypted using a Cloud Key Management Service crypto key. These values must be specified in the build's Secret. These variables will be available to all build steps in this build. Corresponds to the JSON property secretEnv

Returns:

  • (Array<String>)


2265
2266
2267
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2265

def secret_env
  @secret_env
end

#source_provenance_hashArray<String>

Requested hash for SourceProvenance. Corresponds to the JSON property sourceProvenanceHash

Returns:

  • (Array<String>)


2270
2271
2272
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2270

def source_provenance_hash
  @source_provenance_hash
end

#substitution_optionString

Option to specify behavior when there is an error in the substitution checks. NOTE: this is always set to ALLOW_LOOSE for triggered builds and cannot be overridden in the build configuration file. Corresponds to the JSON property substitutionOption

Returns:

  • (String)


2277
2278
2279
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2277

def substitution_option
  @substitution_option
end

#volumesArray<Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume>

Global list of volumes to mount for ALL build steps Each volume is created as an empty volume prior to starting the build process. Upon completion of the build, volumes and their contents are discarded. Global volume names and paths cannot conflict with the volumes defined a build step. Using a global volume in a build with only one step is not valid as it is indicative of a build request with an incorrect configuration. Corresponds to the JSON property volumes



2287
2288
2289
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2287

def volumes
  @volumes
end

#worker_poolString

This field deprecated; please use pool.name instead. Corresponds to the JSON property workerPool

Returns:

  • (String)


2292
2293
2294
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2292

def worker_pool
  @worker_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2299

def update!(**args)
  @automap_substitutions = args[:automap_substitutions] if args.key?(:automap_substitutions)
  @default_logs_bucket_behavior = args[:default_logs_bucket_behavior] if args.key?(:default_logs_bucket_behavior)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @dynamic_substitutions = args[:dynamic_substitutions] if args.key?(:dynamic_substitutions)
  @enable_structured_logging = args[:enable_structured_logging] if args.key?(:enable_structured_logging)
  @env = args[:env] if args.key?(:env)
  @log_streaming_option = args[:log_streaming_option] if args.key?(:log_streaming_option)
  @logging = args[:logging] if args.key?(:logging)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @pool = args[:pool] if args.key?(:pool)
  @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic)
  @requested_verify_option = args[:requested_verify_option] if args.key?(:requested_verify_option)
  @secret_env = args[:secret_env] if args.key?(:secret_env)
  @source_provenance_hash = args[:source_provenance_hash] if args.key?(:source_provenance_hash)
  @substitution_option = args[:substitution_option] if args.key?(:substitution_option)
  @volumes = args[:volumes] if args.key?(:volumes)
  @worker_pool = args[:worker_pool] if args.key?(:worker_pool)
end