Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Optional arguments to enable specific features of builds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions.



2175
2176
2177
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2175

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automap_substitutionsBoolean Also known as: automap_substitutions?

Option to include built-in and custom substitutions as env variables for all build steps. Corresponds to the JSON property automapSubstitutions

Returns:

  • (Boolean)


2066
2067
2068
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2066

def automap_substitutions
  @automap_substitutions
end

#default_logs_bucket_behaviorString

Optional. Option to specify how default logs buckets are setup. Corresponds to the JSON property defaultLogsBucketBehavior

Returns:

  • (String)


2072
2073
2074
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2072

def default_logs_bucket_behavior
  @default_logs_bucket_behavior
end

#disk_size_gbFixnum

Requested disk size for the VM that runs the build. Note that this is NOT " disk free"; some of the space will be used by the operating system and build utilities. Also note that this is the minimum disk size that will be allocated for the build -- the build may run with a larger disk than requested. At present, the maximum disk size is 4000GB; builds that request more than the maximum are rejected with an error. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


2082
2083
2084
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2082

def disk_size_gb
  @disk_size_gb
end

#dynamic_substitutionsBoolean Also known as: dynamic_substitutions?

Option to specify whether or not to apply bash style string operations to the substitutions. NOTE: this is always enabled for triggered builds and cannot be overridden in the build configuration file. Corresponds to the JSON property dynamicSubstitutions

Returns:

  • (Boolean)


2089
2090
2091
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2089

def dynamic_substitutions
  @dynamic_substitutions
end

#enable_structured_loggingBoolean Also known as: enable_structured_logging?

Optional. Option to specify whether structured logging is enabled. If true, JSON-formatted logs are parsed as structured logs. Corresponds to the JSON property enableStructuredLogging

Returns:

  • (Boolean)


2096
2097
2098
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2096

def enable_structured_logging
  @enable_structured_logging
end

#envArray<String>

A list of global environment variable definitions that will exist for all build steps in this build. If a variable is defined in both globally and in a build step, the variable will use the build step value. The elements are of the form "KEY=VALUE" for the environment variable "KEY" being given the value " VALUE". Corresponds to the JSON property env

Returns:

  • (Array<String>)


2106
2107
2108
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2106

def env
  @env
end

#log_streaming_optionString

Option to define build log streaming behavior to Cloud Storage. Corresponds to the JSON property logStreamingOption

Returns:

  • (String)


2111
2112
2113
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2111

def log_streaming_option
  @log_streaming_option
end

#loggingString

Option to specify the logging mode, which determines if and where build logs are stored. Corresponds to the JSON property logging

Returns:

  • (String)


2117
2118
2119
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2117

def logging
  @logging
end

#machine_typeString

Compute Engine machine type on which to run the build. Corresponds to the JSON property machineType

Returns:

  • (String)


2122
2123
2124
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2122

def machine_type
  @machine_type
end

#poolGoogle::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptionsPoolOption

Details about how a build should be executed on a WorkerPool. See running builds in a private pool for more information. Corresponds to the JSON property pool



2129
2130
2131
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2129

def pool
  @pool
end

#pubsub_topicString

Optional. Option to specify the Pub/Sub topic to receive build status updates. Corresponds to the JSON property pubsubTopic

Returns:

  • (String)


2134
2135
2136
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2134

def pubsub_topic
  @pubsub_topic
end

#requested_verify_optionString

Requested verifiability options. Corresponds to the JSON property requestedVerifyOption

Returns:

  • (String)


2139
2140
2141
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2139

def requested_verify_option
  @requested_verify_option
end

#secret_envArray<String>

A list of global environment variables, which are encrypted using a Cloud Key Management Service crypto key. These values must be specified in the build's Secret. These variables will be available to all build steps in this build. Corresponds to the JSON property secretEnv

Returns:

  • (Array<String>)


2146
2147
2148
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2146

def secret_env
  @secret_env
end

#source_provenance_hashArray<String>

Requested hash for SourceProvenance. Corresponds to the JSON property sourceProvenanceHash

Returns:

  • (Array<String>)


2151
2152
2153
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2151

def source_provenance_hash
  @source_provenance_hash
end

#substitution_optionString

Option to specify behavior when there is an error in the substitution checks. NOTE: this is always set to ALLOW_LOOSE for triggered builds and cannot be overridden in the build configuration file. Corresponds to the JSON property substitutionOption

Returns:

  • (String)


2158
2159
2160
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2158

def substitution_option
  @substitution_option
end

#volumesArray<Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume>

Global list of volumes to mount for ALL build steps Each volume is created as an empty volume prior to starting the build process. Upon completion of the build, volumes and their contents are discarded. Global volume names and paths cannot conflict with the volumes defined a build step. Using a global volume in a build with only one step is not valid as it is indicative of a build request with an incorrect configuration. Corresponds to the JSON property volumes



2168
2169
2170
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2168

def volumes
  @volumes
end

#worker_poolString

This field deprecated; please use pool.name instead. Corresponds to the JSON property workerPool

Returns:

  • (String)


2173
2174
2175
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2173

def worker_pool
  @worker_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2180

def update!(**args)
  @automap_substitutions = args[:automap_substitutions] if args.key?(:automap_substitutions)
  @default_logs_bucket_behavior = args[:default_logs_bucket_behavior] if args.key?(:default_logs_bucket_behavior)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @dynamic_substitutions = args[:dynamic_substitutions] if args.key?(:dynamic_substitutions)
  @enable_structured_logging = args[:enable_structured_logging] if args.key?(:enable_structured_logging)
  @env = args[:env] if args.key?(:env)
  @log_streaming_option = args[:log_streaming_option] if args.key?(:log_streaming_option)
  @logging = args[:logging] if args.key?(:logging)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @pool = args[:pool] if args.key?(:pool)
  @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic)
  @requested_verify_option = args[:requested_verify_option] if args.key?(:requested_verify_option)
  @secret_env = args[:secret_env] if args.key?(:secret_env)
  @source_provenance_hash = args[:source_provenance_hash] if args.key?(:source_provenance_hash)
  @substitution_option = args[:substitution_option] if args.key?(:substitution_option)
  @volumes = args[:volumes] if args.key?(:volumes)
  @worker_pool = args[:worker_pool] if args.key?(:worker_pool)
end