Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
A step in the build pipeline.
Instance Attribute Summary collapse
-
#allow_exit_codes ⇒ Array<Fixnum>
Allow this build step to fail without failing the entire build if and only if the exit code is one of the specified codes.
-
#allow_failure ⇒ Boolean
(also: #allow_failure?)
Allow this build step to fail without failing the entire build.
-
#args ⇒ Array<String>
A list of arguments that will be presented to the step when it is started.
-
#automap_substitutions ⇒ Boolean
(also: #automap_substitutions?)
Option to include built-in and custom substitutions as env variables for this build step.
-
#dir ⇒ String
Working directory to use when running this step's container.
-
#entrypoint ⇒ String
Entrypoint to be used instead of the build step image's default entrypoint.
-
#env ⇒ Array<String>
A list of environment variable definitions to be used when running a step.
-
#exit_code ⇒ Fixnum
Output only.
-
#id ⇒ String
Unique identifier for this build step, used in
wait_forto reference this build step as a dependency. -
#name ⇒ String
Required.
-
#pull_timing ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#script ⇒ String
A shell script to be executed in the step.
-
#secret_env ⇒ Array<String>
A list of environment variables which are encrypted using a Cloud Key Management Service crypto key.
-
#status ⇒ String
Output only.
-
#timeout ⇒ String
Time limit for executing this build step.
-
#timing ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#volumes ⇒ Array<Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume>
List of volumes to mount into the build step.
-
#wait_for ⇒ Array<String>
The ID(s) of the step(s) that this build step depends on.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep.
2358 2359 2360 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2358 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_exit_codes ⇒ Array<Fixnum>
Allow this build step to fail without failing the entire build if and only if
the exit code is one of the specified codes. If allow_failure is also
specified, this field will take precedence.
Corresponds to the JSON property allowExitCodes
2227 2228 2229 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2227 def allow_exit_codes @allow_exit_codes end |
#allow_failure ⇒ Boolean Also known as: allow_failure?
Allow this build step to fail without failing the entire build. If false, the
entire build will fail if this step fails. Otherwise, the build will succeed,
but this step will still have a failure status. Error information will be
reported in the failure_detail field.
Corresponds to the JSON property allowFailure
2235 2236 2237 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2235 def allow_failure @allow_failure end |
#args ⇒ Array<String>
A list of arguments that will be presented to the step when it is started. If
the image used to run the step's container has an entrypoint, the args are
used as arguments to that entrypoint. If the image does not define an
entrypoint, the first element in args is used as the entrypoint, and the
remainder will be used as arguments.
Corresponds to the JSON property args
2245 2246 2247 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2245 def args @args end |
#automap_substitutions ⇒ Boolean Also known as: automap_substitutions?
Option to include built-in and custom substitutions as env variables for this
build step. This option will override the global option in BuildOption.
Corresponds to the JSON property automapSubstitutions
2251 2252 2253 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2251 def automap_substitutions @automap_substitutions end |
#dir ⇒ String
Working directory to use when running this step's container. If this value is
a relative path, it is relative to the build's working directory. If this
value is absolute, it may be outside the build's working directory, in which
case the contents of the path may not be persisted across build step
executions, unless a volume for that path is specified. If the build
specifies a RepoSource with dir and a step with a dir, which specifies
an absolute path, the RepoSource dir is ignored for the step's execution.
Corresponds to the JSON property dir
2263 2264 2265 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2263 def dir @dir end |
#entrypoint ⇒ String
Entrypoint to be used instead of the build step image's default entrypoint. If
unset, the image's default entrypoint is used.
Corresponds to the JSON property entrypoint
2269 2270 2271 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2269 def entrypoint @entrypoint end |
#env ⇒ Array<String>
A list of environment variable definitions to be used when running a step. The
elements are of the form "KEY=VALUE" for the environment variable "KEY" being
given the value "VALUE".
Corresponds to the JSON property env
2276 2277 2278 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2276 def env @env end |
#exit_code ⇒ Fixnum
Output only. Return code from running the step.
Corresponds to the JSON property exitCode
2281 2282 2283 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2281 def exit_code @exit_code end |
#id ⇒ String
Unique identifier for this build step, used in wait_for to reference this
build step as a dependency.
Corresponds to the JSON property id
2287 2288 2289 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2287 def id @id end |
#name ⇒ String
Required. The name of the container image that will run this particular build
step. If the image is available in the host's Docker daemon's cache, it will
be run directly. If not, the host will attempt to pull the image first, using
the builder service account's credentials if necessary. The Docker daemon's
cache will already have the latest versions of all of the officially supported
build steps (https://github.com/GoogleCloudPlatform/cloud-builders). The Docker daemon will also
have cached many of the layers for some popular images, like "ubuntu", "debian"
, but they will be refreshed at the time you attempt to use them. If you built
an image in a previous build step, it will be stored in the host's Docker
daemon's cache and is available to use as the name for a later build step.
Corresponds to the JSON property name
2302 2303 2304 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2302 def name @name end |
#pull_timing ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pullTiming
2307 2308 2309 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2307 def pull_timing @pull_timing end |
#script ⇒ String
A shell script to be executed in the step. When script is provided, the user
cannot specify the entrypoint or args.
Corresponds to the JSON property script
2313 2314 2315 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2313 def script @script end |
#secret_env ⇒ Array<String>
A list of environment variables which are encrypted using a Cloud Key
Management Service crypto key. These values must be specified in the build's
Secret.
Corresponds to the JSON property secretEnv
2320 2321 2322 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2320 def secret_env @secret_env end |
#status ⇒ String
Output only. Status of the build step. At this time, build step status is only
updated on build completion; step status is not updated in real-time as the
build progresses.
Corresponds to the JSON property status
2327 2328 2329 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2327 def status @status end |
#timeout ⇒ String
Time limit for executing this build step. If not defined, the step has no time
limit and will be allowed to continue to run until either it completes or the
build itself times out.
Corresponds to the JSON property timeout
2334 2335 2336 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2334 def timeout @timeout end |
#timing ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property timing
2339 2340 2341 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2339 def timing @timing end |
#volumes ⇒ Array<Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume>
List of volumes to mount into the build step. Each volume is created as an
empty volume prior to execution of the build step. Upon completion of the
build, volumes and their contents are discarded. Using a named volume in only
one step is not valid as it is indicative of a build request with an incorrect
configuration.
Corresponds to the JSON property volumes
2348 2349 2350 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2348 def volumes @volumes end |
#wait_for ⇒ Array<String>
The ID(s) of the step(s) that this build step depends on. This build step will
not start until all the build steps in wait_for have completed successfully.
If wait_for is empty, this build step will start when all previous build
steps in the Build.Steps list have completed successfully.
Corresponds to the JSON property waitFor
2356 2357 2358 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2356 def wait_for @wait_for end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2363 def update!(**args) @allow_exit_codes = args[:allow_exit_codes] if args.key?(:allow_exit_codes) @allow_failure = args[:allow_failure] if args.key?(:allow_failure) @args = args[:args] if args.key?(:args) @automap_substitutions = args[:automap_substitutions] if args.key?(:automap_substitutions) @dir = args[:dir] if args.key?(:dir) @entrypoint = args[:entrypoint] if args.key?(:entrypoint) @env = args[:env] if args.key?(:env) @exit_code = args[:exit_code] if args.key?(:exit_code) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @pull_timing = args[:pull_timing] if args.key?(:pull_timing) @script = args[:script] if args.key?(:script) @secret_env = args[:secret_env] if args.key?(:secret_env) @status = args[:status] if args.key?(:status) @timeout = args[:timeout] if args.key?(:timeout) @timing = args[:timing] if args.key?(:timing) @volumes = args[:volumes] if args.key?(:volumes) @wait_for = args[:wait_for] if args.key?(:wait_for) end |