Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

An image built by the pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage.



2491
2492
2493
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


2467
2468
2469
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2467

def artifact_registry_package
  @artifact_registry_package
end

#digestString

Docker Registry 2.0 digest. Corresponds to the JSON property digest

Returns:

  • (String)


2472
2473
2474
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2472

def digest
  @digest
end

#nameString

Name used to push the container image to Google Container Registry, as presented to docker push. Corresponds to the JSON property name

Returns:

  • (String)


2478
2479
2480
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2478

def name
  @name
end

#oci_media_typeString

Output only. The OCI media type of the artifact. Non-OCI images, such as Docker images, will have an unspecified value. Corresponds to the JSON property ociMediaType

Returns:

  • (String)


2484
2485
2486
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2484

def oci_media_type
  @oci_media_type
end

#push_timingGoogle::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



2489
2490
2491
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2489

def push_timing
  @push_timing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2496
2497
2498
2499
2500
2501
2502
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2496

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @digest = args[:digest] if args.key?(:digest)
  @name = args[:name] if args.key?(:name)
  @oci_media_type = args[:oci_media_type] if args.key?(:oci_media_type)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
end