Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A dependency that the Cloud Build worker will fetch before executing user steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency.



2555
2556
2557
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emptyBoolean Also known as: empty?

If set to true disable all dependency fetching (ignoring the default source as well). Corresponds to the JSON property empty

Returns:

  • (Boolean)


2547
2548
2549
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2547

def empty
  @empty
end

#git_sourceGoogle::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Represents a git repository as a build dependency. Corresponds to the JSON property gitSource



2553
2554
2555
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2553

def git_source
  @git_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2560
2561
2562
2563
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2560

def update!(**args)
  @empty = args[:empty] if args.key?(:empty)
  @git_source = args[:git_source] if args.key?(:git_source)
end