Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Represents a git repository as a build dependency.
Instance Attribute Summary collapse
-
#depth ⇒ Fixnum
Optional.
-
#dest_path ⇒ String
Required.
-
#recurse_submodules ⇒ Boolean
(also: #recurse_submodules?)
Optional.
-
#repository ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceRepository
A repository for a git source.
-
#revision ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency.
2540 2541 2542 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#depth ⇒ Fixnum
Optional. How much history should be fetched for the build (default 1, -1 for
all history).
Corresponds to the JSON property depth
2517 2518 2519 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2517 def depth @depth end |
#dest_path ⇒ String
Required. Where should the files be placed on the worker.
Corresponds to the JSON property destPath
2522 2523 2524 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2522 def dest_path @dest_path end |
#recurse_submodules ⇒ Boolean Also known as: recurse_submodules?
Optional. True if submodules should be fetched too (default false).
Corresponds to the JSON property recurseSubmodules
2527 2528 2529 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2527 def recurse_submodules @recurse_submodules end |
#repository ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceRepository
A repository for a git source.
Corresponds to the JSON property repository
2533 2534 2535 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2533 def repository @repository end |
#revision ⇒ String
Required. The revision that we will fetch the repo at.
Corresponds to the JSON property revision
2538 2539 2540 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2538 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2545 2546 2547 2548 2549 2550 2551 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2545 def update!(**args) @depth = args[:depth] if args.key?(:depth) @dest_path = args[:dest_path] if args.key?(:dest_path) @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules) @repository = args[:repository] if args.key?(:repository) @revision = args[:revision] if args.key?(:revision) end |