Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Location of the source in a Google Cloud Source Repository.
Instance Attribute Summary collapse
-
#branch_name ⇒ String
Regex matching branches to build.
-
#commit_sha ⇒ String
Explicit commit SHA to build.
-
#dir ⇒ String
Optional.
-
#invert_regex ⇒ Boolean
(also: #invert_regex?)
Optional.
-
#project_id ⇒ String
Optional.
-
#repo_name ⇒ String
Required.
-
#substitutions ⇒ Hash<String,String>
Optional.
-
#tag_name ⇒ String
Regex matching tags to build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource.
3013 3014 3015 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3013 def initialize(**args) update!(**args) end |
Instance Attribute Details
#branch_name ⇒ String
Regex matching branches to build. The syntax of the regular expressions
accepted is the syntax accepted by RE2 and described at https://github.com/
google/re2/wiki/Syntax
Corresponds to the JSON property branchName
2968 2969 2970 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2968 def branch_name @branch_name end |
#commit_sha ⇒ String
Explicit commit SHA to build.
Corresponds to the JSON property commitSha
2973 2974 2975 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2973 def commit_sha @commit_sha end |
#dir ⇒ String
Optional. Directory, relative to the source root, in which to run the build.
This must be a relative path. If a step's dir is specified and is an
absolute path, this value is ignored for that step's execution.
Corresponds to the JSON property dir
2980 2981 2982 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2980 def dir @dir end |
#invert_regex ⇒ Boolean Also known as: invert_regex?
Optional. Only trigger a build if the revision regex does NOT match the
revision regex.
Corresponds to the JSON property invertRegex
2986 2987 2988 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2986 def invert_regex @invert_regex end |
#project_id ⇒ String
Optional. ID of the project that owns the Cloud Source Repository. If omitted,
the project ID requesting the build is assumed.
Corresponds to the JSON property projectId
2993 2994 2995 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2993 def project_id @project_id end |
#repo_name ⇒ String
Required. Name of the Cloud Source Repository.
Corresponds to the JSON property repoName
2998 2999 3000 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 2998 def repo_name @repo_name end |
#substitutions ⇒ Hash<String,String>
Optional. Substitutions to use in a triggered build. Should only be used with
RunBuildTrigger
Corresponds to the JSON property substitutions
3004 3005 3006 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3004 def substitutions @substitutions end |
#tag_name ⇒ String
Regex matching tags to build. The syntax of the regular expressions accepted
is the syntax accepted by RE2 and described at https://github.com/google/re2/
wiki/Syntax
Corresponds to the JSON property tagName
3011 3012 3013 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3011 def tag_name @tag_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3018 def update!(**args) @branch_name = args[:branch_name] if args.key?(:branch_name) @commit_sha = args[:commit_sha] if args.key?(:commit_sha) @dir = args[:dir] if args.key?(:dir) @invert_regex = args[:invert_regex] if args.key?(:invert_regex) @project_id = args[:project_id] if args.key?(:project_id) @repo_name = args[:repo_name] if args.key?(:repo_name) @substitutions = args[:substitutions] if args.key?(:substitutions) @tag_name = args[:tag_name] if args.key?(:tag_name) end |