Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Provenance of the source. Ways to find the original source, or verify that some source was used for this build.
Instance Attribute Summary collapse
-
#file_hashes ⇒ Hash<String,Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes>
Output only.
-
#resolved_connected_repository ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
-
#resolved_git_source ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1GitSource
Location of the source in any accessible Git repository.
-
#resolved_repo_source ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource
Location of the source in a Google Cloud Source Repository.
-
#resolved_storage_source ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
Location of the source in an archive file in Cloud Storage.
-
#resolved_storage_source_manifest ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSourceManifest
Location of the source manifest in Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance.
3354 3355 3356 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3354 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_hashes ⇒ Hash<String,Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes>
Output only. Hash(es) of the build source, which can be used to verify that
the original source integrity was maintained in the build. Note that
FileHashes will only be populated if BuildOptions has requested a
SourceProvenanceHash. The keys to this map are file paths used as build
source and the values contain the hash values for those files. If the build
source came in a single package such as a gzipped tarfile (.tar.gz), the
FileHash will be for the single path to that file.
Corresponds to the JSON property fileHashes
3325 3326 3327 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3325 def file_hashes @file_hashes end |
#resolved_connected_repository ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
Corresponds to the JSON property resolvedConnectedRepository
3330 3331 3332 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3330 def resolved_connected_repository @resolved_connected_repository end |
#resolved_git_source ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1GitSource
Location of the source in any accessible Git repository.
Corresponds to the JSON property resolvedGitSource
3335 3336 3337 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3335 def resolved_git_source @resolved_git_source end |
#resolved_repo_source ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource
Location of the source in a Google Cloud Source Repository.
Corresponds to the JSON property resolvedRepoSource
3340 3341 3342 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3340 def resolved_repo_source @resolved_repo_source end |
#resolved_storage_source ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
Location of the source in an archive file in Cloud Storage.
Corresponds to the JSON property resolvedStorageSource
3345 3346 3347 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3345 def resolved_storage_source @resolved_storage_source end |
#resolved_storage_source_manifest ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSourceManifest
Location of the source manifest in Cloud Storage. This feature is in Preview;
see description here.
Corresponds to the JSON property resolvedStorageSourceManifest
3352 3353 3354 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3352 def resolved_storage_source_manifest @resolved_storage_source_manifest end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3359 3360 3361 3362 3363 3364 3365 3366 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3359 def update!(**args) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @resolved_connected_repository = args[:resolved_connected_repository] if args.key?(:resolved_connected_repository) @resolved_git_source = args[:resolved_git_source] if args.key?(:resolved_git_source) @resolved_repo_source = args[:resolved_repo_source] if args.key?(:resolved_repo_source) @resolved_storage_source = args[:resolved_storage_source] if args.key?(:resolved_storage_source) @resolved_storage_source_manifest = args[:resolved_storage_source_manifest] if args.key?(:resolved_storage_source_manifest) end |