Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Location of the source in an archive file in Cloud Storage.
Instance Attribute Summary collapse
-
#bucket ⇒ String
Cloud Storage bucket containing the source (see Bucket Name Requirements).
-
#generation ⇒ Fixnum
Optional.
-
#object ⇒ String
Required.
-
#source_fetcher ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource.
3198 3199 3200 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket ⇒ String
Cloud Storage bucket containing the source (see Bucket Name Requirements).
Corresponds to the JSON property bucket
3179 3180 3181 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3179 def bucket @bucket end |
#generation ⇒ Fixnum
Optional. Cloud Storage generation for the object. If the generation is
omitted, the latest generation will be used.
Corresponds to the JSON property generation
3185 3186 3187 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3185 def generation @generation end |
#object ⇒ String
Required. Cloud Storage object containing the source. This object must be a
zipped (.zip) or gzipped archive file (.tar.gz) containing source to build.
Corresponds to the JSON property object
3191 3192 3193 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3191 def object @object end |
#source_fetcher ⇒ String
Optional. Option to specify the tool to fetch the source file for the build.
Corresponds to the JSON property sourceFetcher
3196 3197 3198 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3196 def source_fetcher @source_fetcher end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3203 3204 3205 3206 3207 3208 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3203 def update!(**args) @bucket = args[:bucket] if args.key?(:bucket) @generation = args[:generation] if args.key?(:generation) @object = args[:object] if args.key?(:object) @source_fetcher = args[:source_fetcher] if args.key?(:source_fetcher) end |