Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A generic artifact uploaded to Artifact Registry using the GenericArtifact directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact.



3481
3482
3483
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_fingerprintGoogle::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property artifactFingerprint



3458
3459
3460
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3458

def artifact_fingerprint
  @artifact_fingerprint
end

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


3463
3464
3465
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3463

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesHash<String,Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes>

Output only. The file hashes that make up the generic artifact. Corresponds to the JSON property fileHashes



3468
3469
3470
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3468

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



3473
3474
3475
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3473

def push_timing
  @push_timing
end

#uriString

Output only. URI of the uploaded artifact. Ex: projects/p1/locations/us/ repositories/r1/packages/p1/versions/v1 Corresponds to the JSON property uri

Returns:

  • (String)


3479
3480
3481
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3479

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3486
3487
3488
3489
3490
3491
3492
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3486

def update!(**args)
  @artifact_fingerprint = args[:artifact_fingerprint] if args.key?(:artifact_fingerprint)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end