Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
An npm package uploaded to Artifact Registry using the NpmPackage directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded npm package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage.
3597 3598 3599 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3597 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
3579 3580 3581 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3579 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
3585 3586 3587 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3585 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
3590 3591 3592 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3590 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded npm package.
Corresponds to the JSON property uri
3595 3596 3597 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3595 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3602 3603 3604 3605 3606 3607 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3602 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |