Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Artifact uploaded using the PythonPackage directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage.



3356
3357
3358
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3356

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


3338
3339
3340
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3338

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



3344
3345
3346
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3344

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



3349
3350
3351
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3349

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


3354
3355
3356
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3354

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3361
3362
3363
3364
3365
3366
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3361

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end