Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Volume describes a Docker container volume which is mounted into build steps in order to persist files across build step execution.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the volume to mount.
-
#path ⇒ String
Path at which to mount the volume.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Volume
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Volume.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Volume
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Volume.
3714 3715 3716 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3714 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the volume to mount. Volume names must be unique per build step and
must be valid names for Docker volumes. Each named volume must be used by at
least two build steps.
Corresponds to the JSON property name
3705 3706 3707 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3705 def name @name end |
#path ⇒ String
Path at which to mount the volume. Paths must be absolute and cannot conflict
with other volume paths on the same build step or with certain reserved volume
paths.
Corresponds to the JSON property path
3712 3713 3714 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3712 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3719 3720 3721 3722 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3719 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) end |