Class: Google::Apis::ContaineranalysisV1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Volume describes a Docker container volume which is mounted into build steps in order to persist files across build step execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Volume

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Volume.



3394
3395
3396
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3394

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the volume to mount. Volume names must be unique per build step and must be valid names for Docker volumes. Each named volume must be used by at least two build steps. Corresponds to the JSON property name

Returns:

  • (String)


3385
3386
3387
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3385

def name
  @name
end

#pathString

Path at which to mount the volume. Paths must be absolute and cannot conflict with other volume paths on the same build step or with certain reserved volume paths. Corresponds to the JSON property path

Returns:

  • (String)


3392
3393
3394
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3392

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3399
3400
3401
3402
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3399

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
end