Class: Google::Apis::ContaineranalysisV1::CvsSv3

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Common Vulnerability Scoring System version 3. For details, see https://www. first.org/cvss/specification-document

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CvsSv3

Returns a new instance of CvsSv3.



1120
1121
1122
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1120

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attack_complexityString

Corresponds to the JSON property attackComplexity

Returns:

  • (String)


1067
1068
1069
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1067

def attack_complexity
  @attack_complexity
end

#attack_vectorString

Base Metrics Represents the intrinsic characteristics of a vulnerability that are constant over time and across user environments. Corresponds to the JSON property attackVector

Returns:

  • (String)


1073
1074
1075
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1073

def attack_vector
  @attack_vector
end

#availability_impactString

Corresponds to the JSON property availabilityImpact

Returns:

  • (String)


1078
1079
1080
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1078

def availability_impact
  @availability_impact
end

#base_scoreFloat

The base score is a function of the base metric scores. Corresponds to the JSON property baseScore

Returns:

  • (Float)


1083
1084
1085
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1083

def base_score
  @base_score
end

#confidentiality_impactString

Corresponds to the JSON property confidentialityImpact

Returns:

  • (String)


1088
1089
1090
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1088

def confidentiality_impact
  @confidentiality_impact
end

#exploitability_scoreFloat

Corresponds to the JSON property exploitabilityScore

Returns:

  • (Float)


1093
1094
1095
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1093

def exploitability_score
  @exploitability_score
end

#impact_scoreFloat

Corresponds to the JSON property impactScore

Returns:

  • (Float)


1098
1099
1100
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1098

def impact_score
  @impact_score
end

#integrity_impactString

Corresponds to the JSON property integrityImpact

Returns:

  • (String)


1103
1104
1105
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1103

def integrity_impact
  @integrity_impact
end

#privileges_requiredString

Corresponds to the JSON property privilegesRequired

Returns:

  • (String)


1108
1109
1110
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1108

def privileges_required
  @privileges_required
end

#scopeString

Corresponds to the JSON property scope

Returns:

  • (String)


1113
1114
1115
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1113

def scope
  @scope
end

#user_interactionString

Corresponds to the JSON property userInteraction

Returns:

  • (String)


1118
1119
1120
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1118

def user_interaction
  @user_interaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 1125

def update!(**args)
  @attack_complexity = args[:attack_complexity] if args.key?(:attack_complexity)
  @attack_vector = args[:attack_vector] if args.key?(:attack_vector)
  @availability_impact = args[:availability_impact] if args.key?(:availability_impact)
  @base_score = args[:base_score] if args.key?(:base_score)
  @confidentiality_impact = args[:confidentiality_impact] if args.key?(:confidentiality_impact)
  @exploitability_score = args[:exploitability_score] if args.key?(:exploitability_score)
  @impact_score = args[:impact_score] if args.key?(:impact_score)
  @integrity_impact = args[:integrity_impact] if args.key?(:integrity_impact)
  @privileges_required = args[:privileges_required] if args.key?(:privileges_required)
  @scope = args[:scope] if args.key?(:scope)
  @user_interaction = args[:user_interaction] if args.key?(:user_interaction)
end