Class: Google::Apis::ContaineranalysisV1::DeploymentOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

The period during which some deployable was active in a runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeploymentOccurrence

Returns a new instance of DeploymentOccurrence.



3862
3863
3864
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Address of the runtime element hosting this deployment. Corresponds to the JSON property address

Returns:

  • (String)


3829
3830
3831
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3829

def address
  @address
end

#configString

Configuration used to create this deployment. Corresponds to the JSON property config

Returns:

  • (String)


3834
3835
3836
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3834

def config
  @config
end

#deploy_timeString

Required. Beginning of the lifetime of this deployment. Corresponds to the JSON property deployTime

Returns:

  • (String)


3839
3840
3841
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3839

def deploy_time
  @deploy_time
end

#platformString

Platform hosting this deployment. Corresponds to the JSON property platform

Returns:

  • (String)


3844
3845
3846
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3844

def platform
  @platform
end

#resource_uriArray<String>

Output only. Resource URI for the artifact being deployed taken from the deployable field with the same name. Corresponds to the JSON property resourceUri

Returns:

  • (Array<String>)


3850
3851
3852
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3850

def resource_uri
  @resource_uri
end

#undeploy_timeString

End of the lifetime of this deployment. Corresponds to the JSON property undeployTime

Returns:

  • (String)


3855
3856
3857
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3855

def undeploy_time
  @undeploy_time
end

#user_emailString

Identity of the user that triggered this deployment. Corresponds to the JSON property userEmail

Returns:

  • (String)


3860
3861
3862
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3860

def user_email
  @user_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3867
3868
3869
3870
3871
3872
3873
3874
3875
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3867

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @config = args[:config] if args.key?(:config)
  @deploy_time = args[:deploy_time] if args.key?(:deploy_time)
  @platform = args[:platform] if args.key?(:platform)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time)
  @user_email = args[:user_email] if args.key?(:user_email)
end