Class: Google::Apis::ContaineranalysisV1::DeploymentOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::DeploymentOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
The period during which some deployable was active in a runtime.
Instance Attribute Summary collapse
-
#address ⇒ String
Address of the runtime element hosting this deployment.
-
#config ⇒ String
Configuration used to create this deployment.
-
#deploy_time ⇒ String
Required.
-
#platform ⇒ String
Platform hosting this deployment.
-
#resource_uri ⇒ Array<String>
Output only.
-
#undeploy_time ⇒ String
End of the lifetime of this deployment.
-
#user_email ⇒ String
Identity of the user that triggered this deployment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeploymentOccurrence
constructor
A new instance of DeploymentOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeploymentOccurrence
Returns a new instance of DeploymentOccurrence.
3536 3537 3538 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3536 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Address of the runtime element hosting this deployment.
Corresponds to the JSON property address
3503 3504 3505 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3503 def address @address end |
#config ⇒ String
Configuration used to create this deployment.
Corresponds to the JSON property config
3508 3509 3510 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3508 def config @config end |
#deploy_time ⇒ String
Required. Beginning of the lifetime of this deployment.
Corresponds to the JSON property deployTime
3513 3514 3515 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3513 def deploy_time @deploy_time end |
#platform ⇒ String
Platform hosting this deployment.
Corresponds to the JSON property platform
3518 3519 3520 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3518 def platform @platform end |
#resource_uri ⇒ Array<String>
Output only. Resource URI for the artifact being deployed taken from the
deployable field with the same name.
Corresponds to the JSON property resourceUri
3524 3525 3526 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3524 def resource_uri @resource_uri end |
#undeploy_time ⇒ String
End of the lifetime of this deployment.
Corresponds to the JSON property undeployTime
3529 3530 3531 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3529 def undeploy_time @undeploy_time end |
#user_email ⇒ String
Identity of the user that triggered this deployment.
Corresponds to the JSON property userEmail
3534 3535 3536 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3534 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3541 3542 3543 3544 3545 3546 3547 3548 3549 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3541 def update!(**args) @address = args[:address] if args.key?(:address) @config = args[:config] if args.key?(:config) @deploy_time = args[:deploy_time] if args.key?(:deploy_time) @platform = args[:platform] if args.key?(:platform) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time) @user_email = args[:user_email] if args.key?(:user_email) end |