Class: Google::Apis::ContaineranalysisV1::DiscoveryOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Provides information about the analysis status of a discovered resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveryOccurrence

Returns a new instance of DiscoveryOccurrence.



4106
4107
4108
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_completedGoogle::Apis::ContaineranalysisV1::AnalysisCompleted

Indicates which analysis completed successfully. Multiple types of analysis can be performed on a single resource. Corresponds to the JSON property analysisCompleted



4047
4048
4049
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4047

def analysis_completed
  @analysis_completed
end

#analysis_errorArray<Google::Apis::ContaineranalysisV1::Status>

Indicates any errors encountered during analysis of a resource. There could be 0 or more of these errors. Corresponds to the JSON property analysisError



4053
4054
4055
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4053

def analysis_error
  @analysis_error
end

#analysis_statusString

The status of discovery for the resource. Corresponds to the JSON property analysisStatus

Returns:

  • (String)


4058
4059
4060
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4058

def analysis_status
  @analysis_status
end

#analysis_status_errorGoogle::Apis::ContaineranalysisV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property analysisStatusError



4068
4069
4070
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4068

def analysis_status_error
  @analysis_status_error
end

#archive_timeString

Output only. The time occurrences related to this discovery occurrence were archived. Corresponds to the JSON property archiveTime

Returns:

  • (String)


4074
4075
4076
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4074

def archive_time
  @archive_time
end

#continuous_analysisString

Whether the resource is continuously analyzed. Corresponds to the JSON property continuousAnalysis

Returns:

  • (String)


4079
4080
4081
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4079

def continuous_analysis
  @continuous_analysis
end

#cpeString

The CPE of the resource being scanned. Corresponds to the JSON property cpe

Returns:

  • (String)


4084
4085
4086
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4084

def cpe
  @cpe
end

#filesArray<Google::Apis::ContaineranalysisV1::File>

Files that make up the resource described by the occurrence. Corresponds to the JSON property files



4089
4090
4091
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4089

def files
  @files
end

#last_scan_timeString

The last time this resource was scanned. Corresponds to the JSON property lastScanTime

Returns:

  • (String)


4094
4095
4096
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4094

def last_scan_time
  @last_scan_time
end

#last_vulnerability_update_timeString

The last time vulnerability scan results changed. Corresponds to the JSON property lastVulnerabilityUpdateTime

Returns:

  • (String)


4099
4100
4101
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4099

def last_vulnerability_update_time
  @last_vulnerability_update_time
end

#sbom_statusGoogle::Apis::ContaineranalysisV1::SbomStatus

The status of an SBOM generation. Corresponds to the JSON property sbomStatus



4104
4105
4106
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4104

def sbom_status
  @sbom_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4111
4112
4113
4114
4115
4116
4117
4118
4119
4120
4121
4122
4123
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4111

def update!(**args)
  @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed)
  @analysis_error = args[:analysis_error] if args.key?(:analysis_error)
  @analysis_status = args[:analysis_status] if args.key?(:analysis_status)
  @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error)
  @archive_time = args[:archive_time] if args.key?(:archive_time)
  @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis)
  @cpe = args[:cpe] if args.key?(:cpe)
  @files = args[:files] if args.key?(:files)
  @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time)
  @last_vulnerability_update_time = args[:last_vulnerability_update_time] if args.key?(:last_vulnerability_update_time)
  @sbom_status = args[:sbom_status] if args.key?(:sbom_status)
end