Class: Google::Apis::ContaineranalysisV1::DiscoveryOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::DiscoveryOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Provides information about the analysis status of a discovered resource.
Instance Attribute Summary collapse
-
#analysis_completed ⇒ Google::Apis::ContaineranalysisV1::AnalysisCompleted
Indicates which analysis completed successfully.
-
#analysis_error ⇒ Array<Google::Apis::ContaineranalysisV1::Status>
Indicates any errors encountered during analysis of a resource.
-
#analysis_status ⇒ String
The status of discovery for the resource.
-
#analysis_status_error ⇒ Google::Apis::ContaineranalysisV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#archive_time ⇒ String
Output only.
-
#continuous_analysis ⇒ String
Whether the resource is continuously analyzed.
-
#cpe ⇒ String
The CPE of the resource being scanned.
-
#files ⇒ Array<Google::Apis::ContaineranalysisV1::File>
Files that make up the resource described by the occurrence.
-
#last_scan_time ⇒ String
The last time this resource was scanned.
-
#last_vulnerability_update_time ⇒ String
The last time vulnerability scan results changed.
-
#sbom_status ⇒ Google::Apis::ContaineranalysisV1::SbomStatus
The status of an SBOM generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiscoveryOccurrence
constructor
A new instance of DiscoveryOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiscoveryOccurrence
Returns a new instance of DiscoveryOccurrence.
4053 4054 4055 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_completed ⇒ Google::Apis::ContaineranalysisV1::AnalysisCompleted
Indicates which analysis completed successfully. Multiple types of analysis
can be performed on a single resource.
Corresponds to the JSON property analysisCompleted
3994 3995 3996 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3994 def analysis_completed @analysis_completed end |
#analysis_error ⇒ Array<Google::Apis::ContaineranalysisV1::Status>
Indicates any errors encountered during analysis of a resource. There could be
0 or more of these errors.
Corresponds to the JSON property analysisError
4000 4001 4002 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4000 def analysis_error @analysis_error end |
#analysis_status ⇒ String
The status of discovery for the resource.
Corresponds to the JSON property analysisStatus
4005 4006 4007 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4005 def analysis_status @analysis_status end |
#analysis_status_error ⇒ Google::Apis::ContaineranalysisV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property analysisStatusError
4015 4016 4017 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4015 def analysis_status_error @analysis_status_error end |
#archive_time ⇒ String
Output only. The time occurrences related to this discovery occurrence were
archived.
Corresponds to the JSON property archiveTime
4021 4022 4023 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4021 def archive_time @archive_time end |
#continuous_analysis ⇒ String
Whether the resource is continuously analyzed.
Corresponds to the JSON property continuousAnalysis
4026 4027 4028 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4026 def continuous_analysis @continuous_analysis end |
#cpe ⇒ String
The CPE of the resource being scanned.
Corresponds to the JSON property cpe
4031 4032 4033 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4031 def cpe @cpe end |
#files ⇒ Array<Google::Apis::ContaineranalysisV1::File>
Files that make up the resource described by the occurrence.
Corresponds to the JSON property files
4036 4037 4038 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4036 def files @files end |
#last_scan_time ⇒ String
The last time this resource was scanned.
Corresponds to the JSON property lastScanTime
4041 4042 4043 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4041 def last_scan_time @last_scan_time end |
#last_vulnerability_update_time ⇒ String
The last time vulnerability scan results changed.
Corresponds to the JSON property lastVulnerabilityUpdateTime
4046 4047 4048 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4046 def last_vulnerability_update_time @last_vulnerability_update_time end |
#sbom_status ⇒ Google::Apis::ContaineranalysisV1::SbomStatus
The status of an SBOM generation.
Corresponds to the JSON property sbomStatus
4051 4052 4053 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4051 def sbom_status @sbom_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4058 4059 4060 4061 4062 4063 4064 4065 4066 4067 4068 4069 4070 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4058 def update!(**args) @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed) @analysis_error = args[:analysis_error] if args.key?(:analysis_error) @analysis_status = args[:analysis_status] if args.key?(:analysis_status) @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error) @archive_time = args[:archive_time] if args.key?(:archive_time) @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis) @cpe = args[:cpe] if args.key?(:cpe) @files = args[:files] if args.key?(:files) @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time) @last_vulnerability_update_time = args[:last_vulnerability_update_time] if args.key?(:last_vulnerability_update_time) @sbom_status = args[:sbom_status] if args.key?(:sbom_status) end |