Class: Google::Apis::ContaineranalysisV1::DiscoveryOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Provides information about the analysis status of a discovered resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveryOccurrence

Returns a new instance of DiscoveryOccurrence.



3769
3770
3771
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_completedGoogle::Apis::ContaineranalysisV1::AnalysisCompleted

Indicates which analysis completed successfully. Multiple types of analysis can be performed on a single resource. Corresponds to the JSON property analysisCompleted



3715
3716
3717
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3715

def analysis_completed
  @analysis_completed
end

#analysis_errorArray<Google::Apis::ContaineranalysisV1::Status>

Indicates any errors encountered during analysis of a resource. There could be 0 or more of these errors. Corresponds to the JSON property analysisError



3721
3722
3723
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3721

def analysis_error
  @analysis_error
end

#analysis_statusString

The status of discovery for the resource. Corresponds to the JSON property analysisStatus

Returns:

  • (String)


3726
3727
3728
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3726

def analysis_status
  @analysis_status
end

#analysis_status_errorGoogle::Apis::ContaineranalysisV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property analysisStatusError



3736
3737
3738
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3736

def analysis_status_error
  @analysis_status_error
end

#archive_timeString

Output only. The time occurrences related to this discovery occurrence were archived. Corresponds to the JSON property archiveTime

Returns:

  • (String)


3742
3743
3744
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3742

def archive_time
  @archive_time
end

#continuous_analysisString

Whether the resource is continuously analyzed. Corresponds to the JSON property continuousAnalysis

Returns:

  • (String)


3747
3748
3749
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3747

def continuous_analysis
  @continuous_analysis
end

#cpeString

The CPE of the resource being scanned. Corresponds to the JSON property cpe

Returns:

  • (String)


3752
3753
3754
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3752

def cpe
  @cpe
end

#filesArray<Google::Apis::ContaineranalysisV1::File>

Files that make up the resource described by the occurrence. Corresponds to the JSON property files



3757
3758
3759
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3757

def files
  @files
end

#last_scan_timeString

The last time this resource was scanned. Corresponds to the JSON property lastScanTime

Returns:

  • (String)


3762
3763
3764
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3762

def last_scan_time
  @last_scan_time
end

#sbom_statusGoogle::Apis::ContaineranalysisV1::SbomStatus

The status of an SBOM generation. Corresponds to the JSON property sbomStatus



3767
3768
3769
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3767

def sbom_status
  @sbom_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3774

def update!(**args)
  @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed)
  @analysis_error = args[:analysis_error] if args.key?(:analysis_error)
  @analysis_status = args[:analysis_status] if args.key?(:analysis_status)
  @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error)
  @archive_time = args[:archive_time] if args.key?(:archive_time)
  @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis)
  @cpe = args[:cpe] if args.key?(:cpe)
  @files = args[:files] if args.key?(:files)
  @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time)
  @sbom_status = args[:sbom_status] if args.key?(:sbom_status)
end