Class: Google::Apis::ContaineranalysisV1::Distribution

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

This represents a particular channel of distribution for a given package. E.g., Debian's jessie-backports dpkg mirror.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Distribution

Returns a new instance of Distribution.



4110
4111
4112
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The CPU architecture for which packages in this distribution channel were built. Corresponds to the JSON property architecture

Returns:

  • (String)


4082
4083
4084
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4082

def architecture
  @architecture
end

#cpe_uriString

Required. The cpe_uri in CPE format denoting the package manager version distributing a package. Corresponds to the JSON property cpeUri

Returns:

  • (String)


4088
4089
4090
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4088

def cpe_uri
  @cpe_uri
end

#descriptionString

The distribution channel-specific description of this package. Corresponds to the JSON property description

Returns:

  • (String)


4093
4094
4095
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4093

def description
  @description
end

#latest_versionGoogle::Apis::ContaineranalysisV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property latestVersion



4098
4099
4100
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4098

def latest_version
  @latest_version
end

#maintainerString

A freeform string denoting the maintainer of this package. Corresponds to the JSON property maintainer

Returns:

  • (String)


4103
4104
4105
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4103

def maintainer
  @maintainer
end

#urlString

The distribution channel-specific homepage for this package. Corresponds to the JSON property url

Returns:

  • (String)


4108
4109
4110
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4108

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4115
4116
4117
4118
4119
4120
4121
4122
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4115

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @description = args[:description] if args.key?(:description)
  @latest_version = args[:latest_version] if args.key?(:latest_version)
  @maintainer = args[:maintainer] if args.key?(:maintainer)
  @url = args[:url] if args.key?(:url)
end