Class: Google::Apis::ContaineranalysisV1::Distribution

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

This represents a particular channel of distribution for a given package. E.g., Debian's jessie-backports dpkg mirror.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Distribution

Returns a new instance of Distribution.



3837
3838
3839
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3837

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The CPU architecture for which packages in this distribution channel were built. Corresponds to the JSON property architecture

Returns:

  • (String)


3809
3810
3811
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3809

def architecture
  @architecture
end

#cpe_uriString

Required. The cpe_uri in CPE format denoting the package manager version distributing a package. Corresponds to the JSON property cpeUri

Returns:

  • (String)


3815
3816
3817
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3815

def cpe_uri
  @cpe_uri
end

#descriptionString

The distribution channel-specific description of this package. Corresponds to the JSON property description

Returns:

  • (String)


3820
3821
3822
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3820

def description
  @description
end

#latest_versionGoogle::Apis::ContaineranalysisV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property latestVersion



3825
3826
3827
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3825

def latest_version
  @latest_version
end

#maintainerString

A freeform string denoting the maintainer of this package. Corresponds to the JSON property maintainer

Returns:

  • (String)


3830
3831
3832
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3830

def maintainer
  @maintainer
end

#urlString

The distribution channel-specific homepage for this package. Corresponds to the JSON property url

Returns:

  • (String)


3835
3836
3837
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3835

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3842
3843
3844
3845
3846
3847
3848
3849
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3842

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @description = args[:description] if args.key?(:description)
  @latest_version = args[:latest_version] if args.key?(:latest_version)
  @maintainer = args[:maintainer] if args.key?(:maintainer)
  @url = args[:url] if args.key?(:url)
end