Class: Google::Apis::ContaineranalysisV1::DsseAttestationNote
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::DsseAttestationNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Instance Attribute Summary collapse
-
#hint ⇒ Google::Apis::ContaineranalysisV1::DsseHint
This submessage provides human-readable hints about the purpose of the authority.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DsseAttestationNote
constructor
A new instance of DsseAttestationNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DsseAttestationNote
Returns a new instance of DsseAttestationNote.
3692 3693 3694 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3692 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hint ⇒ Google::Apis::ContaineranalysisV1::DsseHint
This submessage provides human-readable hints about the purpose of the
authority. Because the name of a note acts as its resource reference, it is
important to disambiguate the canonical name of the Note (which might be a
UUID for security purposes) from "readable" names more suitable for debug
output. Note that these hints should not be used to look up authorities in
security sensitive contexts, such as when looking up attestations to verify.
Corresponds to the JSON property hint
3690 3691 3692 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3690 def hint @hint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3697 3698 3699 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3697 def update!(**args) @hint = args[:hint] if args.key?(:hint) end |