Class: Google::Apis::ContaineranalysisV1::DsseAttestationNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DsseAttestationNote

Returns a new instance of DsseAttestationNote.



3413
3414
3415
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hintGoogle::Apis::ContaineranalysisV1::DsseHint

This submessage provides human-readable hints about the purpose of the authority. Because the name of a note acts as its resource reference, it is important to disambiguate the canonical name of the Note (which might be a UUID for security purposes) from "readable" names more suitable for debug output. Note that these hints should not be used to look up authorities in security sensitive contexts, such as when looking up attestations to verify. Corresponds to the JSON property hint



3411
3412
3413
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3411

def hint
  @hint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3418
3419
3420
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3418

def update!(**args)
  @hint = args[:hint] if args.key?(:hint)
end