Class: Google::Apis::ContaineranalysisV1::DsseHint
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::DsseHint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
This submessage provides human-readable hints about the purpose of the authority. Because the name of a note acts as its resource reference, it is important to disambiguate the canonical name of the Note (which might be a UUID for security purposes) from "readable" names more suitable for debug output. Note that these hints should not be used to look up authorities in security sensitive contexts, such as when looking up attestations to verify.
Instance Attribute Summary collapse
-
#human_readable_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DsseHint
constructor
A new instance of DsseHint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DsseHint
Returns a new instance of DsseHint.
3752 3753 3754 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#human_readable_name ⇒ String
Required. The human readable name of this attestation authority, for example "
cloudbuild-prod".
Corresponds to the JSON property humanReadableName
3750 3751 3752 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3750 def human_readable_name @human_readable_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3757 3758 3759 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3757 def update!(**args) @human_readable_name = args[:human_readable_name] if args.key?(:human_readable_name) end |