Class: Google::Apis::ContaineranalysisV1::DsseHint
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::DsseHint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
This submessage provides human-readable hints about the purpose of the authority. Because the name of a note acts as its resource reference, it is important to disambiguate the canonical name of the Note (which might be a UUID for security purposes) from "readable" names more suitable for debug output. Note that these hints should not be used to look up authorities in security sensitive contexts, such as when looking up attestations to verify.
Instance Attribute Summary collapse
-
#human_readable_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DsseHint
constructor
A new instance of DsseHint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DsseHint
Returns a new instance of DsseHint.
3524 3525 3526 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3524 def initialize(**args) update!(**args) end |
Instance Attribute Details
#human_readable_name ⇒ String
Required. The human readable name of this attestation authority, for example "
cloudbuild-prod".
Corresponds to the JSON property humanReadableName
3522 3523 3524 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3522 def human_readable_name @human_readable_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3529 3530 3531 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3529 def update!(**args) @human_readable_name = args[:human_readable_name] if args.key?(:human_readable_name) end |