Class: Google::Apis::ContaineranalysisV1::ExploitPredictionScoringSystem

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExploitPredictionScoringSystem

Returns a new instance of ExploitPredictionScoringSystem.



3931
3932
3933
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#percentileFloat

The percentile of the current score, the proportion of all scored vulnerabilities with the same or a lower EPSS score Corresponds to the JSON property percentile

Returns:

  • (Float)


3923
3924
3925
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3923

def percentile
  @percentile
end

#scoreFloat

The EPSS score representing the probability [0-1] of exploitation in the wild in the next 30 days Corresponds to the JSON property score

Returns:

  • (Float)


3929
3930
3931
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3929

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3936
3937
3938
3939
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 3936

def update!(**args)
  @percentile = args[:percentile] if args.key?(:percentile)
  @score = args[:score] if args.key?(:score)
end