Class: Google::Apis::ContaineranalysisV1::FileHashes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileHashes

Returns a new instance of FileHashes.



4410
4411
4412
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashArray<Google::Apis::ContaineranalysisV1::HashProp>

Required. Collection of file hashes. Corresponds to the JSON property fileHash



4408
4409
4410
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4408

def file_hash
  @file_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4415
4416
4417
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4415

def update!(**args)
  @file_hash = args[:file_hash] if args.key?(:file_hash)
end