Class: Google::Apis::ContaineranalysisV1::FileHashes
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::FileHashes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileHashes
constructor
A new instance of FileHashes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileHashes
Returns a new instance of FileHashes.
4084 4085 4086 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_hash ⇒ Array<Google::Apis::ContaineranalysisV1::HashProp>
Required. Collection of file hashes.
Corresponds to the JSON property fileHash
4082 4083 4084 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4082 def file_hash @file_hash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4089 4090 4091 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4089 def update!(**args) @file_hash = args[:file_hash] if args.key?(:file_hash) end |