Class: Google::Apis::ContaineranalysisV1::FileHashes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileHashes

Returns a new instance of FileHashes.



4072
4073
4074
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4072

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashArray<Google::Apis::ContaineranalysisV1::HashProp>

Required. Collection of file hashes. Corresponds to the JSON property fileHash



4070
4071
4072
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4070

def file_hash
  @file_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4077
4078
4079
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4077

def update!(**args)
  @file_hash = args[:file_hash] if args.key?(:file_hash)
end