Class: Google::Apis::ContaineranalysisV1::Finding
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Finding
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Finding provides details for a single finding within an AISkillAnalysisOccurrence.
Instance Attribute Summary collapse
-
#category ⇒ String
Category of the finding.
-
#description ⇒ String
Detailed description of the finding.
-
#file_path ⇒ String
Path to the file where the finding was detected.
-
#rule_id ⇒ String
Unique identifier of the rule that produced this finding.
-
#severity ⇒ String
Severity of the finding.
-
#snippet ⇒ String
Code snippet relevant to the finding.
-
#title ⇒ String
Title of the finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Finding
constructor
A new instance of Finding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Finding
Returns a new instance of Finding.
4407 4408 4409 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4407 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
Category of the finding.
Corresponds to the JSON property category
4375 4376 4377 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4375 def category @category end |
#description ⇒ String
Detailed description of the finding.
Corresponds to the JSON property description
4380 4381 4382 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4380 def description @description end |
#file_path ⇒ String
Path to the file where the finding was detected.
Corresponds to the JSON property filePath
4385 4386 4387 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4385 def file_path @file_path end |
#rule_id ⇒ String
Unique identifier of the rule that produced this finding.
Corresponds to the JSON property ruleId
4390 4391 4392 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4390 def rule_id @rule_id end |
#severity ⇒ String
Severity of the finding.
Corresponds to the JSON property severity
4395 4396 4397 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4395 def severity @severity end |
#snippet ⇒ String
Code snippet relevant to the finding.
Corresponds to the JSON property snippet
4400 4401 4402 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4400 def snippet @snippet end |
#title ⇒ String
Title of the finding.
Corresponds to the JSON property title
4405 4406 4407 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4405 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4412 4413 4414 4415 4416 4417 4418 4419 4420 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4412 def update!(**args) @category = args[:category] if args.key?(:category) @description = args[:description] if args.key?(:description) @file_path = args[:file_path] if args.key?(:file_path) @rule_id = args[:rule_id] if args.key?(:rule_id) @severity = args[:severity] if args.key?(:severity) @snippet = args[:snippet] if args.key?(:snippet) @title = args[:title] if args.key?(:title) end |