Class: Google::Apis::ContaineranalysisV1::FixableTotalByDigest
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::FixableTotalByDigest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Per resource and severity counts of fixable and total vulnerabilities.
Instance Attribute Summary collapse
-
#fixable_count ⇒ Fixnum
The number of fixable vulnerabilities associated with this resource.
-
#resource_uri ⇒ String
The affected resource.
-
#severity ⇒ String
The severity for this count.
-
#total_count ⇒ Fixnum
The total number of vulnerabilities associated with this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FixableTotalByDigest
constructor
A new instance of FixableTotalByDigest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FixableTotalByDigest
Returns a new instance of FixableTotalByDigest.
4482 4483 4484 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fixable_count ⇒ Fixnum
The number of fixable vulnerabilities associated with this resource.
Corresponds to the JSON property fixableCount
4464 4465 4466 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4464 def fixable_count @fixable_count end |
#resource_uri ⇒ String
The affected resource.
Corresponds to the JSON property resourceUri
4469 4470 4471 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4469 def resource_uri @resource_uri end |
#severity ⇒ String
The severity for this count. SEVERITY_UNSPECIFIED indicates total across all
severities.
Corresponds to the JSON property severity
4475 4476 4477 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4475 def severity @severity end |
#total_count ⇒ Fixnum
The total number of vulnerabilities associated with this resource.
Corresponds to the JSON property totalCount
4480 4481 4482 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4480 def total_count @total_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4487 4488 4489 4490 4491 4492 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4487 def update!(**args) @fixable_count = args[:fixable_count] if args.key?(:fixable_count) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @severity = args[:severity] if args.key?(:severity) @total_count = args[:total_count] if args.key?(:total_count) end |