Class: Google::Apis::ContaineranalysisV1::FixableTotalByDigest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Per resource and severity counts of fixable and total vulnerabilities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FixableTotalByDigest

Returns a new instance of FixableTotalByDigest.



4141
4142
4143
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fixable_countFixnum

The number of fixable vulnerabilities associated with this resource. Corresponds to the JSON property fixableCount

Returns:

  • (Fixnum)


4123
4124
4125
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4123

def fixable_count
  @fixable_count
end

#resource_uriString

The affected resource. Corresponds to the JSON property resourceUri

Returns:

  • (String)


4128
4129
4130
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4128

def resource_uri
  @resource_uri
end

#severityString

The severity for this count. SEVERITY_UNSPECIFIED indicates total across all severities. Corresponds to the JSON property severity

Returns:

  • (String)


4134
4135
4136
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4134

def severity
  @severity
end

#total_countFixnum

The total number of vulnerabilities associated with this resource. Corresponds to the JSON property totalCount

Returns:

  • (Fixnum)


4139
4140
4141
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4139

def total_count
  @total_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4146
4147
4148
4149
4150
4151
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4146

def update!(**args)
  @fixable_count = args[:fixable_count] if args.key?(:fixable_count)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @severity = args[:severity] if args.key?(:severity)
  @total_count = args[:total_count] if args.key?(:total_count)
end