Class: Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Indicates the location at which a package was found.
Instance Attribute Summary collapse
-
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file.
-
#layer_details ⇒ Google::Apis::ContaineranalysisV1::LayerDetails
Details about the layer a package was found in.
-
#line_number ⇒ Fixnum
Line number in the file where the package was found.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1FileLocation
constructor
A new instance of GrafeasV1FileLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1FileLocation
Returns a new instance of GrafeasV1FileLocation.
4725 4726 4727 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the
path to war file combined with the path to jar file.
Corresponds to the JSON property filePath
4712 4713 4714 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4712 def file_path @file_path end |
#layer_details ⇒ Google::Apis::ContaineranalysisV1::LayerDetails
Details about the layer a package was found in.
Corresponds to the JSON property layerDetails
4717 4718 4719 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4717 def layer_details @layer_details end |
#line_number ⇒ Fixnum
Line number in the file where the package was found. Optional field that only
applies to source repository scanning.
Corresponds to the JSON property lineNumber
4723 4724 4725 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4723 def line_number @line_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4730 4731 4732 4733 4734 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4730 def update!(**args) @file_path = args[:file_path] if args.key?(:file_path) @layer_details = args[:layer_details] if args.key?(:layer_details) @line_number = args[:line_number] if args.key?(:line_number) end |