Class: Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Indicates the location at which a package was found.
Instance Attribute Summary collapse
-
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file.
-
#layer_details ⇒ Google::Apis::ContaineranalysisV1::LayerDetails
Details about the layer a package was found in.
-
#line_number ⇒ Fixnum
Line number in the file where the package was found.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1FileLocation
constructor
A new instance of GrafeasV1FileLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1FileLocation
Returns a new instance of GrafeasV1FileLocation.
4707 4708 4709 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the
path to war file combined with the path to jar file.
Corresponds to the JSON property filePath
4694 4695 4696 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4694 def file_path @file_path end |
#layer_details ⇒ Google::Apis::ContaineranalysisV1::LayerDetails
Details about the layer a package was found in.
Corresponds to the JSON property layerDetails
4699 4700 4701 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4699 def layer_details @layer_details end |
#line_number ⇒ Fixnum
Line number in the file where the package was found. Optional field that only
applies to source repository scanning.
Corresponds to the JSON property lineNumber
4705 4706 4707 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4705 def line_number @line_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4712 4713 4714 4715 4716 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4712 def update!(**args) @file_path = args[:file_path] if args.key?(:file_path) @layer_details = args[:layer_details] if args.key?(:layer_details) @line_number = args[:line_number] if args.key?(:line_number) end |