Class: Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Indicates the location at which a package was found.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1FileLocation

Returns a new instance of GrafeasV1FileLocation.



4666
4667
4668
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_pathString

For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file. Corresponds to the JSON property filePath

Returns:

  • (String)


4653
4654
4655
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4653

def file_path
  @file_path
end

#layer_detailsGoogle::Apis::ContaineranalysisV1::LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



4658
4659
4660
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4658

def layer_details
  @layer_details
end

#line_numberFixnum

Line number in the file where the package was found. Optional field that only applies to source repository scanning. Corresponds to the JSON property lineNumber

Returns:

  • (Fixnum)


4664
4665
4666
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4664

def line_number
  @line_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4671
4672
4673
4674
4675
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4671

def update!(**args)
  @file_path = args[:file_path] if args.key?(:file_path)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
  @line_number = args[:line_number] if args.key?(:line_number)
end