Class: Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Indicates the location at which a package was found.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1FileLocation

Returns a new instance of GrafeasV1FileLocation.



4375
4376
4377
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_pathString

For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file. Corresponds to the JSON property filePath

Returns:

  • (String)


4362
4363
4364
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4362

def file_path
  @file_path
end

#layer_detailsGoogle::Apis::ContaineranalysisV1::LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



4367
4368
4369
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4367

def layer_details
  @layer_details
end

#line_numberFixnum

Line number in the file where the package was found. Optional field that only applies to source repository scanning. Corresponds to the JSON property lineNumber

Returns:

  • (Fixnum)


4373
4374
4375
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4373

def line_number
  @line_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4380
4381
4382
4383
4384
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4380

def update!(**args)
  @file_path = args[:file_path] if args.key?(:file_path)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
  @line_number = args[:line_number] if args.key?(:line_number)
end