Class: Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Indicates the location at which a package was found.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1FileLocation

Returns a new instance of GrafeasV1FileLocation.



4318
4319
4320
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4318

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_pathString

For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file. Corresponds to the JSON property filePath

Returns:

  • (String)


4311
4312
4313
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4311

def file_path
  @file_path
end

#layer_detailsGoogle::Apis::ContaineranalysisV1::LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



4316
4317
4318
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4316

def layer_details
  @layer_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4323
4324
4325
4326
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4323

def update!(**args)
  @file_path = args[:file_path] if args.key?(:file_path)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
end