Class: Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Indicates the location at which a package was found.
Instance Attribute Summary collapse
-
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file.
-
#layer_details ⇒ Google::Apis::ContaineranalysisV1::LayerDetails
Details about the layer a package was found in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1FileLocation
constructor
A new instance of GrafeasV1FileLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1FileLocation
Returns a new instance of GrafeasV1FileLocation.
4306 4307 4308 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4306 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the
path to war file combined with the path to jar file.
Corresponds to the JSON property filePath
4299 4300 4301 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4299 def file_path @file_path end |
#layer_details ⇒ Google::Apis::ContaineranalysisV1::LayerDetails
Details about the layer a package was found in.
Corresponds to the JSON property layerDetails
4304 4305 4306 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4304 def layer_details @layer_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4311 4312 4313 4314 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4311 def update!(**args) @file_path = args[:file_path] if args.key?(:file_path) @layer_details = args[:layer_details] if args.key?(:layer_details) end |