Class: Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder.



4729
4730
4731
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Corresponds to the JSON property id

Returns:

  • (String)


4727
4728
4729
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4727

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4734
4735
4736
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4734

def update!(**args)
  @id = args[:id] if args.key?(:id)
end