Class: Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder.



4397
4398
4399
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Corresponds to the JSON property id

Returns:

  • (String)


4395
4396
4397
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4395

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4402
4403
4404
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4402

def update!(**args)
  @id = args[:id] if args.key?(:id)
end