Class: Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder.



4339
4340
4341
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4339

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Corresponds to the JSON property id

Returns:

  • (String)


4337
4338
4339
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4337

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4344
4345
4346
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4344

def update!(**args)
  @id = args[:id] if args.key?(:id)
end