Class: Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Identifies the event that kicked off the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation.



4436
4437
4438
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_sourceGoogle::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource

Describes where the config file that kicked off the build came from. This is effectively a pointer to the source where buildConfig came from. Corresponds to the JSON property configSource



4424
4425
4426
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4424

def config_source
  @config_source
end

#environmentHash<String,Object>

Corresponds to the JSON property environment

Returns:

  • (Hash<String,Object>)


4429
4430
4431
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4429

def environment
  @environment
end

#parametersHash<String,Object>

Corresponds to the JSON property parameters

Returns:

  • (Hash<String,Object>)


4434
4435
4436
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4434

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4441
4442
4443
4444
4445
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4441

def update!(**args)
  @config_source = args[:config_source] if args.key?(:config_source)
  @environment = args[:environment] if args.key?(:environment)
  @parameters = args[:parameters] if args.key?(:parameters)
end