Class: Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
Instance Attribute Summary collapse
-
#digest ⇒ Hash<String,String>
Corresponds to the JSON property
digest. -
#uri ⇒ String
Corresponds to the JSON property
uri.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial
constructor
A new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial
Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial.
4451 4452 4453 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4451 def initialize(**args) update!(**args) end |
Instance Attribute Details
#digest ⇒ Hash<String,String>
Corresponds to the JSON property digest
4444 4445 4446 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4444 def digest @digest end |
#uri ⇒ String
Corresponds to the JSON property uri
4449 4450 4451 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4449 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4456 4457 4458 4459 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4456 def update!(**args) @digest = args[:digest] if args.key?(:digest) @uri = args[:uri] if args.key?(:uri) end |