Class: Google::Apis::ContaineranalysisV1::InTotoProvenance
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::InTotoProvenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Instance Attribute Summary collapse
-
#builder_config ⇒ Google::Apis::ContaineranalysisV1::BuilderConfig
required Corresponds to the JSON property
builderConfig. -
#materials ⇒ Array<String>
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
-
#metadata ⇒ Google::Apis::ContaineranalysisV1::Metadata
Other properties of the build.
-
#recipe ⇒ Google::Apis::ContaineranalysisV1::Recipe
Steps taken to build the artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InTotoProvenance
constructor
A new instance of InTotoProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InTotoProvenance
Returns a new instance of InTotoProvenance.
5100 5101 5102 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#builder_config ⇒ Google::Apis::ContaineranalysisV1::BuilderConfig
required
Corresponds to the JSON property builderConfig
5079 5080 5081 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5079 def builder_config @builder_config end |
#materials ⇒ Array<String>
The collection of artifacts that influenced the build including sources,
dependencies, build tools, base images, and so on. This is considered to be
incomplete unless metadata.completeness.materials is true. Unset or null is
equivalent to empty.
Corresponds to the JSON property materials
5087 5088 5089 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5087 def materials @materials end |
#metadata ⇒ Google::Apis::ContaineranalysisV1::Metadata
Other properties of the build.
Corresponds to the JSON property metadata
5092 5093 5094 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5092 def @metadata end |
#recipe ⇒ Google::Apis::ContaineranalysisV1::Recipe
Steps taken to build the artifact. For a TaskRun, typically each container
corresponds to one step in the recipe.
Corresponds to the JSON property recipe
5098 5099 5100 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5098 def recipe @recipe end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5105 5106 5107 5108 5109 5110 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5105 def update!(**args) @builder_config = args[:builder_config] if args.key?(:builder_config) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) @recipe = args[:recipe] if args.key?(:recipe) end |