Class: Google::Apis::ContaineranalysisV1::InTotoProvenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InTotoProvenance

Returns a new instance of InTotoProvenance.



5088
5089
5090
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5088

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builder_configGoogle::Apis::ContaineranalysisV1::BuilderConfig

required Corresponds to the JSON property builderConfig



5067
5068
5069
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5067

def builder_config
  @builder_config
end

#materialsArray<String>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials

Returns:

  • (Array<String>)


5075
5076
5077
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5075

def materials
  @materials
end

#metadataGoogle::Apis::ContaineranalysisV1::Metadata

Other properties of the build. Corresponds to the JSON property metadata



5080
5081
5082
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5080

def 
  @metadata
end

#recipeGoogle::Apis::ContaineranalysisV1::Recipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



5086
5087
5088
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5086

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5093
5094
5095
5096
5097
5098
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5093

def update!(**args)
  @builder_config = args[:builder_config] if args.key?(:builder_config)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end