Class: Google::Apis::ContaineranalysisV1::InTotoProvenance
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::InTotoProvenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Instance Attribute Summary collapse
-
#builder_config ⇒ Google::Apis::ContaineranalysisV1::BuilderConfig
required Corresponds to the JSON property
builderConfig. -
#materials ⇒ Array<String>
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
-
#metadata ⇒ Google::Apis::ContaineranalysisV1::Metadata
Other properties of the build.
-
#recipe ⇒ Google::Apis::ContaineranalysisV1::Recipe
Steps taken to build the artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InTotoProvenance
constructor
A new instance of InTotoProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InTotoProvenance
Returns a new instance of InTotoProvenance.
5028 5029 5030 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5028 def initialize(**args) update!(**args) end |
Instance Attribute Details
#builder_config ⇒ Google::Apis::ContaineranalysisV1::BuilderConfig
required
Corresponds to the JSON property builderConfig
5007 5008 5009 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5007 def builder_config @builder_config end |
#materials ⇒ Array<String>
The collection of artifacts that influenced the build including sources,
dependencies, build tools, base images, and so on. This is considered to be
incomplete unless metadata.completeness.materials is true. Unset or null is
equivalent to empty.
Corresponds to the JSON property materials
5015 5016 5017 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5015 def materials @materials end |
#metadata ⇒ Google::Apis::ContaineranalysisV1::Metadata
Other properties of the build.
Corresponds to the JSON property metadata
5020 5021 5022 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5020 def @metadata end |
#recipe ⇒ Google::Apis::ContaineranalysisV1::Recipe
Steps taken to build the artifact. For a TaskRun, typically each container
corresponds to one step in the recipe.
Corresponds to the JSON property recipe
5026 5027 5028 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5026 def recipe @recipe end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5033 5034 5035 5036 5037 5038 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5033 def update!(**args) @builder_config = args[:builder_config] if args.key?(:builder_config) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) @recipe = args[:recipe] if args.key?(:recipe) end |