Class: Google::Apis::ContaineranalysisV1::InTotoProvenance
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::InTotoProvenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Instance Attribute Summary collapse
-
#builder_config ⇒ Google::Apis::ContaineranalysisV1::BuilderConfig
required Corresponds to the JSON property
builderConfig. -
#materials ⇒ Array<String>
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
-
#metadata ⇒ Google::Apis::ContaineranalysisV1::Metadata
Other properties of the build.
-
#recipe ⇒ Google::Apis::ContaineranalysisV1::Recipe
Steps taken to build the artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InTotoProvenance
constructor
A new instance of InTotoProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InTotoProvenance
Returns a new instance of InTotoProvenance.
4692 4693 4694 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4692 def initialize(**args) update!(**args) end |
Instance Attribute Details
#builder_config ⇒ Google::Apis::ContaineranalysisV1::BuilderConfig
required
Corresponds to the JSON property builderConfig
4671 4672 4673 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4671 def builder_config @builder_config end |
#materials ⇒ Array<String>
The collection of artifacts that influenced the build including sources,
dependencies, build tools, base images, and so on. This is considered to be
incomplete unless metadata.completeness.materials is true. Unset or null is
equivalent to empty.
Corresponds to the JSON property materials
4679 4680 4681 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4679 def materials @materials end |
#metadata ⇒ Google::Apis::ContaineranalysisV1::Metadata
Other properties of the build.
Corresponds to the JSON property metadata
4684 4685 4686 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4684 def @metadata end |
#recipe ⇒ Google::Apis::ContaineranalysisV1::Recipe
Steps taken to build the artifact. For a TaskRun, typically each container
corresponds to one step in the recipe.
Corresponds to the JSON property recipe
4690 4691 4692 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4690 def recipe @recipe end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4697 4698 4699 4700 4701 4702 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4697 def update!(**args) @builder_config = args[:builder_config] if args.key?(:builder_config) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) @recipe = args[:recipe] if args.key?(:recipe) end |