Class: Google::Apis::ContaineranalysisV1::InTotoProvenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InTotoProvenance

Returns a new instance of InTotoProvenance.



4680
4681
4682
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4680

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builder_configGoogle::Apis::ContaineranalysisV1::BuilderConfig

required Corresponds to the JSON property builderConfig



4659
4660
4661
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4659

def builder_config
  @builder_config
end

#materialsArray<String>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials

Returns:

  • (Array<String>)


4667
4668
4669
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4667

def materials
  @materials
end

#metadataGoogle::Apis::ContaineranalysisV1::Metadata

Other properties of the build. Corresponds to the JSON property metadata



4672
4673
4674
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4672

def 
  @metadata
end

#recipeGoogle::Apis::ContaineranalysisV1::Recipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



4678
4679
4680
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4678

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4685
4686
4687
4688
4689
4690
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4685

def update!(**args)
  @builder_config = args[:builder_config] if args.key?(:builder_config)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end