Class: Google::Apis::ContaineranalysisV1::LayerDetails
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::LayerDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Details about the layer a package was found in.
Instance Attribute Summary collapse
-
#base_images ⇒ Array<Google::Apis::ContaineranalysisV1::BaseImage>
The base images the layer is found within.
-
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image.
-
#command ⇒ String
The layer build command that was used to build the layer.
-
#diff_id ⇒ String
The diff ID (typically a sha256 hash) of the layer in the container image.
-
#index ⇒ Fixnum
The index of the layer in the container image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LayerDetails
constructor
A new instance of LayerDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LayerDetails
Returns a new instance of LayerDetails.
5328 5329 5330 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5328 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_images ⇒ Array<Google::Apis::ContaineranalysisV1::BaseImage>
The base images the layer is found within.
Corresponds to the JSON property baseImages
5304 5305 5306 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5304 def base_images @base_images end |
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image. https://
github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid
Corresponds to the JSON property chainId
5310 5311 5312 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5310 def chain_id @chain_id end |
#command ⇒ String
The layer build command that was used to build the layer. This may not be
found in all layers depending on how the container image is built.
Corresponds to the JSON property command
5316 5317 5318 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5316 def command @command end |
#diff_id ⇒ String
The diff ID (typically a sha256 hash) of the layer in the container image.
Corresponds to the JSON property diffId
5321 5322 5323 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5321 def diff_id @diff_id end |
#index ⇒ Fixnum
The index of the layer in the container image.
Corresponds to the JSON property index
5326 5327 5328 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5326 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5333 5334 5335 5336 5337 5338 5339 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5333 def update!(**args) @base_images = args[:base_images] if args.key?(:base_images) @chain_id = args[:chain_id] if args.key?(:chain_id) @command = args[:command] if args.key?(:command) @diff_id = args[:diff_id] if args.key?(:diff_id) @index = args[:index] if args.key?(:index) end |