Class: Google::Apis::ContaineranalysisV1::LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LayerDetails

Returns a new instance of LayerDetails.



5275
5276
5277
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::ContaineranalysisV1::BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



5251
5252
5253
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5251

def base_images
  @base_images
end

#chain_idString

The layer chain ID (sha256 hash) of the layer in the container image. https:// github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid Corresponds to the JSON property chainId

Returns:

  • (String)


5257
5258
5259
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5257

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


5263
5264
5265
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5263

def command
  @command
end

#diff_idString

The diff ID (typically a sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


5268
5269
5270
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5268

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


5273
5274
5275
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5273

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5280
5281
5282
5283
5284
5285
5286
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5280

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end