Class: Google::Apis::ContaineranalysisV1::LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LayerDetails

Returns a new instance of LayerDetails.



5262
5263
5264
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5262

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::ContaineranalysisV1::BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



5238
5239
5240
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5238

def base_images
  @base_images
end

#chain_idString

The layer chain ID (sha256 hash) of the layer in the container image. https:// github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid Corresponds to the JSON property chainId

Returns:

  • (String)


5244
5245
5246
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5244

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


5250
5251
5252
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5250

def command
  @command
end

#diff_idString

The diff ID (typically a sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


5255
5256
5257
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5255

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


5260
5261
5262
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5260

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5267
5268
5269
5270
5271
5272
5273
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5267

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end