Class: Google::Apis::ContaineranalysisV1::LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LayerDetails

Returns a new instance of LayerDetails.



4984
4985
4986
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4984

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::ContaineranalysisV1::BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



4960
4961
4962
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4960

def base_images
  @base_images
end

#chain_idString

The layer chain ID (sha256 hash) of the layer in the container image. https:// github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid Corresponds to the JSON property chainId

Returns:

  • (String)


4966
4967
4968
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4966

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


4972
4973
4974
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4972

def command
  @command
end

#diff_idString

The diff ID (typically a sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


4977
4978
4979
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4977

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


4982
4983
4984
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4982

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4989
4990
4991
4992
4993
4994
4995
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 4989

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end