Class: Google::Apis::ContaineranalysisV1::Note
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Note
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
A type of analysis that can be done for a resource.
Instance Attribute Summary collapse
-
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1::AiSkillAnalysisNote
AISkillAnalysisNote provides the metadata of an AI-based skill analysis.
-
#attestation ⇒ Google::Apis::ContaineranalysisV1::AttestationNote
Note kind that represents a logical attestation "role" or "authority".
-
#build ⇒ Google::Apis::ContaineranalysisV1::BuildNote
Note holding the version of the provider's builder and the signature of the provenance message in the build details occurrence.
-
#compliance ⇒ Google::Apis::ContaineranalysisV1::ComplianceNote
A note describing a compliance check.
-
#create_time ⇒ String
Output only.
-
#deployment ⇒ Google::Apis::ContaineranalysisV1::DeploymentNote
An artifact that can be deployed in some runtime.
-
#discovery ⇒ Google::Apis::ContaineranalysisV1::DiscoveryNote
A note that indicates a type of analysis a provider would perform.
-
#dsse_attestation ⇒ Google::Apis::ContaineranalysisV1::DsseAttestationNote
A note describing a dsse attestation note.
-
#expiration_time ⇒ String
Time of expiration for this note.
-
#image ⇒ Google::Apis::ContaineranalysisV1::ImageNote
Basis describes the base image portion (Note) of the DockerImage relationship.
-
#kind ⇒ String
Output only.
-
#long_description ⇒ String
A detailed description of this note.
-
#name ⇒ String
Output only.
-
#package ⇒ Google::Apis::ContaineranalysisV1::PackageNote
PackageNote represents a particular package version.
-
#related_note_names ⇒ Array<String>
Other notes related to this note.
-
#related_url ⇒ Array<Google::Apis::ContaineranalysisV1::RelatedUrl>
URLs associated with this note.
-
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1::SbomReferenceNote
The note representing an SBOM reference.
-
#secret ⇒ Google::Apis::ContaineranalysisV1::SecretNote
The note representing a secret.
-
#short_description ⇒ String
A one sentence description of this note.
-
#update_time ⇒ String
Output only.
-
#upgrade ⇒ Google::Apis::ContaineranalysisV1::UpgradeNote
An Upgrade Note represents a potential upgrade of a package to a given version.
-
#vulnerability ⇒ Google::Apis::ContaineranalysisV1::VulnerabilityNote
A security vulnerability that can be found in resources.
-
#vulnerability_assessment ⇒ Google::Apis::ContaineranalysisV1::VulnerabilityAssessmentNote
A single VulnerabilityAssessmentNote represents one particular product's vulnerability assessment for one CVE.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Note
constructor
A new instance of Note.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Note
Returns a new instance of Note.
5822 5823 5824 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5822 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1::AiSkillAnalysisNote
AISkillAnalysisNote provides the metadata of an AI-based skill analysis.
Corresponds to the JSON property aiSkillAnalysis
5690 5691 5692 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5690 def ai_skill_analysis @ai_skill_analysis end |
#attestation ⇒ Google::Apis::ContaineranalysisV1::AttestationNote
Note kind that represents a logical attestation "role" or "authority". For
example, an organization might have one Authority for "QA" and one for "
build". This note is intended to act strictly as a grouping mechanism for the
attached occurrences (Attestations). This grouping mechanism also provides a
security boundary, since IAM ACLs gate the ability for a principle to attach
an occurrence to a given note. It also provides a single point of lookup to
find all attached attestation occurrences, even if they don't all live in the
same project.
Corresponds to the JSON property attestation
5702 5703 5704 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5702 def attestation @attestation end |
#build ⇒ Google::Apis::ContaineranalysisV1::BuildNote
Note holding the version of the provider's builder and the signature of the
provenance message in the build details occurrence.
Corresponds to the JSON property build
5708 5709 5710 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5708 def build @build end |
#compliance ⇒ Google::Apis::ContaineranalysisV1::ComplianceNote
A note describing a compliance check.
Corresponds to the JSON property compliance
5713 5714 5715 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5713 def compliance @compliance end |
#create_time ⇒ String
Output only. The time this note was created. This field can be used as a
filter in list requests.
Corresponds to the JSON property createTime
5719 5720 5721 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5719 def create_time @create_time end |
#deployment ⇒ Google::Apis::ContaineranalysisV1::DeploymentNote
An artifact that can be deployed in some runtime.
Corresponds to the JSON property deployment
5724 5725 5726 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5724 def deployment @deployment end |
#discovery ⇒ Google::Apis::ContaineranalysisV1::DiscoveryNote
A note that indicates a type of analysis a provider would perform. This note
exists in a provider's project. A Discovery occurrence is created in a
consumer's project at the start of analysis.
Corresponds to the JSON property discovery
5731 5732 5733 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5731 def discovery @discovery end |
#dsse_attestation ⇒ Google::Apis::ContaineranalysisV1::DsseAttestationNote
A note describing a dsse attestation note.
Corresponds to the JSON property dsseAttestation
5736 5737 5738 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5736 def dsse_attestation @dsse_attestation end |
#expiration_time ⇒ String
Time of expiration for this note. Empty if note does not expire.
Corresponds to the JSON property expirationTime
5741 5742 5743 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5741 def expiration_time @expiration_time end |
#image ⇒ Google::Apis::ContaineranalysisV1::ImageNote
Basis describes the base image portion (Note) of the DockerImage relationship.
Linked occurrences are derived from this or an equivalent image via: FROM Or
an equivalent reference, e.g., a tag of the resource_url.
Corresponds to the JSON property image
5748 5749 5750 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5748 def image @image end |
#kind ⇒ String
Output only. The type of analysis. This field can be used as a filter in list
requests.
Corresponds to the JSON property kind
5754 5755 5756 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5754 def kind @kind end |
#long_description ⇒ String
A detailed description of this note.
Corresponds to the JSON property longDescription
5759 5760 5761 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5759 def long_description @long_description end |
#name ⇒ String
Output only. The name of the note in the form of projects/[PROVIDER_ID]/notes/
[NOTE_ID].
Corresponds to the JSON property name
5765 5766 5767 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5765 def name @name end |
#package ⇒ Google::Apis::ContaineranalysisV1::PackageNote
PackageNote represents a particular package version.
Corresponds to the JSON property package
5770 5771 5772 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5770 def package @package end |
#related_note_names ⇒ Array<String>
Other notes related to this note.
Corresponds to the JSON property relatedNoteNames
5775 5776 5777 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5775 def @related_note_names end |
#related_url ⇒ Array<Google::Apis::ContaineranalysisV1::RelatedUrl>
URLs associated with this note.
Corresponds to the JSON property relatedUrl
5780 5781 5782 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5780 def @related_url end |
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1::SbomReferenceNote
The note representing an SBOM reference.
Corresponds to the JSON property sbomReference
5785 5786 5787 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5785 def sbom_reference @sbom_reference end |
#secret ⇒ Google::Apis::ContaineranalysisV1::SecretNote
The note representing a secret.
Corresponds to the JSON property secret
5790 5791 5792 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5790 def secret @secret end |
#short_description ⇒ String
A one sentence description of this note.
Corresponds to the JSON property shortDescription
5795 5796 5797 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5795 def short_description @short_description end |
#update_time ⇒ String
Output only. The time this note was last updated. This field can be used as a
filter in list requests.
Corresponds to the JSON property updateTime
5801 5802 5803 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5801 def update_time @update_time end |
#upgrade ⇒ Google::Apis::ContaineranalysisV1::UpgradeNote
An Upgrade Note represents a potential upgrade of a package to a given version.
For each package version combination (i.e. bash 4.0, bash 4.1, bash 4.1.2),
there will be an Upgrade Note. For Windows, windows_update field represents
the information related to the update.
Corresponds to the JSON property upgrade
5809 5810 5811 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5809 def upgrade @upgrade end |
#vulnerability ⇒ Google::Apis::ContaineranalysisV1::VulnerabilityNote
A security vulnerability that can be found in resources.
Corresponds to the JSON property vulnerability
5814 5815 5816 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5814 def vulnerability @vulnerability end |
#vulnerability_assessment ⇒ Google::Apis::ContaineranalysisV1::VulnerabilityAssessmentNote
A single VulnerabilityAssessmentNote represents one particular product's
vulnerability assessment for one CVE.
Corresponds to the JSON property vulnerabilityAssessment
5820 5821 5822 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5820 def vulnerability_assessment @vulnerability_assessment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 5842 5843 5844 5845 5846 5847 5848 5849 5850 5851 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5827 def update!(**args) @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis) @attestation = args[:attestation] if args.key?(:attestation) @build = args[:build] if args.key?(:build) @compliance = args[:compliance] if args.key?(:compliance) @create_time = args[:create_time] if args.key?(:create_time) @deployment = args[:deployment] if args.key?(:deployment) @discovery = args[:discovery] if args.key?(:discovery) @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @image = args[:image] if args.key?(:image) @kind = args[:kind] if args.key?(:kind) @long_description = args[:long_description] if args.key?(:long_description) @name = args[:name] if args.key?(:name) @package = args[:package] if args.key?(:package) @related_note_names = args[:related_note_names] if args.key?(:related_note_names) @related_url = args[:related_url] if args.key?(:related_url) @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference) @secret = args[:secret] if args.key?(:secret) @short_description = args[:short_description] if args.key?(:short_description) @update_time = args[:update_time] if args.key?(:update_time) @upgrade = args[:upgrade] if args.key?(:upgrade) @vulnerability = args[:vulnerability] if args.key?(:vulnerability) @vulnerability_assessment = args[:vulnerability_assessment] if args.key?(:vulnerability_assessment) end |