Class: Google::Apis::ContaineranalysisV1::Note
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Note
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
A type of analysis that can be done for a resource.
Instance Attribute Summary collapse
-
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1::AiSkillAnalysisNote
AISkillAnalysisNote provides the metadata of an AI-based skill analysis.
-
#attestation ⇒ Google::Apis::ContaineranalysisV1::AttestationNote
Note kind that represents a logical attestation "role" or "authority".
-
#build ⇒ Google::Apis::ContaineranalysisV1::BuildNote
Note holding the version of the provider's builder and the signature of the provenance message in the build details occurrence.
-
#compliance ⇒ Google::Apis::ContaineranalysisV1::ComplianceNote
A note describing a compliance check.
-
#create_time ⇒ String
Output only.
-
#deployment ⇒ Google::Apis::ContaineranalysisV1::DeploymentNote
An artifact that can be deployed in some runtime.
-
#discovery ⇒ Google::Apis::ContaineranalysisV1::DiscoveryNote
A note that indicates a type of analysis a provider would perform.
-
#dsse_attestation ⇒ Google::Apis::ContaineranalysisV1::DsseAttestationNote
A note describing a dsse attestation note.
-
#expiration_time ⇒ String
Time of expiration for this note.
-
#image ⇒ Google::Apis::ContaineranalysisV1::ImageNote
Basis describes the base image portion (Note) of the DockerImage relationship.
-
#kind ⇒ String
Output only.
-
#long_description ⇒ String
A detailed description of this note.
-
#name ⇒ String
Output only.
-
#package ⇒ Google::Apis::ContaineranalysisV1::PackageNote
PackageNote represents a particular package version.
-
#related_note_names ⇒ Array<String>
Other notes related to this note.
-
#related_url ⇒ Array<Google::Apis::ContaineranalysisV1::RelatedUrl>
URLs associated with this note.
-
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1::SbomReferenceNote
The note representing an SBOM reference.
-
#secret ⇒ Google::Apis::ContaineranalysisV1::SecretNote
The note representing a secret.
-
#short_description ⇒ String
A one sentence description of this note.
-
#update_time ⇒ String
Output only.
-
#upgrade ⇒ Google::Apis::ContaineranalysisV1::UpgradeNote
An Upgrade Note represents a potential upgrade of a package to a given version.
-
#vulnerability ⇒ Google::Apis::ContaineranalysisV1::VulnerabilityNote
A security vulnerability that can be found in resources.
-
#vulnerability_assessment ⇒ Google::Apis::ContaineranalysisV1::VulnerabilityAssessmentNote
A single VulnerabilityAssessmentNote represents one particular product's vulnerability assessment for one CVE.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Note
constructor
A new instance of Note.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Note
Returns a new instance of Note.
5735 5736 5737 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5735 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1::AiSkillAnalysisNote
AISkillAnalysisNote provides the metadata of an AI-based skill analysis.
Corresponds to the JSON property aiSkillAnalysis
5603 5604 5605 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5603 def ai_skill_analysis @ai_skill_analysis end |
#attestation ⇒ Google::Apis::ContaineranalysisV1::AttestationNote
Note kind that represents a logical attestation "role" or "authority". For
example, an organization might have one Authority for "QA" and one for "
build". This note is intended to act strictly as a grouping mechanism for the
attached occurrences (Attestations). This grouping mechanism also provides a
security boundary, since IAM ACLs gate the ability for a principle to attach
an occurrence to a given note. It also provides a single point of lookup to
find all attached attestation occurrences, even if they don't all live in the
same project.
Corresponds to the JSON property attestation
5615 5616 5617 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5615 def attestation @attestation end |
#build ⇒ Google::Apis::ContaineranalysisV1::BuildNote
Note holding the version of the provider's builder and the signature of the
provenance message in the build details occurrence.
Corresponds to the JSON property build
5621 5622 5623 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5621 def build @build end |
#compliance ⇒ Google::Apis::ContaineranalysisV1::ComplianceNote
A note describing a compliance check.
Corresponds to the JSON property compliance
5626 5627 5628 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5626 def compliance @compliance end |
#create_time ⇒ String
Output only. The time this note was created. This field can be used as a
filter in list requests.
Corresponds to the JSON property createTime
5632 5633 5634 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5632 def create_time @create_time end |
#deployment ⇒ Google::Apis::ContaineranalysisV1::DeploymentNote
An artifact that can be deployed in some runtime.
Corresponds to the JSON property deployment
5637 5638 5639 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5637 def deployment @deployment end |
#discovery ⇒ Google::Apis::ContaineranalysisV1::DiscoveryNote
A note that indicates a type of analysis a provider would perform. This note
exists in a provider's project. A Discovery occurrence is created in a
consumer's project at the start of analysis.
Corresponds to the JSON property discovery
5644 5645 5646 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5644 def discovery @discovery end |
#dsse_attestation ⇒ Google::Apis::ContaineranalysisV1::DsseAttestationNote
A note describing a dsse attestation note.
Corresponds to the JSON property dsseAttestation
5649 5650 5651 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5649 def dsse_attestation @dsse_attestation end |
#expiration_time ⇒ String
Time of expiration for this note. Empty if note does not expire.
Corresponds to the JSON property expirationTime
5654 5655 5656 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5654 def expiration_time @expiration_time end |
#image ⇒ Google::Apis::ContaineranalysisV1::ImageNote
Basis describes the base image portion (Note) of the DockerImage relationship.
Linked occurrences are derived from this or an equivalent image via: FROM Or
an equivalent reference, e.g., a tag of the resource_url.
Corresponds to the JSON property image
5661 5662 5663 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5661 def image @image end |
#kind ⇒ String
Output only. The type of analysis. This field can be used as a filter in list
requests.
Corresponds to the JSON property kind
5667 5668 5669 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5667 def kind @kind end |
#long_description ⇒ String
A detailed description of this note.
Corresponds to the JSON property longDescription
5672 5673 5674 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5672 def long_description @long_description end |
#name ⇒ String
Output only. The name of the note in the form of projects/[PROVIDER_ID]/notes/
[NOTE_ID].
Corresponds to the JSON property name
5678 5679 5680 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5678 def name @name end |
#package ⇒ Google::Apis::ContaineranalysisV1::PackageNote
PackageNote represents a particular package version.
Corresponds to the JSON property package
5683 5684 5685 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5683 def package @package end |
#related_note_names ⇒ Array<String>
Other notes related to this note.
Corresponds to the JSON property relatedNoteNames
5688 5689 5690 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5688 def @related_note_names end |
#related_url ⇒ Array<Google::Apis::ContaineranalysisV1::RelatedUrl>
URLs associated with this note.
Corresponds to the JSON property relatedUrl
5693 5694 5695 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5693 def @related_url end |
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1::SbomReferenceNote
The note representing an SBOM reference.
Corresponds to the JSON property sbomReference
5698 5699 5700 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5698 def sbom_reference @sbom_reference end |
#secret ⇒ Google::Apis::ContaineranalysisV1::SecretNote
The note representing a secret.
Corresponds to the JSON property secret
5703 5704 5705 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5703 def secret @secret end |
#short_description ⇒ String
A one sentence description of this note.
Corresponds to the JSON property shortDescription
5708 5709 5710 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5708 def short_description @short_description end |
#update_time ⇒ String
Output only. The time this note was last updated. This field can be used as a
filter in list requests.
Corresponds to the JSON property updateTime
5714 5715 5716 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5714 def update_time @update_time end |
#upgrade ⇒ Google::Apis::ContaineranalysisV1::UpgradeNote
An Upgrade Note represents a potential upgrade of a package to a given version.
For each package version combination (i.e. bash 4.0, bash 4.1, bash 4.1.2),
there will be an Upgrade Note. For Windows, windows_update field represents
the information related to the update.
Corresponds to the JSON property upgrade
5722 5723 5724 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5722 def upgrade @upgrade end |
#vulnerability ⇒ Google::Apis::ContaineranalysisV1::VulnerabilityNote
A security vulnerability that can be found in resources.
Corresponds to the JSON property vulnerability
5727 5728 5729 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5727 def vulnerability @vulnerability end |
#vulnerability_assessment ⇒ Google::Apis::ContaineranalysisV1::VulnerabilityAssessmentNote
A single VulnerabilityAssessmentNote represents one particular product's
vulnerability assessment for one CVE.
Corresponds to the JSON property vulnerabilityAssessment
5733 5734 5735 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5733 def vulnerability_assessment @vulnerability_assessment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5740 5741 5742 5743 5744 5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5740 def update!(**args) @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis) @attestation = args[:attestation] if args.key?(:attestation) @build = args[:build] if args.key?(:build) @compliance = args[:compliance] if args.key?(:compliance) @create_time = args[:create_time] if args.key?(:create_time) @deployment = args[:deployment] if args.key?(:deployment) @discovery = args[:discovery] if args.key?(:discovery) @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @image = args[:image] if args.key?(:image) @kind = args[:kind] if args.key?(:kind) @long_description = args[:long_description] if args.key?(:long_description) @name = args[:name] if args.key?(:name) @package = args[:package] if args.key?(:package) @related_note_names = args[:related_note_names] if args.key?(:related_note_names) @related_url = args[:related_url] if args.key?(:related_url) @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference) @secret = args[:secret] if args.key?(:secret) @short_description = args[:short_description] if args.key?(:short_description) @update_time = args[:update_time] if args.key?(:update_time) @upgrade = args[:upgrade] if args.key?(:upgrade) @vulnerability = args[:vulnerability] if args.key?(:vulnerability) @vulnerability_assessment = args[:vulnerability_assessment] if args.key?(:vulnerability_assessment) end |