Class: Google::Apis::ContaineranalysisV1::Note

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A type of analysis that can be done for a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Note

Returns a new instance of Note.



5729
5730
5731
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_skill_analysisGoogle::Apis::ContaineranalysisV1::AiSkillAnalysisNote

AISkillAnalysisNote provides the metadata of an AI-based skill analysis. Corresponds to the JSON property aiSkillAnalysis



5597
5598
5599
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5597

def ai_skill_analysis
  @ai_skill_analysis
end

#attestationGoogle::Apis::ContaineranalysisV1::AttestationNote

Note kind that represents a logical attestation "role" or "authority". For example, an organization might have one Authority for "QA" and one for " build". This note is intended to act strictly as a grouping mechanism for the attached occurrences (Attestations). This grouping mechanism also provides a security boundary, since IAM ACLs gate the ability for a principle to attach an occurrence to a given note. It also provides a single point of lookup to find all attached attestation occurrences, even if they don't all live in the same project. Corresponds to the JSON property attestation



5609
5610
5611
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5609

def attestation
  @attestation
end

#buildGoogle::Apis::ContaineranalysisV1::BuildNote

Note holding the version of the provider's builder and the signature of the provenance message in the build details occurrence. Corresponds to the JSON property build



5615
5616
5617
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5615

def build
  @build
end

#complianceGoogle::Apis::ContaineranalysisV1::ComplianceNote

A note describing a compliance check. Corresponds to the JSON property compliance



5620
5621
5622
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5620

def compliance
  @compliance
end

#create_timeString

Output only. The time this note was created. This field can be used as a filter in list requests. Corresponds to the JSON property createTime

Returns:

  • (String)


5626
5627
5628
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5626

def create_time
  @create_time
end

#deploymentGoogle::Apis::ContaineranalysisV1::DeploymentNote

An artifact that can be deployed in some runtime. Corresponds to the JSON property deployment



5631
5632
5633
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5631

def deployment
  @deployment
end

#discoveryGoogle::Apis::ContaineranalysisV1::DiscoveryNote

A note that indicates a type of analysis a provider would perform. This note exists in a provider's project. A Discovery occurrence is created in a consumer's project at the start of analysis. Corresponds to the JSON property discovery



5638
5639
5640
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5638

def discovery
  @discovery
end

#dsse_attestationGoogle::Apis::ContaineranalysisV1::DsseAttestationNote

A note describing a dsse attestation note. Corresponds to the JSON property dsseAttestation



5643
5644
5645
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5643

def dsse_attestation
  @dsse_attestation
end

#expiration_timeString

Time of expiration for this note. Empty if note does not expire. Corresponds to the JSON property expirationTime

Returns:

  • (String)


5648
5649
5650
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5648

def expiration_time
  @expiration_time
end

#imageGoogle::Apis::ContaineranalysisV1::ImageNote

Basis describes the base image portion (Note) of the DockerImage relationship. Linked occurrences are derived from this or an equivalent image via: FROM Or an equivalent reference, e.g., a tag of the resource_url. Corresponds to the JSON property image



5655
5656
5657
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5655

def image
  @image
end

#kindString

Output only. The type of analysis. This field can be used as a filter in list requests. Corresponds to the JSON property kind

Returns:

  • (String)


5661
5662
5663
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5661

def kind
  @kind
end

#long_descriptionString

A detailed description of this note. Corresponds to the JSON property longDescription

Returns:

  • (String)


5666
5667
5668
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5666

def long_description
  @long_description
end

#nameString

Output only. The name of the note in the form of projects/[PROVIDER_ID]/notes/ [NOTE_ID]. Corresponds to the JSON property name

Returns:

  • (String)


5672
5673
5674
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5672

def name
  @name
end

#packageGoogle::Apis::ContaineranalysisV1::PackageNote

PackageNote represents a particular package version. Corresponds to the JSON property package



5677
5678
5679
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5677

def package
  @package
end

Other notes related to this note. Corresponds to the JSON property relatedNoteNames

Returns:

  • (Array<String>)


5682
5683
5684
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5682

def related_note_names
  @related_note_names
end

URLs associated with this note. Corresponds to the JSON property relatedUrl



5687
5688
5689
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5687

def related_url
  @related_url
end

#sbom_referenceGoogle::Apis::ContaineranalysisV1::SbomReferenceNote

The note representing an SBOM reference. Corresponds to the JSON property sbomReference



5692
5693
5694
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5692

def sbom_reference
  @sbom_reference
end

#secretGoogle::Apis::ContaineranalysisV1::SecretNote

The note representing a secret. Corresponds to the JSON property secret



5697
5698
5699
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5697

def secret
  @secret
end

#short_descriptionString

A one sentence description of this note. Corresponds to the JSON property shortDescription

Returns:

  • (String)


5702
5703
5704
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5702

def short_description
  @short_description
end

#update_timeString

Output only. The time this note was last updated. This field can be used as a filter in list requests. Corresponds to the JSON property updateTime

Returns:

  • (String)


5708
5709
5710
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5708

def update_time
  @update_time
end

#upgradeGoogle::Apis::ContaineranalysisV1::UpgradeNote

An Upgrade Note represents a potential upgrade of a package to a given version. For each package version combination (i.e. bash 4.0, bash 4.1, bash 4.1.2), there will be an Upgrade Note. For Windows, windows_update field represents the information related to the update. Corresponds to the JSON property upgrade



5716
5717
5718
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5716

def upgrade
  @upgrade
end

#vulnerabilityGoogle::Apis::ContaineranalysisV1::VulnerabilityNote

A security vulnerability that can be found in resources. Corresponds to the JSON property vulnerability



5721
5722
5723
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5721

def vulnerability
  @vulnerability
end

#vulnerability_assessmentGoogle::Apis::ContaineranalysisV1::VulnerabilityAssessmentNote

A single VulnerabilityAssessmentNote represents one particular product's vulnerability assessment for one CVE. Corresponds to the JSON property vulnerabilityAssessment



5727
5728
5729
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5727

def vulnerability_assessment
  @vulnerability_assessment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5734
5735
5736
5737
5738
5739
5740
5741
5742
5743
5744
5745
5746
5747
5748
5749
5750
5751
5752
5753
5754
5755
5756
5757
5758
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5734

def update!(**args)
  @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis)
  @attestation = args[:attestation] if args.key?(:attestation)
  @build = args[:build] if args.key?(:build)
  @compliance = args[:compliance] if args.key?(:compliance)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployment = args[:deployment] if args.key?(:deployment)
  @discovery = args[:discovery] if args.key?(:discovery)
  @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @image = args[:image] if args.key?(:image)
  @kind = args[:kind] if args.key?(:kind)
  @long_description = args[:long_description] if args.key?(:long_description)
  @name = args[:name] if args.key?(:name)
  @package = args[:package] if args.key?(:package)
  @related_note_names = args[:related_note_names] if args.key?(:related_note_names)
  @related_url = args[:related_url] if args.key?(:related_url)
  @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference)
  @secret = args[:secret] if args.key?(:secret)
  @short_description = args[:short_description] if args.key?(:short_description)
  @update_time = args[:update_time] if args.key?(:update_time)
  @upgrade = args[:upgrade] if args.key?(:upgrade)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
  @vulnerability_assessment = args[:vulnerability_assessment] if args.key?(:vulnerability_assessment)
end