Class: Google::Apis::ContaineranalysisV1::Note

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A type of analysis that can be done for a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Note

Returns a new instance of Note.



5392
5393
5394
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5392

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attestationGoogle::Apis::ContaineranalysisV1::AttestationNote

Note kind that represents a logical attestation "role" or "authority". For example, an organization might have one Authority for "QA" and one for " build". This note is intended to act strictly as a grouping mechanism for the attached occurrences (Attestations). This grouping mechanism also provides a security boundary, since IAM ACLs gate the ability for a principle to attach an occurrence to a given note. It also provides a single point of lookup to find all attached attestation occurrences, even if they don't all live in the same project. Corresponds to the JSON property attestation



5272
5273
5274
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5272

def attestation
  @attestation
end

#buildGoogle::Apis::ContaineranalysisV1::BuildNote

Note holding the version of the provider's builder and the signature of the provenance message in the build details occurrence. Corresponds to the JSON property build



5278
5279
5280
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5278

def build
  @build
end

#complianceGoogle::Apis::ContaineranalysisV1::ComplianceNote

A note describing a compliance check. Corresponds to the JSON property compliance



5283
5284
5285
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5283

def compliance
  @compliance
end

#create_timeString

Output only. The time this note was created. This field can be used as a filter in list requests. Corresponds to the JSON property createTime

Returns:

  • (String)


5289
5290
5291
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5289

def create_time
  @create_time
end

#deploymentGoogle::Apis::ContaineranalysisV1::DeploymentNote

An artifact that can be deployed in some runtime. Corresponds to the JSON property deployment



5294
5295
5296
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5294

def deployment
  @deployment
end

#discoveryGoogle::Apis::ContaineranalysisV1::DiscoveryNote

A note that indicates a type of analysis a provider would perform. This note exists in a provider's project. A Discovery occurrence is created in a consumer's project at the start of analysis. Corresponds to the JSON property discovery



5301
5302
5303
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5301

def discovery
  @discovery
end

#dsse_attestationGoogle::Apis::ContaineranalysisV1::DsseAttestationNote

A note describing a dsse attestation note. Corresponds to the JSON property dsseAttestation



5306
5307
5308
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5306

def dsse_attestation
  @dsse_attestation
end

#expiration_timeString

Time of expiration for this note. Empty if note does not expire. Corresponds to the JSON property expirationTime

Returns:

  • (String)


5311
5312
5313
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5311

def expiration_time
  @expiration_time
end

#imageGoogle::Apis::ContaineranalysisV1::ImageNote

Basis describes the base image portion (Note) of the DockerImage relationship. Linked occurrences are derived from this or an equivalent image via: FROM Or an equivalent reference, e.g., a tag of the resource_url. Corresponds to the JSON property image



5318
5319
5320
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5318

def image
  @image
end

#kindString

Output only. The type of analysis. This field can be used as a filter in list requests. Corresponds to the JSON property kind

Returns:

  • (String)


5324
5325
5326
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5324

def kind
  @kind
end

#long_descriptionString

A detailed description of this note. Corresponds to the JSON property longDescription

Returns:

  • (String)


5329
5330
5331
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5329

def long_description
  @long_description
end

#nameString

Output only. The name of the note in the form of projects/[PROVIDER_ID]/notes/ [NOTE_ID]. Corresponds to the JSON property name

Returns:

  • (String)


5335
5336
5337
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5335

def name
  @name
end

#packageGoogle::Apis::ContaineranalysisV1::PackageNote

PackageNote represents a particular package version. Corresponds to the JSON property package



5340
5341
5342
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5340

def package
  @package
end

Other notes related to this note. Corresponds to the JSON property relatedNoteNames

Returns:

  • (Array<String>)


5345
5346
5347
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5345

def related_note_names
  @related_note_names
end

URLs associated with this note. Corresponds to the JSON property relatedUrl



5350
5351
5352
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5350

def related_url
  @related_url
end

#sbom_referenceGoogle::Apis::ContaineranalysisV1::SbomReferenceNote

The note representing an SBOM reference. Corresponds to the JSON property sbomReference



5355
5356
5357
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5355

def sbom_reference
  @sbom_reference
end

#secretGoogle::Apis::ContaineranalysisV1::SecretNote

The note representing a secret. Corresponds to the JSON property secret



5360
5361
5362
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5360

def secret
  @secret
end

#short_descriptionString

A one sentence description of this note. Corresponds to the JSON property shortDescription

Returns:

  • (String)


5365
5366
5367
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5365

def short_description
  @short_description
end

#update_timeString

Output only. The time this note was last updated. This field can be used as a filter in list requests. Corresponds to the JSON property updateTime

Returns:

  • (String)


5371
5372
5373
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5371

def update_time
  @update_time
end

#upgradeGoogle::Apis::ContaineranalysisV1::UpgradeNote

An Upgrade Note represents a potential upgrade of a package to a given version. For each package version combination (i.e. bash 4.0, bash 4.1, bash 4.1.2), there will be an Upgrade Note. For Windows, windows_update field represents the information related to the update. Corresponds to the JSON property upgrade



5379
5380
5381
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5379

def upgrade
  @upgrade
end

#vulnerabilityGoogle::Apis::ContaineranalysisV1::VulnerabilityNote

A security vulnerability that can be found in resources. Corresponds to the JSON property vulnerability



5384
5385
5386
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5384

def vulnerability
  @vulnerability
end

#vulnerability_assessmentGoogle::Apis::ContaineranalysisV1::VulnerabilityAssessmentNote

A single VulnerabilityAssessmentNote represents one particular product's vulnerability assessment for one CVE. Corresponds to the JSON property vulnerabilityAssessment



5390
5391
5392
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5390

def vulnerability_assessment
  @vulnerability_assessment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
5417
5418
5419
5420
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5397

def update!(**args)
  @attestation = args[:attestation] if args.key?(:attestation)
  @build = args[:build] if args.key?(:build)
  @compliance = args[:compliance] if args.key?(:compliance)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployment = args[:deployment] if args.key?(:deployment)
  @discovery = args[:discovery] if args.key?(:discovery)
  @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @image = args[:image] if args.key?(:image)
  @kind = args[:kind] if args.key?(:kind)
  @long_description = args[:long_description] if args.key?(:long_description)
  @name = args[:name] if args.key?(:name)
  @package = args[:package] if args.key?(:package)
  @related_note_names = args[:related_note_names] if args.key?(:related_note_names)
  @related_url = args[:related_url] if args.key?(:related_url)
  @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference)
  @secret = args[:secret] if args.key?(:secret)
  @short_description = args[:short_description] if args.key?(:short_description)
  @update_time = args[:update_time] if args.key?(:update_time)
  @upgrade = args[:upgrade] if args.key?(:upgrade)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
  @vulnerability_assessment = args[:vulnerability_assessment] if args.key?(:vulnerability_assessment)
end