Class: Google::Apis::ContaineranalysisV1::Occurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Occurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
An instance of an analysis type that has been found on a resource.
Instance Attribute Summary collapse
-
#advisory_publish_time ⇒ String
The time this advisory was published by the source.
-
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1::AiSkillAnalysisOccurrence
AISkillAnalysisOccurrence provides the results of an AI-based skill analysis.
-
#attestation ⇒ Google::Apis::ContaineranalysisV1::AttestationOccurrence
Occurrence that represents a single "attestation".
-
#build ⇒ Google::Apis::ContaineranalysisV1::BuildOccurrence
Details of a build occurrence.
-
#compliance ⇒ Google::Apis::ContaineranalysisV1::ComplianceOccurrence
An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason.
-
#create_time ⇒ String
Output only.
-
#deployment ⇒ Google::Apis::ContaineranalysisV1::DeploymentOccurrence
The period during which some deployable was active in a runtime.
-
#discovery ⇒ Google::Apis::ContaineranalysisV1::DiscoveryOccurrence
Provides information about the analysis status of a discovered resource.
-
#dsse_attestation ⇒ Google::Apis::ContaineranalysisV1::DsseAttestationOccurrence
Deprecated.
- #envelope ⇒ Google::Apis::ContaineranalysisV1::Envelope
-
#image ⇒ Google::Apis::ContaineranalysisV1::ImageOccurrence
Details of the derived image portion of the DockerImage relationship.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#note_name ⇒ String
Required.
-
#package ⇒ Google::Apis::ContaineranalysisV1::PackageOccurrence
Details on how a particular software package was installed on a system.
-
#remediation ⇒ String
A description of actions that can be taken to remedy the note.
-
#resource_uri ⇒ String
Required.
-
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1::SbomReferenceOccurrence
The occurrence representing an SBOM reference as applied to a specific resource.
-
#secret ⇒ Google::Apis::ContaineranalysisV1::SecretOccurrence
The occurrence provides details of a secret.
-
#update_time ⇒ String
Output only.
-
#upgrade ⇒ Google::Apis::ContaineranalysisV1::UpgradeOccurrence
An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade.
-
#vulnerability ⇒ Google::Apis::ContaineranalysisV1::VulnerabilityOccurrence
An occurrence of a severity vulnerability on a resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Occurrence
constructor
A new instance of Occurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Occurrence
Returns a new instance of Occurrence.
5990 5991 5992 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advisory_publish_time ⇒ String
The time this advisory was published by the source.
Corresponds to the JSON property advisoryPublishTime
5861 5862 5863 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5861 def advisory_publish_time @advisory_publish_time end |
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1::AiSkillAnalysisOccurrence
AISkillAnalysisOccurrence provides the results of an AI-based skill analysis.
Corresponds to the JSON property aiSkillAnalysis
5866 5867 5868 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5866 def ai_skill_analysis @ai_skill_analysis end |
#attestation ⇒ Google::Apis::ContaineranalysisV1::AttestationOccurrence
Occurrence that represents a single "attestation". The authenticity of an
attestation can be verified using the attached signature. If the verifier
trusts the public key of the signer, then verifying the signature is
sufficient to establish trust. In this circumstance, the authority to which
this attestation is attached is primarily useful for lookup (how to find this
attestation if you already know the authority and artifact to be verified) and
intent (for which authority this attestation was intended to sign.
Corresponds to the JSON property attestation
5877 5878 5879 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5877 def attestation @attestation end |
#build ⇒ Google::Apis::ContaineranalysisV1::BuildOccurrence
Details of a build occurrence.
Corresponds to the JSON property build
5882 5883 5884 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5882 def build @build end |
#compliance ⇒ Google::Apis::ContaineranalysisV1::ComplianceOccurrence
An indication that the compliance checks in the associated ComplianceNote were
not satisfied for particular resources or a specified reason.
Corresponds to the JSON property compliance
5888 5889 5890 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5888 def compliance @compliance end |
#create_time ⇒ String
Output only. The time this occurrence was created.
Corresponds to the JSON property createTime
5893 5894 5895 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5893 def create_time @create_time end |
#deployment ⇒ Google::Apis::ContaineranalysisV1::DeploymentOccurrence
The period during which some deployable was active in a runtime.
Corresponds to the JSON property deployment
5898 5899 5900 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5898 def deployment @deployment end |
#discovery ⇒ Google::Apis::ContaineranalysisV1::DiscoveryOccurrence
Provides information about the analysis status of a discovered resource.
Corresponds to the JSON property discovery
5903 5904 5905 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5903 def discovery @discovery end |
#dsse_attestation ⇒ Google::Apis::ContaineranalysisV1::DsseAttestationOccurrence
Deprecated. Prefer to use a regular Occurrence, and populate the Envelope at
the top level of the Occurrence.
Corresponds to the JSON property dsseAttestation
5909 5910 5911 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5909 def dsse_attestation @dsse_attestation end |
#envelope ⇒ Google::Apis::ContaineranalysisV1::Envelope
MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope.
proto. An authenticated message of arbitrary type.
Corresponds to the JSON property envelope
5915 5916 5917 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5915 def envelope @envelope end |
#image ⇒ Google::Apis::ContaineranalysisV1::ImageOccurrence
Details of the derived image portion of the DockerImage relationship. This
image would be produced from a Dockerfile with FROM .
Corresponds to the JSON property image
5921 5922 5923 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5921 def image @image end |
#kind ⇒ String
Output only. This explicitly denotes which of the occurrence details are
specified. This field can be used as a filter in list requests.
Corresponds to the JSON property kind
5927 5928 5929 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5927 def kind @kind end |
#name ⇒ String
Output only. The name of the occurrence in the form of projects/[PROJECT_ID]/
occurrences/[OCCURRENCE_ID].
Corresponds to the JSON property name
5933 5934 5935 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5933 def name @name end |
#note_name ⇒ String
Required. Immutable. The analysis note associated with this occurrence, in the
form of projects/[PROVIDER_ID]/notes/[NOTE_ID]. This field can be used as a
filter in list requests.
Corresponds to the JSON property noteName
5940 5941 5942 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5940 def note_name @note_name end |
#package ⇒ Google::Apis::ContaineranalysisV1::PackageOccurrence
Details on how a particular software package was installed on a system.
Corresponds to the JSON property package
5945 5946 5947 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5945 def package @package end |
#remediation ⇒ String
A description of actions that can be taken to remedy the note.
Corresponds to the JSON property remediation
5950 5951 5952 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5950 def remediation @remediation end |
#resource_uri ⇒ String
Required. Immutable. A URI that represents the resource for which the
occurrence applies. For example, https://gcr.io/project/image@sha256:123abc
for a Docker image.
Corresponds to the JSON property resourceUri
5957 5958 5959 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5957 def resource_uri @resource_uri end |
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1::SbomReferenceOccurrence
The occurrence representing an SBOM reference as applied to a specific
resource. The occurrence follows the DSSE specification. See https://github.
com/secure-systems-lab/dsse/blob/master/envelope.md for more details.
Corresponds to the JSON property sbomReference
5964 5965 5966 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5964 def sbom_reference @sbom_reference end |
#secret ⇒ Google::Apis::ContaineranalysisV1::SecretOccurrence
The occurrence provides details of a secret.
Corresponds to the JSON property secret
5969 5970 5971 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5969 def secret @secret end |
#update_time ⇒ String
Output only. The time this occurrence was last updated.
Corresponds to the JSON property updateTime
5974 5975 5976 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5974 def update_time @update_time end |
#upgrade ⇒ Google::Apis::ContaineranalysisV1::UpgradeOccurrence
An Upgrade Occurrence represents that a specific resource_url could install a
specific upgrade. This presence is supplied via local sources (i.e. it is
present in the mirror and the running system has noticed its availability).
For Windows, both distribution and windows_update contain information for the
Windows update.
Corresponds to the JSON property upgrade
5983 5984 5985 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5983 def upgrade @upgrade end |
#vulnerability ⇒ Google::Apis::ContaineranalysisV1::VulnerabilityOccurrence
An occurrence of a severity vulnerability on a resource.
Corresponds to the JSON property vulnerability
5988 5989 5990 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5988 def vulnerability @vulnerability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5995 def update!(**args) @advisory_publish_time = args[:advisory_publish_time] if args.key?(:advisory_publish_time) @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis) @attestation = args[:attestation] if args.key?(:attestation) @build = args[:build] if args.key?(:build) @compliance = args[:compliance] if args.key?(:compliance) @create_time = args[:create_time] if args.key?(:create_time) @deployment = args[:deployment] if args.key?(:deployment) @discovery = args[:discovery] if args.key?(:discovery) @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation) @envelope = args[:envelope] if args.key?(:envelope) @image = args[:image] if args.key?(:image) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @note_name = args[:note_name] if args.key?(:note_name) @package = args[:package] if args.key?(:package) @remediation = args[:remediation] if args.key?(:remediation) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference) @secret = args[:secret] if args.key?(:secret) @update_time = args[:update_time] if args.key?(:update_time) @upgrade = args[:upgrade] if args.key?(:upgrade) @vulnerability = args[:vulnerability] if args.key?(:vulnerability) end |