Class: Google::Apis::ContaineranalysisV1::Occurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

An instance of an analysis type that has been found on a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Occurrence

Returns a new instance of Occurrence.



5897
5898
5899
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advisory_publish_timeString

The time this advisory was published by the source. Corresponds to the JSON property advisoryPublishTime

Returns:

  • (String)


5768
5769
5770
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5768

def advisory_publish_time
  @advisory_publish_time
end

#ai_skill_analysisGoogle::Apis::ContaineranalysisV1::AiSkillAnalysisOccurrence

AISkillAnalysisOccurrence provides the results of an AI-based skill analysis. Corresponds to the JSON property aiSkillAnalysis



5773
5774
5775
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5773

def ai_skill_analysis
  @ai_skill_analysis
end

#attestationGoogle::Apis::ContaineranalysisV1::AttestationOccurrence

Occurrence that represents a single "attestation". The authenticity of an attestation can be verified using the attached signature. If the verifier trusts the public key of the signer, then verifying the signature is sufficient to establish trust. In this circumstance, the authority to which this attestation is attached is primarily useful for lookup (how to find this attestation if you already know the authority and artifact to be verified) and intent (for which authority this attestation was intended to sign. Corresponds to the JSON property attestation



5784
5785
5786
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5784

def attestation
  @attestation
end

#buildGoogle::Apis::ContaineranalysisV1::BuildOccurrence

Details of a build occurrence. Corresponds to the JSON property build



5789
5790
5791
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5789

def build
  @build
end

#complianceGoogle::Apis::ContaineranalysisV1::ComplianceOccurrence

An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason. Corresponds to the JSON property compliance



5795
5796
5797
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5795

def compliance
  @compliance
end

#create_timeString

Output only. The time this occurrence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5800
5801
5802
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5800

def create_time
  @create_time
end

#deploymentGoogle::Apis::ContaineranalysisV1::DeploymentOccurrence

The period during which some deployable was active in a runtime. Corresponds to the JSON property deployment



5805
5806
5807
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5805

def deployment
  @deployment
end

#discoveryGoogle::Apis::ContaineranalysisV1::DiscoveryOccurrence

Provides information about the analysis status of a discovered resource. Corresponds to the JSON property discovery



5810
5811
5812
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5810

def discovery
  @discovery
end

#dsse_attestationGoogle::Apis::ContaineranalysisV1::DsseAttestationOccurrence

Deprecated. Prefer to use a regular Occurrence, and populate the Envelope at the top level of the Occurrence. Corresponds to the JSON property dsseAttestation



5816
5817
5818
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5816

def dsse_attestation
  @dsse_attestation
end

#envelopeGoogle::Apis::ContaineranalysisV1::Envelope

MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope. proto. An authenticated message of arbitrary type. Corresponds to the JSON property envelope



5822
5823
5824
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5822

def envelope
  @envelope
end

#imageGoogle::Apis::ContaineranalysisV1::ImageOccurrence

Details of the derived image portion of the DockerImage relationship. This image would be produced from a Dockerfile with FROM . Corresponds to the JSON property image



5828
5829
5830
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5828

def image
  @image
end

#kindString

Output only. This explicitly denotes which of the occurrence details are specified. This field can be used as a filter in list requests. Corresponds to the JSON property kind

Returns:

  • (String)


5834
5835
5836
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5834

def kind
  @kind
end

#nameString

Output only. The name of the occurrence in the form of projects/[PROJECT_ID]/ occurrences/[OCCURRENCE_ID]. Corresponds to the JSON property name

Returns:

  • (String)


5840
5841
5842
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5840

def name
  @name
end

#note_nameString

Required. Immutable. The analysis note associated with this occurrence, in the form of projects/[PROVIDER_ID]/notes/[NOTE_ID]. This field can be used as a filter in list requests. Corresponds to the JSON property noteName

Returns:

  • (String)


5847
5848
5849
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5847

def note_name
  @note_name
end

#packageGoogle::Apis::ContaineranalysisV1::PackageOccurrence

Details on how a particular software package was installed on a system. Corresponds to the JSON property package



5852
5853
5854
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5852

def package
  @package
end

#remediationString

A description of actions that can be taken to remedy the note. Corresponds to the JSON property remediation

Returns:

  • (String)


5857
5858
5859
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5857

def remediation
  @remediation
end

#resource_uriString

Required. Immutable. A URI that represents the resource for which the occurrence applies. For example, https://gcr.io/project/image@sha256:123abc for a Docker image. Corresponds to the JSON property resourceUri

Returns:

  • (String)


5864
5865
5866
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5864

def resource_uri
  @resource_uri
end

#sbom_referenceGoogle::Apis::ContaineranalysisV1::SbomReferenceOccurrence

The occurrence representing an SBOM reference as applied to a specific resource. The occurrence follows the DSSE specification. See https://github. com/secure-systems-lab/dsse/blob/master/envelope.md for more details. Corresponds to the JSON property sbomReference



5871
5872
5873
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5871

def sbom_reference
  @sbom_reference
end

#secretGoogle::Apis::ContaineranalysisV1::SecretOccurrence

The occurrence provides details of a secret. Corresponds to the JSON property secret



5876
5877
5878
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5876

def secret
  @secret
end

#update_timeString

Output only. The time this occurrence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5881
5882
5883
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5881

def update_time
  @update_time
end

#upgradeGoogle::Apis::ContaineranalysisV1::UpgradeOccurrence

An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability). For Windows, both distribution and windows_update contain information for the Windows update. Corresponds to the JSON property upgrade



5890
5891
5892
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5890

def upgrade
  @upgrade
end

#vulnerabilityGoogle::Apis::ContaineranalysisV1::VulnerabilityOccurrence

An occurrence of a severity vulnerability on a resource. Corresponds to the JSON property vulnerability



5895
5896
5897
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5895

def vulnerability
  @vulnerability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5902

def update!(**args)
  @advisory_publish_time = args[:advisory_publish_time] if args.key?(:advisory_publish_time)
  @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis)
  @attestation = args[:attestation] if args.key?(:attestation)
  @build = args[:build] if args.key?(:build)
  @compliance = args[:compliance] if args.key?(:compliance)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployment = args[:deployment] if args.key?(:deployment)
  @discovery = args[:discovery] if args.key?(:discovery)
  @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation)
  @envelope = args[:envelope] if args.key?(:envelope)
  @image = args[:image] if args.key?(:image)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @note_name = args[:note_name] if args.key?(:note_name)
  @package = args[:package] if args.key?(:package)
  @remediation = args[:remediation] if args.key?(:remediation)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference)
  @secret = args[:secret] if args.key?(:secret)
  @update_time = args[:update_time] if args.key?(:update_time)
  @upgrade = args[:upgrade] if args.key?(:upgrade)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
end