Class: Google::Apis::ContaineranalysisV1::Occurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Occurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
An instance of an analysis type that has been found on a resource.
Instance Attribute Summary collapse
-
#advisory_publish_time ⇒ String
The time this advisory was published by the source.
-
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1::AiSkillAnalysisOccurrence
AISkillAnalysisOccurrence provides the results of an AI-based skill analysis.
-
#attestation ⇒ Google::Apis::ContaineranalysisV1::AttestationOccurrence
Occurrence that represents a single "attestation".
-
#build ⇒ Google::Apis::ContaineranalysisV1::BuildOccurrence
Details of a build occurrence.
-
#compliance ⇒ Google::Apis::ContaineranalysisV1::ComplianceOccurrence
An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason.
-
#create_time ⇒ String
Output only.
-
#deployment ⇒ Google::Apis::ContaineranalysisV1::DeploymentOccurrence
The period during which some deployable was active in a runtime.
-
#discovery ⇒ Google::Apis::ContaineranalysisV1::DiscoveryOccurrence
Provides information about the analysis status of a discovered resource.
-
#dsse_attestation ⇒ Google::Apis::ContaineranalysisV1::DsseAttestationOccurrence
Deprecated.
- #envelope ⇒ Google::Apis::ContaineranalysisV1::Envelope
-
#image ⇒ Google::Apis::ContaineranalysisV1::ImageOccurrence
Details of the derived image portion of the DockerImage relationship.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#note_name ⇒ String
Required.
-
#package ⇒ Google::Apis::ContaineranalysisV1::PackageOccurrence
Details on how a particular software package was installed on a system.
-
#remediation ⇒ String
A description of actions that can be taken to remedy the note.
-
#resource_uri ⇒ String
Required.
-
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1::SbomReferenceOccurrence
The occurrence representing an SBOM reference as applied to a specific resource.
-
#secret ⇒ Google::Apis::ContaineranalysisV1::SecretOccurrence
The occurrence provides details of a secret.
-
#update_time ⇒ String
Output only.
-
#upgrade ⇒ Google::Apis::ContaineranalysisV1::UpgradeOccurrence
An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade.
-
#vulnerability ⇒ Google::Apis::ContaineranalysisV1::VulnerabilityOccurrence
An occurrence of a severity vulnerability on a resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Occurrence
constructor
A new instance of Occurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Occurrence
Returns a new instance of Occurrence.
5843 5844 5845 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5843 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advisory_publish_time ⇒ String
The time this advisory was published by the source.
Corresponds to the JSON property advisoryPublishTime
5714 5715 5716 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5714 def advisory_publish_time @advisory_publish_time end |
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1::AiSkillAnalysisOccurrence
AISkillAnalysisOccurrence provides the results of an AI-based skill analysis.
Corresponds to the JSON property aiSkillAnalysis
5719 5720 5721 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5719 def ai_skill_analysis @ai_skill_analysis end |
#attestation ⇒ Google::Apis::ContaineranalysisV1::AttestationOccurrence
Occurrence that represents a single "attestation". The authenticity of an
attestation can be verified using the attached signature. If the verifier
trusts the public key of the signer, then verifying the signature is
sufficient to establish trust. In this circumstance, the authority to which
this attestation is attached is primarily useful for lookup (how to find this
attestation if you already know the authority and artifact to be verified) and
intent (for which authority this attestation was intended to sign.
Corresponds to the JSON property attestation
5730 5731 5732 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5730 def attestation @attestation end |
#build ⇒ Google::Apis::ContaineranalysisV1::BuildOccurrence
Details of a build occurrence.
Corresponds to the JSON property build
5735 5736 5737 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5735 def build @build end |
#compliance ⇒ Google::Apis::ContaineranalysisV1::ComplianceOccurrence
An indication that the compliance checks in the associated ComplianceNote were
not satisfied for particular resources or a specified reason.
Corresponds to the JSON property compliance
5741 5742 5743 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5741 def compliance @compliance end |
#create_time ⇒ String
Output only. The time this occurrence was created.
Corresponds to the JSON property createTime
5746 5747 5748 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5746 def create_time @create_time end |
#deployment ⇒ Google::Apis::ContaineranalysisV1::DeploymentOccurrence
The period during which some deployable was active in a runtime.
Corresponds to the JSON property deployment
5751 5752 5753 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5751 def deployment @deployment end |
#discovery ⇒ Google::Apis::ContaineranalysisV1::DiscoveryOccurrence
Provides information about the analysis status of a discovered resource.
Corresponds to the JSON property discovery
5756 5757 5758 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5756 def discovery @discovery end |
#dsse_attestation ⇒ Google::Apis::ContaineranalysisV1::DsseAttestationOccurrence
Deprecated. Prefer to use a regular Occurrence, and populate the Envelope at
the top level of the Occurrence.
Corresponds to the JSON property dsseAttestation
5762 5763 5764 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5762 def dsse_attestation @dsse_attestation end |
#envelope ⇒ Google::Apis::ContaineranalysisV1::Envelope
MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope.
proto. An authenticated message of arbitrary type.
Corresponds to the JSON property envelope
5768 5769 5770 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5768 def envelope @envelope end |
#image ⇒ Google::Apis::ContaineranalysisV1::ImageOccurrence
Details of the derived image portion of the DockerImage relationship. This
image would be produced from a Dockerfile with FROM .
Corresponds to the JSON property image
5774 5775 5776 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5774 def image @image end |
#kind ⇒ String
Output only. This explicitly denotes which of the occurrence details are
specified. This field can be used as a filter in list requests.
Corresponds to the JSON property kind
5780 5781 5782 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5780 def kind @kind end |
#name ⇒ String
Output only. The name of the occurrence in the form of projects/[PROJECT_ID]/
occurrences/[OCCURRENCE_ID].
Corresponds to the JSON property name
5786 5787 5788 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5786 def name @name end |
#note_name ⇒ String
Required. Immutable. The analysis note associated with this occurrence, in the
form of projects/[PROVIDER_ID]/notes/[NOTE_ID]. This field can be used as a
filter in list requests.
Corresponds to the JSON property noteName
5793 5794 5795 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5793 def note_name @note_name end |
#package ⇒ Google::Apis::ContaineranalysisV1::PackageOccurrence
Details on how a particular software package was installed on a system.
Corresponds to the JSON property package
5798 5799 5800 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5798 def package @package end |
#remediation ⇒ String
A description of actions that can be taken to remedy the note.
Corresponds to the JSON property remediation
5803 5804 5805 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5803 def remediation @remediation end |
#resource_uri ⇒ String
Required. Immutable. A URI that represents the resource for which the
occurrence applies. For example, https://gcr.io/project/image@sha256:123abc
for a Docker image.
Corresponds to the JSON property resourceUri
5810 5811 5812 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5810 def resource_uri @resource_uri end |
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1::SbomReferenceOccurrence
The occurrence representing an SBOM reference as applied to a specific
resource. The occurrence follows the DSSE specification. See https://github.
com/secure-systems-lab/dsse/blob/master/envelope.md for more details.
Corresponds to the JSON property sbomReference
5817 5818 5819 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5817 def sbom_reference @sbom_reference end |
#secret ⇒ Google::Apis::ContaineranalysisV1::SecretOccurrence
The occurrence provides details of a secret.
Corresponds to the JSON property secret
5822 5823 5824 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5822 def secret @secret end |
#update_time ⇒ String
Output only. The time this occurrence was last updated.
Corresponds to the JSON property updateTime
5827 5828 5829 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5827 def update_time @update_time end |
#upgrade ⇒ Google::Apis::ContaineranalysisV1::UpgradeOccurrence
An Upgrade Occurrence represents that a specific resource_url could install a
specific upgrade. This presence is supplied via local sources (i.e. it is
present in the mirror and the running system has noticed its availability).
For Windows, both distribution and windows_update contain information for the
Windows update.
Corresponds to the JSON property upgrade
5836 5837 5838 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5836 def upgrade @upgrade end |
#vulnerability ⇒ Google::Apis::ContaineranalysisV1::VulnerabilityOccurrence
An occurrence of a severity vulnerability on a resource.
Corresponds to the JSON property vulnerability
5841 5842 5843 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5841 def vulnerability @vulnerability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5848 5849 5850 5851 5852 5853 5854 5855 5856 5857 5858 5859 5860 5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5848 def update!(**args) @advisory_publish_time = args[:advisory_publish_time] if args.key?(:advisory_publish_time) @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis) @attestation = args[:attestation] if args.key?(:attestation) @build = args[:build] if args.key?(:build) @compliance = args[:compliance] if args.key?(:compliance) @create_time = args[:create_time] if args.key?(:create_time) @deployment = args[:deployment] if args.key?(:deployment) @discovery = args[:discovery] if args.key?(:discovery) @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation) @envelope = args[:envelope] if args.key?(:envelope) @image = args[:image] if args.key?(:image) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @note_name = args[:note_name] if args.key?(:note_name) @package = args[:package] if args.key?(:package) @remediation = args[:remediation] if args.key?(:remediation) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference) @secret = args[:secret] if args.key?(:secret) @update_time = args[:update_time] if args.key?(:update_time) @upgrade = args[:upgrade] if args.key?(:upgrade) @vulnerability = args[:vulnerability] if args.key?(:vulnerability) end |