Class: Google::Apis::ContaineranalysisV1::PackageIssue
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::PackageIssue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
A detail for a distro and package this vulnerability occurrence was found in and its associated fix (if one is available).
Instance Attribute Summary collapse
-
#affected_cpe_uri ⇒ String
Required.
-
#affected_package ⇒ String
Required.
-
#affected_version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
-
#effective_severity ⇒ String
Output only.
-
#file_location ⇒ Array<Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation>
The location at which this package was found.
-
#fix_available ⇒ Boolean
(also: #fix_available?)
Output only.
-
#fixed_cpe_uri ⇒ String
The CPE URI this vulnerability was fixed in.
-
#fixed_package ⇒ String
The package this vulnerability was fixed in.
-
#fixed_version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
-
#package_type ⇒ String
The type of package (e.g. OS, MAVEN, GO).
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageIssue
constructor
A new instance of PackageIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageIssue
Returns a new instance of PackageIssue.
5995 5996 5997 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affected_cpe_uri ⇒ String
Required. The CPE URI this
vulnerability was found in.
Corresponds to the JSON property affectedCpeUri
5943 5944 5945 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5943 def affected_cpe_uri @affected_cpe_uri end |
#affected_package ⇒ String
Required. The package this vulnerability was found in.
Corresponds to the JSON property affectedPackage
5948 5949 5950 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5948 def affected_package @affected_package end |
#affected_version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property affectedVersion
5953 5954 5955 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5953 def affected_version @affected_version end |
#effective_severity ⇒ String
Output only. The distro or language system assigned severity for this
vulnerability when that is available and note provider assigned severity when
it is not available.
Corresponds to the JSON property effectiveSeverity
5960 5961 5962 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5960 def effective_severity @effective_severity end |
#file_location ⇒ Array<Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation>
The location at which this package was found.
Corresponds to the JSON property fileLocation
5965 5966 5967 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5965 def file_location @file_location end |
#fix_available ⇒ Boolean Also known as: fix_available?
Output only. Whether a fix is available for this package.
Corresponds to the JSON property fixAvailable
5970 5971 5972 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5970 def fix_available @fix_available end |
#fixed_cpe_uri ⇒ String
The CPE URI this vulnerability was
fixed in. It is possible for this to be different from the affected_cpe_uri.
Corresponds to the JSON property fixedCpeUri
5977 5978 5979 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5977 def fixed_cpe_uri @fixed_cpe_uri end |
#fixed_package ⇒ String
The package this vulnerability was fixed in. It is possible for this to be
different from the affected_package.
Corresponds to the JSON property fixedPackage
5983 5984 5985 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5983 def fixed_package @fixed_package end |
#fixed_version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property fixedVersion
5988 5989 5990 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5988 def fixed_version @fixed_version end |
#package_type ⇒ String
The type of package (e.g. OS, MAVEN, GO).
Corresponds to the JSON property packageType
5993 5994 5995 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5993 def package_type @package_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6000 6001 6002 6003 6004 6005 6006 6007 6008 6009 6010 6011 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6000 def update!(**args) @affected_cpe_uri = args[:affected_cpe_uri] if args.key?(:affected_cpe_uri) @affected_package = args[:affected_package] if args.key?(:affected_package) @affected_version = args[:affected_version] if args.key?(:affected_version) @effective_severity = args[:effective_severity] if args.key?(:effective_severity) @file_location = args[:file_location] if args.key?(:file_location) @fix_available = args[:fix_available] if args.key?(:fix_available) @fixed_cpe_uri = args[:fixed_cpe_uri] if args.key?(:fixed_cpe_uri) @fixed_package = args[:fixed_package] if args.key?(:fixed_package) @fixed_version = args[:fixed_version] if args.key?(:fixed_version) @package_type = args[:package_type] if args.key?(:package_type) end |