Class: Google::Apis::ContaineranalysisV1::PackageIssue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A detail for a distro and package this vulnerability occurrence was found in and its associated fix (if one is available).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageIssue

Returns a new instance of PackageIssue.



5948
5949
5950
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_cpe_uriString

Required. The CPE URI this vulnerability was found in. Corresponds to the JSON property affectedCpeUri

Returns:

  • (String)


5896
5897
5898
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5896

def affected_cpe_uri
  @affected_cpe_uri
end

#affected_packageString

Required. The package this vulnerability was found in. Corresponds to the JSON property affectedPackage

Returns:

  • (String)


5901
5902
5903
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5901

def affected_package
  @affected_package
end

#affected_versionGoogle::Apis::ContaineranalysisV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property affectedVersion



5906
5907
5908
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5906

def affected_version
  @affected_version
end

#effective_severityString

Output only. The distro or language system assigned severity for this vulnerability when that is available and note provider assigned severity when it is not available. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


5913
5914
5915
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5913

def effective_severity
  @effective_severity
end

#file_locationArray<Google::Apis::ContaineranalysisV1::GrafeasV1FileLocation>

The location at which this package was found. Corresponds to the JSON property fileLocation



5918
5919
5920
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5918

def file_location
  @file_location
end

#fix_availableBoolean Also known as: fix_available?

Output only. Whether a fix is available for this package. Corresponds to the JSON property fixAvailable

Returns:

  • (Boolean)


5923
5924
5925
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5923

def fix_available
  @fix_available
end

#fixed_cpe_uriString

The CPE URI this vulnerability was fixed in. It is possible for this to be different from the affected_cpe_uri. Corresponds to the JSON property fixedCpeUri

Returns:

  • (String)


5930
5931
5932
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5930

def fixed_cpe_uri
  @fixed_cpe_uri
end

#fixed_packageString

The package this vulnerability was fixed in. It is possible for this to be different from the affected_package. Corresponds to the JSON property fixedPackage

Returns:

  • (String)


5936
5937
5938
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5936

def fixed_package
  @fixed_package
end

#fixed_versionGoogle::Apis::ContaineranalysisV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property fixedVersion



5941
5942
5943
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5941

def fixed_version
  @fixed_version
end

#package_typeString

The type of package (e.g. OS, MAVEN, GO). Corresponds to the JSON property packageType

Returns:

  • (String)


5946
5947
5948
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5946

def package_type
  @package_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5953

def update!(**args)
  @affected_cpe_uri = args[:affected_cpe_uri] if args.key?(:affected_cpe_uri)
  @affected_package = args[:affected_package] if args.key?(:affected_package)
  @affected_version = args[:affected_version] if args.key?(:affected_version)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @file_location = args[:file_location] if args.key?(:file_location)
  @fix_available = args[:fix_available] if args.key?(:fix_available)
  @fixed_cpe_uri = args[:fixed_cpe_uri] if args.key?(:fixed_cpe_uri)
  @fixed_package = args[:fixed_package] if args.key?(:fixed_package)
  @fixed_version = args[:fixed_version] if args.key?(:fixed_version)
  @package_type = args[:package_type] if args.key?(:package_type)
end