Class: Google::Apis::ContaineranalysisV1::PackageNote
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::PackageNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
PackageNote represents a particular package version.
Instance Attribute Summary collapse
-
#architecture ⇒ String
The CPU architecture for which packages in this distribution channel were built.
-
#cpe_uri ⇒ String
The cpe_uri in CPE format denoting the package manager version distributing a package.
-
#description ⇒ String
The description of this package.
-
#digest ⇒ Array<Google::Apis::ContaineranalysisV1::Digest>
Hash value, typically a file digest, that allows unique identification a specific package.
-
#distribution ⇒ Array<Google::Apis::ContaineranalysisV1::Distribution>
Deprecated.
-
#license ⇒ Google::Apis::ContaineranalysisV1::License
License information.
-
#maintainer ⇒ String
A freeform text denoting the maintainer of this package.
-
#name ⇒ String
Required.
-
#package_type ⇒ String
The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.).
-
#url ⇒ String
The homepage for this package.
-
#version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageNote
constructor
A new instance of PackageNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageNote
Returns a new instance of PackageNote.
6031 6032 6033 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
The CPU architecture for which packages in this distribution channel were
built. Architecture will be blank for language packages.
Corresponds to the JSON property architecture
5975 5976 5977 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5975 def architecture @architecture end |
#cpe_uri ⇒ String
The cpe_uri in CPE format denoting the
package manager version distributing a package. The cpe_uri will be blank for
language packages.
Corresponds to the JSON property cpeUri
5982 5983 5984 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5982 def cpe_uri @cpe_uri end |
#description ⇒ String
The description of this package.
Corresponds to the JSON property description
5987 5988 5989 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5987 def description @description end |
#digest ⇒ Array<Google::Apis::ContaineranalysisV1::Digest>
Hash value, typically a file digest, that allows unique identification a
specific package.
Corresponds to the JSON property digest
5993 5994 5995 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5993 def digest @digest end |
#distribution ⇒ Array<Google::Apis::ContaineranalysisV1::Distribution>
Deprecated. The various channels by which a package is distributed.
Corresponds to the JSON property distribution
5998 5999 6000 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5998 def distribution @distribution end |
#license ⇒ Google::Apis::ContaineranalysisV1::License
License information.
Corresponds to the JSON property license
6003 6004 6005 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6003 def license @license end |
#maintainer ⇒ String
A freeform text denoting the maintainer of this package.
Corresponds to the JSON property maintainer
6008 6009 6010 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6008 def maintainer @maintainer end |
#name ⇒ String
Required. Immutable. The name of the package.
Corresponds to the JSON property name
6013 6014 6015 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6013 def name @name end |
#package_type ⇒ String
The type of package; whether native or non native (e.g., ruby gems, node.js
packages, etc.).
Corresponds to the JSON property packageType
6019 6020 6021 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6019 def package_type @package_type end |
#url ⇒ String
The homepage for this package.
Corresponds to the JSON property url
6024 6025 6026 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6024 def url @url end |
#version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property version
6029 6030 6031 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6029 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6036 6037 6038 6039 6040 6041 6042 6043 6044 6045 6046 6047 6048 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6036 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @description = args[:description] if args.key?(:description) @digest = args[:digest] if args.key?(:digest) @distribution = args[:distribution] if args.key?(:distribution) @license = args[:license] if args.key?(:license) @maintainer = args[:maintainer] if args.key?(:maintainer) @name = args[:name] if args.key?(:name) @package_type = args[:package_type] if args.key?(:package_type) @url = args[:url] if args.key?(:url) @version = args[:version] if args.key?(:version) end |