Class: Google::Apis::ContaineranalysisV1::PackageNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

PackageNote represents a particular package version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageNote

Returns a new instance of PackageNote.



6018
6019
6020
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6018

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The CPU architecture for which packages in this distribution channel were built. Architecture will be blank for language packages. Corresponds to the JSON property architecture

Returns:

  • (String)


5962
5963
5964
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5962

def architecture
  @architecture
end

#cpe_uriString

The cpe_uri in CPE format denoting the package manager version distributing a package. The cpe_uri will be blank for language packages. Corresponds to the JSON property cpeUri

Returns:

  • (String)


5969
5970
5971
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5969

def cpe_uri
  @cpe_uri
end

#descriptionString

The description of this package. Corresponds to the JSON property description

Returns:

  • (String)


5974
5975
5976
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5974

def description
  @description
end

#digestArray<Google::Apis::ContaineranalysisV1::Digest>

Hash value, typically a file digest, that allows unique identification a specific package. Corresponds to the JSON property digest



5980
5981
5982
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5980

def digest
  @digest
end

#distributionArray<Google::Apis::ContaineranalysisV1::Distribution>

Deprecated. The various channels by which a package is distributed. Corresponds to the JSON property distribution



5985
5986
5987
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5985

def distribution
  @distribution
end

#licenseGoogle::Apis::ContaineranalysisV1::License

License information. Corresponds to the JSON property license



5990
5991
5992
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5990

def license
  @license
end

#maintainerString

A freeform text denoting the maintainer of this package. Corresponds to the JSON property maintainer

Returns:

  • (String)


5995
5996
5997
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5995

def maintainer
  @maintainer
end

#nameString

Required. Immutable. The name of the package. Corresponds to the JSON property name

Returns:

  • (String)


6000
6001
6002
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6000

def name
  @name
end

#package_typeString

The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.). Corresponds to the JSON property packageType

Returns:

  • (String)


6006
6007
6008
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6006

def package_type
  @package_type
end

#urlString

The homepage for this package. Corresponds to the JSON property url

Returns:

  • (String)


6011
6012
6013
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6011

def url
  @url
end

#versionGoogle::Apis::ContaineranalysisV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property version



6016
6017
6018
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6016

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6023
6024
6025
6026
6027
6028
6029
6030
6031
6032
6033
6034
6035
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6023

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @description = args[:description] if args.key?(:description)
  @digest = args[:digest] if args.key?(:digest)
  @distribution = args[:distribution] if args.key?(:distribution)
  @license = args[:license] if args.key?(:license)
  @maintainer = args[:maintainer] if args.key?(:maintainer)
  @name = args[:name] if args.key?(:name)
  @package_type = args[:package_type] if args.key?(:package_type)
  @url = args[:url] if args.key?(:url)
  @version = args[:version] if args.key?(:version)
end