Class: Google::Apis::ContaineranalysisV1::PackageNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

PackageNote represents a particular package version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageNote

Returns a new instance of PackageNote.



5664
5665
5666
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5664

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The CPU architecture for which packages in this distribution channel were built. Architecture will be blank for language packages. Corresponds to the JSON property architecture

Returns:

  • (String)


5608
5609
5610
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5608

def architecture
  @architecture
end

#cpe_uriString

The cpe_uri in CPE format denoting the package manager version distributing a package. The cpe_uri will be blank for language packages. Corresponds to the JSON property cpeUri

Returns:

  • (String)


5615
5616
5617
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5615

def cpe_uri
  @cpe_uri
end

#descriptionString

The description of this package. Corresponds to the JSON property description

Returns:

  • (String)


5620
5621
5622
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5620

def description
  @description
end

#digestArray<Google::Apis::ContaineranalysisV1::Digest>

Hash value, typically a file digest, that allows unique identification a specific package. Corresponds to the JSON property digest



5626
5627
5628
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5626

def digest
  @digest
end

#distributionArray<Google::Apis::ContaineranalysisV1::Distribution>

Deprecated. The various channels by which a package is distributed. Corresponds to the JSON property distribution



5631
5632
5633
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5631

def distribution
  @distribution
end

#licenseGoogle::Apis::ContaineranalysisV1::License

License information. Corresponds to the JSON property license



5636
5637
5638
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5636

def license
  @license
end

#maintainerString

A freeform text denoting the maintainer of this package. Corresponds to the JSON property maintainer

Returns:

  • (String)


5641
5642
5643
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5641

def maintainer
  @maintainer
end

#nameString

Required. Immutable. The name of the package. Corresponds to the JSON property name

Returns:

  • (String)


5646
5647
5648
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5646

def name
  @name
end

#package_typeString

The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.). Corresponds to the JSON property packageType

Returns:

  • (String)


5652
5653
5654
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5652

def package_type
  @package_type
end

#urlString

The homepage for this package. Corresponds to the JSON property url

Returns:

  • (String)


5657
5658
5659
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5657

def url
  @url
end

#versionGoogle::Apis::ContaineranalysisV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property version



5662
5663
5664
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5662

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5669

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @description = args[:description] if args.key?(:description)
  @digest = args[:digest] if args.key?(:digest)
  @distribution = args[:distribution] if args.key?(:distribution)
  @license = args[:license] if args.key?(:license)
  @maintainer = args[:maintainer] if args.key?(:maintainer)
  @name = args[:name] if args.key?(:name)
  @package_type = args[:package_type] if args.key?(:package_type)
  @url = args[:url] if args.key?(:url)
  @version = args[:version] if args.key?(:version)
end