Class: Google::Apis::ContaineranalysisV1::PackageOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::PackageOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Details on how a particular software package was installed on a system.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#cpe_uri ⇒ String
Output only.
-
#license ⇒ Google::Apis::ContaineranalysisV1::License
License information.
-
#location ⇒ Array<Google::Apis::ContaineranalysisV1::Location>
All of the places within the filesystem versions of this package have been found.
-
#name ⇒ String
Required.
-
#package_type ⇒ String
Output only.
-
#version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageOccurrence
constructor
A new instance of PackageOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageOccurrence
Returns a new instance of PackageOccurrence.
5716 5717 5718 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5716 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. The CPU architecture for which packages in this distribution
channel were built. Architecture will be blank for language packages.
Corresponds to the JSON property architecture
5680 5681 5682 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5680 def architecture @architecture end |
#cpe_uri ⇒ String
Output only. The cpe_uri in CPE format
denoting the package manager version distributing a package. The cpe_uri will
be blank for language packages.
Corresponds to the JSON property cpeUri
5687 5688 5689 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5687 def cpe_uri @cpe_uri end |
#license ⇒ Google::Apis::ContaineranalysisV1::License
License information.
Corresponds to the JSON property license
5692 5693 5694 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5692 def license @license end |
#location ⇒ Array<Google::Apis::ContaineranalysisV1::Location>
All of the places within the filesystem versions of this package have been
found.
Corresponds to the JSON property location
5698 5699 5700 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5698 def location @location end |
#name ⇒ String
Required. Output only. The name of the installed package.
Corresponds to the JSON property name
5703 5704 5705 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5703 def name @name end |
#package_type ⇒ String
Output only. The type of package; whether native or non native (e.g., ruby
gems, node.js packages, etc.).
Corresponds to the JSON property packageType
5709 5710 5711 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5709 def package_type @package_type end |
#version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property version
5714 5715 5716 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5714 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5721 5722 5723 5724 5725 5726 5727 5728 5729 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5721 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @license = args[:license] if args.key?(:license) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @package_type = args[:package_type] if args.key?(:package_type) @version = args[:version] if args.key?(:version) end |