Class: Google::Apis::ContaineranalysisV1::Publisher
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Publisher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Publisher contains information about the publisher of this Note.
Instance Attribute Summary collapse
-
#issuing_authority ⇒ String
Provides information about the authority of the issuing party to release the document, in particular, the party's constituency and responsibilities or other obligations.
-
#name ⇒ String
Name of the publisher.
-
#publisher_namespace ⇒ String
The context or namespace.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Publisher
constructor
A new instance of Publisher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Publisher
Returns a new instance of Publisher.
5947 5948 5949 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5947 def initialize(**args) update!(**args) end |
Instance Attribute Details
#issuing_authority ⇒ String
Provides information about the authority of the issuing party to release the
document, in particular, the party's constituency and responsibilities or
other obligations.
Corresponds to the JSON property issuingAuthority
5933 5934 5935 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5933 def @issuing_authority end |
#name ⇒ String
Name of the publisher. Examples: 'Google', 'Google Cloud Platform'.
Corresponds to the JSON property name
5938 5939 5940 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5938 def name @name end |
#publisher_namespace ⇒ String
The context or namespace. Contains a URL which is under control of the issuing
party and can be used as a globally unique identifier for that issuing party.
Example: https://csaf.io
Corresponds to the JSON property publisherNamespace
5945 5946 5947 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5945 def publisher_namespace @publisher_namespace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5952 5953 5954 5955 5956 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 5952 def update!(**args) @issuing_authority = args[:issuing_authority] if args.key?(:issuing_authority) @name = args[:name] if args.key?(:name) @publisher_namespace = args[:publisher_namespace] if args.key?(:publisher_namespace) end |