Class: Google::Apis::ContaineranalysisV1::Risk
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Risk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Instance Attribute Summary collapse
-
#cisa_kev ⇒ Google::Apis::ContaineranalysisV1::CisaKnownExploitedVulnerabilities
CISA maintains the authoritative source of vulnerabilities that have been exploited in the wild.
-
#epss ⇒ Google::Apis::ContaineranalysisV1::ExploitPredictionScoringSystem
The Exploit Prediction Scoring System (EPSS) estimates the likelihood ( probability) that a software vulnerability will be exploited in the wild.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Risk
constructor
A new instance of Risk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Risk
Returns a new instance of Risk.
6238 6239 6240 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6238 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cisa_kev ⇒ Google::Apis::ContaineranalysisV1::CisaKnownExploitedVulnerabilities
CISA maintains the authoritative source of vulnerabilities that have been
exploited in the wild.
Corresponds to the JSON property cisaKev
6230 6231 6232 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6230 def cisa_kev @cisa_kev end |
#epss ⇒ Google::Apis::ContaineranalysisV1::ExploitPredictionScoringSystem
The Exploit Prediction Scoring System (EPSS) estimates the likelihood (
probability) that a software vulnerability will be exploited in the wild.
Corresponds to the JSON property epss
6236 6237 6238 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6236 def epss @epss end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6243 6244 6245 6246 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6243 def update!(**args) @cisa_kev = args[:cisa_kev] if args.key?(:cisa_kev) @epss = args[:epss] if args.key?(:epss) end |