Class: Google::Apis::ContaineranalysisV1::Risk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Risk

Returns a new instance of Risk.



6174
6175
6176
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6174

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cisa_kevGoogle::Apis::ContaineranalysisV1::CisaKnownExploitedVulnerabilities

CISA maintains the authoritative source of vulnerabilities that have been exploited in the wild. Corresponds to the JSON property cisaKev



6166
6167
6168
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6166

def cisa_kev
  @cisa_kev
end

#epssGoogle::Apis::ContaineranalysisV1::ExploitPredictionScoringSystem

The Exploit Prediction Scoring System (EPSS) estimates the likelihood ( probability) that a software vulnerability will be exploited in the wild. Corresponds to the JSON property epss



6172
6173
6174
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6172

def epss
  @epss
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6179
6180
6181
6182
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6179

def update!(**args)
  @cisa_kev = args[:cisa_kev] if args.key?(:cisa_kev)
  @epss = args[:epss] if args.key?(:epss)
end