Class: Google::Apis::ContaineranalysisV1::SlsaCompleteness

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Indicates that the builder claims certain fields in this message to be complete.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaCompleteness

Returns a new instance of SlsaCompleteness.



6986
6987
6988
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6986

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argumentsBoolean Also known as: arguments?

If true, the builder claims that recipe.arguments is complete, meaning that all external inputs are properly captured in the recipe. Corresponds to the JSON property arguments

Returns:

  • (Boolean)


6970
6971
6972
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6970

def arguments
  @arguments
end

#environmentBoolean Also known as: environment?

If true, the builder claims that recipe.environment is claimed to be complete. Corresponds to the JSON property environment

Returns:

  • (Boolean)


6976
6977
6978
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6976

def environment
  @environment
end

#materialsBoolean Also known as: materials?

If true, the builder claims that materials are complete, usually through some controls to prevent network access. Sometimes called "hermetic". Corresponds to the JSON property materials

Returns:

  • (Boolean)


6983
6984
6985
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6983

def materials
  @materials
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6991
6992
6993
6994
6995
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6991

def update!(**args)
  @arguments = args[:arguments] if args.key?(:arguments)
  @environment = args[:environment] if args.key?(:environment)
  @materials = args[:materials] if args.key?(:materials)
end