Class: Google::Apis::ContaineranalysisV1::SlsaProvenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenance

Returns a new instance of SlsaProvenance.



7121
7122
7123
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builderGoogle::Apis::ContaineranalysisV1::SlsaBuilder

required Corresponds to the JSON property builder



7100
7101
7102
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7100

def builder
  @builder
end

#materialsArray<Google::Apis::ContaineranalysisV1::Material>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials



7108
7109
7110
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7108

def materials
  @materials
end

#metadataGoogle::Apis::ContaineranalysisV1::SlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



7113
7114
7115
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7113

def 
  @metadata
end

#recipeGoogle::Apis::ContaineranalysisV1::SlsaRecipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



7119
7120
7121
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7119

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7126
7127
7128
7129
7130
7131
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7126

def update!(**args)
  @builder = args[:builder] if args.key?(:builder)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end