Class: Google::Apis::ContaineranalysisV1::SlsaProvenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenance

Returns a new instance of SlsaProvenance.



7115
7116
7117
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builderGoogle::Apis::ContaineranalysisV1::SlsaBuilder

required Corresponds to the JSON property builder



7094
7095
7096
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7094

def builder
  @builder
end

#materialsArray<Google::Apis::ContaineranalysisV1::Material>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials



7102
7103
7104
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7102

def materials
  @materials
end

#metadataGoogle::Apis::ContaineranalysisV1::SlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



7107
7108
7109
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7107

def 
  @metadata
end

#recipeGoogle::Apis::ContaineranalysisV1::SlsaRecipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



7113
7114
7115
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7113

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7120
7121
7122
7123
7124
7125
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7120

def update!(**args)
  @builder = args[:builder] if args.key?(:builder)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end