Class: Google::Apis::ContaineranalysisV1::SlsaProvenance
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::SlsaProvenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Instance Attribute Summary collapse
-
#builder ⇒ Google::Apis::ContaineranalysisV1::SlsaBuilder
required Corresponds to the JSON property
builder. -
#materials ⇒ Array<Google::Apis::ContaineranalysisV1::Material>
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
-
#metadata ⇒ Google::Apis::ContaineranalysisV1::SlsaMetadata
Other properties of the build.
-
#recipe ⇒ Google::Apis::ContaineranalysisV1::SlsaRecipe
Steps taken to build the artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlsaProvenance
constructor
A new instance of SlsaProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlsaProvenance
Returns a new instance of SlsaProvenance.
7074 7075 7076 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7074 def initialize(**args) update!(**args) end |
Instance Attribute Details
#builder ⇒ Google::Apis::ContaineranalysisV1::SlsaBuilder
required
Corresponds to the JSON property builder
7053 7054 7055 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7053 def builder @builder end |
#materials ⇒ Array<Google::Apis::ContaineranalysisV1::Material>
The collection of artifacts that influenced the build including sources,
dependencies, build tools, base images, and so on. This is considered to be
incomplete unless metadata.completeness.materials is true. Unset or null is
equivalent to empty.
Corresponds to the JSON property materials
7061 7062 7063 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7061 def materials @materials end |
#metadata ⇒ Google::Apis::ContaineranalysisV1::SlsaMetadata
Other properties of the build.
Corresponds to the JSON property metadata
7066 7067 7068 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7066 def @metadata end |
#recipe ⇒ Google::Apis::ContaineranalysisV1::SlsaRecipe
Steps taken to build the artifact. For a TaskRun, typically each container
corresponds to one step in the recipe.
Corresponds to the JSON property recipe
7072 7073 7074 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7072 def recipe @recipe end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7079 7080 7081 7082 7083 7084 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7079 def update!(**args) @builder = args[:builder] if args.key?(:builder) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) @recipe = args[:recipe] if args.key?(:recipe) end |