Class: Google::Apis::ContaineranalysisV1::SlsaProvenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenance

Returns a new instance of SlsaProvenance.



6771
6772
6773
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builderGoogle::Apis::ContaineranalysisV1::SlsaBuilder

required Corresponds to the JSON property builder



6750
6751
6752
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6750

def builder
  @builder
end

#materialsArray<Google::Apis::ContaineranalysisV1::Material>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials



6758
6759
6760
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6758

def materials
  @materials
end

#metadataGoogle::Apis::ContaineranalysisV1::SlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



6763
6764
6765
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6763

def 
  @metadata
end

#recipeGoogle::Apis::ContaineranalysisV1::SlsaRecipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



6769
6770
6771
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6769

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6776
6777
6778
6779
6780
6781
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6776

def update!(**args)
  @builder = args[:builder] if args.key?(:builder)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end