Class: Google::Apis::ContaineranalysisV1::SlsaProvenance
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::SlsaProvenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Instance Attribute Summary collapse
-
#builder ⇒ Google::Apis::ContaineranalysisV1::SlsaBuilder
required Corresponds to the JSON property
builder. -
#materials ⇒ Array<Google::Apis::ContaineranalysisV1::Material>
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
-
#metadata ⇒ Google::Apis::ContaineranalysisV1::SlsaMetadata
Other properties of the build.
-
#recipe ⇒ Google::Apis::ContaineranalysisV1::SlsaRecipe
Steps taken to build the artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlsaProvenance
constructor
A new instance of SlsaProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlsaProvenance
Returns a new instance of SlsaProvenance.
6707 6708 6709 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#builder ⇒ Google::Apis::ContaineranalysisV1::SlsaBuilder
required
Corresponds to the JSON property builder
6686 6687 6688 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6686 def builder @builder end |
#materials ⇒ Array<Google::Apis::ContaineranalysisV1::Material>
The collection of artifacts that influenced the build including sources,
dependencies, build tools, base images, and so on. This is considered to be
incomplete unless metadata.completeness.materials is true. Unset or null is
equivalent to empty.
Corresponds to the JSON property materials
6694 6695 6696 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6694 def materials @materials end |
#metadata ⇒ Google::Apis::ContaineranalysisV1::SlsaMetadata
Other properties of the build.
Corresponds to the JSON property metadata
6699 6700 6701 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6699 def @metadata end |
#recipe ⇒ Google::Apis::ContaineranalysisV1::SlsaRecipe
Steps taken to build the artifact. For a TaskRun, typically each container
corresponds to one step in the recipe.
Corresponds to the JSON property recipe
6705 6706 6707 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6705 def recipe @recipe end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6712 6713 6714 6715 6716 6717 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 6712 def update!(**args) @builder = args[:builder] if args.key?(:builder) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) @recipe = args[:recipe] if args.key?(:recipe) end |