Class: Google::Apis::ContaineranalysisV1::Source
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Source
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
Source describes the location of the source used for the build.
Instance Attribute Summary collapse
-
#additional_contexts ⇒ Array<Google::Apis::ContaineranalysisV1::SourceContext>
If provided, some of the source code used for the build may be found in these locations, in the case where the source repository had multiple remotes or submodules.
-
#artifact_storage_source_uri ⇒ String
If provided, the input binary artifacts for the build came from this location.
-
#context ⇒ Google::Apis::ContaineranalysisV1::SourceContext
A SourceContext is a reference to a tree of files.
-
#file_hashes ⇒ Hash<String,Google::Apis::ContaineranalysisV1::FileHashes>
Hash(es) of the build source, which can be used to verify that the original source integrity was maintained in the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Source
constructor
A new instance of Source.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Source
Returns a new instance of Source.
7308 7309 7310 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_contexts ⇒ Array<Google::Apis::ContaineranalysisV1::SourceContext>
If provided, some of the source code used for the build may be found in these
locations, in the case where the source repository had multiple remotes or
submodules. This list will not include the context specified in the context
field.
Corresponds to the JSON property additionalContexts
7286 7287 7288 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7286 def additional_contexts @additional_contexts end |
#artifact_storage_source_uri ⇒ String
If provided, the input binary artifacts for the build came from this location.
Corresponds to the JSON property artifactStorageSourceUri
7291 7292 7293 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7291 def artifact_storage_source_uri @artifact_storage_source_uri end |
#context ⇒ Google::Apis::ContaineranalysisV1::SourceContext
A SourceContext is a reference to a tree of files. A SourceContext together
with a path point to a unique revision of a single file or directory.
Corresponds to the JSON property context
7297 7298 7299 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7297 def context @context end |
#file_hashes ⇒ Hash<String,Google::Apis::ContaineranalysisV1::FileHashes>
Hash(es) of the build source, which can be used to verify that the original
source integrity was maintained in the build. The keys to this map are file
paths used as build source and the values contain the hash values for those
files. If the build source came in a single package such as a gzipped tarfile (
.tar.gz), the FileHash will be for the single path to that file.
Corresponds to the JSON property fileHashes
7306 7307 7308 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7306 def file_hashes @file_hashes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7313 7314 7315 7316 7317 7318 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7313 def update!(**args) @additional_contexts = args[:additional_contexts] if args.key?(:additional_contexts) @artifact_storage_source_uri = args[:artifact_storage_source_uri] if args.key?(:artifact_storage_source_uri) @context = args[:context] if args.key?(:context) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) end |