Class: Google::Apis::ContaineranalysisV1::Status
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::Status
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Instance Attribute Summary collapse
-
#code ⇒ Fixnum
The status code, which should be an enum value of google.rpc.Code.
-
#details ⇒ Array<Hash<String,Object>>
A list of messages that carry the error details.
-
#message ⇒ String
A developer-facing error message, which should be in English.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Status
constructor
A new instance of Status.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Status
Returns a new instance of Status.
7032 7033 7034 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7032 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ Fixnum
The status code, which should be an enum value of google.rpc.Code.
Corresponds to the JSON property code
7017 7018 7019 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7017 def code @code end |
#details ⇒ Array<Hash<String,Object>>
A list of messages that carry the error details. There is a common set of
message types for APIs to use.
Corresponds to the JSON property details
7023 7024 7025 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7023 def details @details end |
#message ⇒ String
A developer-facing error message, which should be in English. Any user-facing
error message should be localized and sent in the google.rpc.Status.details
field, or localized by the client.
Corresponds to the JSON property message
7030 7031 7032 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7030 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7037 7038 7039 7040 7041 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7037 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @message = args[:message] if args.key?(:message) end |