Class: Google::Apis::ContaineranalysisV1::UpgradeDistribution

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeDistribution

Returns a new instance of UpgradeDistribution.



7552
7553
7554
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7552

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classificationString

The operating system classification of this Upgrade, as specified by the upstream operating system upgrade feed. For Windows the classification is one of the category_ids listed at https://docs.microsoft.com/en-us/previous- versions/windows/desktop/ff357803(v=vs.85) Corresponds to the JSON property classification

Returns:

  • (String)


7534
7535
7536
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7534

def classification
  @classification
end

#cpe_uriString

Required - The specific operating system this metadata applies to. See https:// cpe.mitre.org/specification/. Corresponds to the JSON property cpeUri

Returns:

  • (String)


7540
7541
7542
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7540

def cpe_uri
  @cpe_uri
end

#cveArray<String>

The cve tied to this Upgrade. Corresponds to the JSON property cve

Returns:

  • (Array<String>)


7545
7546
7547
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7545

def cve
  @cve
end

#severityString

The severity as specified by the upstream operating system. Corresponds to the JSON property severity

Returns:

  • (String)


7550
7551
7552
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7550

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7557
7558
7559
7560
7561
7562
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7557

def update!(**args)
  @classification = args[:classification] if args.key?(:classification)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @cve = args[:cve] if args.key?(:cve)
  @severity = args[:severity] if args.key?(:severity)
end