Class: Google::Apis::ContaineranalysisV1::UpgradeOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::UpgradeOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability). For Windows, both distribution and windows_update contain information for the Windows update.
Instance Attribute Summary collapse
-
#distribution ⇒ Google::Apis::ContaineranalysisV1::UpgradeDistribution
The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE).
-
#package ⇒ String
Required for non-Windows OS.
-
#parsed_version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
-
#windows_update ⇒ Google::Apis::ContaineranalysisV1::WindowsUpdate
Windows Update represents the metadata about the update for the Windows operating system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeOccurrence
constructor
A new instance of UpgradeOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeOccurrence
Returns a new instance of UpgradeOccurrence.
7209 7210 7211 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7209 def initialize(**args) update!(**args) end |
Instance Attribute Details
#distribution ⇒ Google::Apis::ContaineranalysisV1::UpgradeDistribution
The Upgrade Distribution represents metadata about the Upgrade for each
operating system (CPE). Some distributions have additional metadata around
updates, classifying them into various categories and severities.
Corresponds to the JSON property distribution
7189 7190 7191 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7189 def distribution @distribution end |
#package ⇒ String
Required for non-Windows OS. The package this Upgrade is for.
Corresponds to the JSON property package
7194 7195 7196 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7194 def package @package end |
#parsed_version ⇒ Google::Apis::ContaineranalysisV1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property parsedVersion
7199 7200 7201 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7199 def parsed_version @parsed_version end |
#windows_update ⇒ Google::Apis::ContaineranalysisV1::WindowsUpdate
Windows Update represents the metadata about the update for the Windows
operating system. The fields in this message come from the Windows Update API
documented at https://docs.microsoft.com/en-us/windows/win32/api/wuapi/nn-
wuapi-iupdate.
Corresponds to the JSON property windowsUpdate
7207 7208 7209 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7207 def windows_update @windows_update end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7214 7215 7216 7217 7218 7219 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7214 def update!(**args) @distribution = args[:distribution] if args.key?(:distribution) @package = args[:package] if args.key?(:package) @parsed_version = args[:parsed_version] if args.key?(:parsed_version) @windows_update = args[:windows_update] if args.key?(:windows_update) end |