Class: Google::Apis::ContaineranalysisV1::Version

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Version contains structured information about the version of a package.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Version

Returns a new instance of Version.



7642
7643
7644
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#epochFixnum

Used to correct mistakes in the version numbering scheme. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


7608
7609
7610
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7608

def epoch
  @epoch
end

#full_nameString

Human readable version string. This string is of the form :- and is only set when kind is NORMAL. Corresponds to the JSON property fullName

Returns:

  • (String)


7614
7615
7616
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7614

def full_name
  @full_name
end

#inclusiveBoolean Also known as: inclusive?

Whether this version is specifying part of an inclusive range. Grafeas does not have the capability to specify version ranges; instead we have fields that specify start version and end versions. At times this is insufficient - we also need to specify whether the version is included in the range or is excluded from the range. This boolean is expected to be set to true when the version is included in a range. Corresponds to the JSON property inclusive

Returns:

  • (Boolean)


7624
7625
7626
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7624

def inclusive
  @inclusive
end

#kindString

Required. Distinguishes between sentinel MIN/MAX versions and normal versions. Corresponds to the JSON property kind

Returns:

  • (String)


7630
7631
7632
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7630

def kind
  @kind
end

#nameString

Required only when version kind is NORMAL. The main part of the version name. Corresponds to the JSON property name

Returns:

  • (String)


7635
7636
7637
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7635

def name
  @name
end

#revisionString

The iteration of the package build from the above version. Corresponds to the JSON property revision

Returns:

  • (String)


7640
7641
7642
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7640

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7647
7648
7649
7650
7651
7652
7653
7654
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7647

def update!(**args)
  @epoch = args[:epoch] if args.key?(:epoch)
  @full_name = args[:full_name] if args.key?(:full_name)
  @inclusive = args[:inclusive] if args.key?(:inclusive)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @revision = args[:revision] if args.key?(:revision)
end