Class: Google::Apis::ContaineranalysisV1::Version

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Version contains structured information about the version of a package.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Version

Returns a new instance of Version.



7275
7276
7277
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#epochFixnum

Used to correct mistakes in the version numbering scheme. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


7241
7242
7243
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7241

def epoch
  @epoch
end

#full_nameString

Human readable version string. This string is of the form :- and is only set when kind is NORMAL. Corresponds to the JSON property fullName

Returns:

  • (String)


7247
7248
7249
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7247

def full_name
  @full_name
end

#inclusiveBoolean Also known as: inclusive?

Whether this version is specifying part of an inclusive range. Grafeas does not have the capability to specify version ranges; instead we have fields that specify start version and end versions. At times this is insufficient - we also need to specify whether the version is included in the range or is excluded from the range. This boolean is expected to be set to true when the version is included in a range. Corresponds to the JSON property inclusive

Returns:

  • (Boolean)


7257
7258
7259
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7257

def inclusive
  @inclusive
end

#kindString

Required. Distinguishes between sentinel MIN/MAX versions and normal versions. Corresponds to the JSON property kind

Returns:

  • (String)


7263
7264
7265
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7263

def kind
  @kind
end

#nameString

Required only when version kind is NORMAL. The main part of the version name. Corresponds to the JSON property name

Returns:

  • (String)


7268
7269
7270
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7268

def name
  @name
end

#revisionString

The iteration of the package build from the above version. Corresponds to the JSON property revision

Returns:

  • (String)


7273
7274
7275
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7273

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7280
7281
7282
7283
7284
7285
7286
7287
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7280

def update!(**args)
  @epoch = args[:epoch] if args.key?(:epoch)
  @full_name = args[:full_name] if args.key?(:full_name)
  @inclusive = args[:inclusive] if args.key?(:inclusive)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @revision = args[:revision] if args.key?(:revision)
end