Class: Google::Apis::ContaineranalysisV1::VexAssessment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

VexAssessment provides all publisher provided Vex information that is related to this vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VexAssessment

Returns a new instance of VexAssessment.



7330
7331
7332
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cveString

Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking number for the vulnerability. Deprecated: Use vulnerability_id instead to denote CVEs. Corresponds to the JSON property cve

Returns:

  • (String)


7288
7289
7290
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7288

def cve
  @cve
end

#impactsArray<String>

Contains information about the impact of this vulnerability, this will change with time. Corresponds to the JSON property impacts

Returns:

  • (Array<String>)


7294
7295
7296
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7294

def impacts
  @impacts
end

#justificationGoogle::Apis::ContaineranalysisV1::Justification

Justification provides the justification when the state of the assessment if NOT_AFFECTED. Corresponds to the JSON property justification



7300
7301
7302
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7300

def justification
  @justification
end

#note_nameString

The VulnerabilityAssessment note from which this VexAssessment was generated. This will be of the form: projects/[PROJECT_ID]/notes/[NOTE_ID]. Corresponds to the JSON property noteName

Returns:

  • (String)


7306
7307
7308
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7306

def note_name
  @note_name
end

Holds a list of references associated with this vulnerability item and assessment. Corresponds to the JSON property relatedUris



7312
7313
7314
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7312

def related_uris
  @related_uris
end

#remediationsArray<Google::Apis::ContaineranalysisV1::Remediation>

Specifies details on how to handle (and presumably, fix) a vulnerability. Corresponds to the JSON property remediations



7317
7318
7319
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7317

def remediations
  @remediations
end

#stateString

Provides the state of this Vulnerability assessment. Corresponds to the JSON property state

Returns:

  • (String)


7322
7323
7324
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7322

def state
  @state
end

#vulnerability_idString

The vulnerability identifier for this Assessment. Will hold one of common identifiers e.g. CVE, GHSA etc. Corresponds to the JSON property vulnerabilityId

Returns:

  • (String)


7328
7329
7330
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7328

def vulnerability_id
  @vulnerability_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7335
7336
7337
7338
7339
7340
7341
7342
7343
7344
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7335

def update!(**args)
  @cve = args[:cve] if args.key?(:cve)
  @impacts = args[:impacts] if args.key?(:impacts)
  @justification = args[:justification] if args.key?(:justification)
  @note_name = args[:note_name] if args.key?(:note_name)
  @related_uris = args[:related_uris] if args.key?(:related_uris)
  @remediations = args[:remediations] if args.key?(:remediations)
  @state = args[:state] if args.key?(:state)
  @vulnerability_id = args[:vulnerability_id] if args.key?(:vulnerability_id)
end