Class: Google::Apis::ContaineranalysisV1::Volume

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

Volume describes a Docker container volume which is mounted into build steps in order to persist files across build step execution. Next ID: 3

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Volume

Returns a new instance of Volume.



7378
7379
7380
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the volume to mount. Volume names must be unique per build step and must be valid names for Docker volumes. Each named volume must be used by at least two build steps. Corresponds to the JSON property name

Returns:

  • (String)


7369
7370
7371
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7369

def name
  @name
end

#pathString

Path at which to mount the volume. Paths must be absolute and cannot conflict with other volume paths on the same build step or with certain reserved volume paths. Corresponds to the JSON property path

Returns:

  • (String)


7376
7377
7378
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7376

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7383
7384
7385
7386
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7383

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
end