Class: Google::Apis::ContaineranalysisV1::VulnerabilityAssessmentNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A single VulnerabilityAssessmentNote represents one particular product's vulnerability assessment for one CVE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityAssessmentNote

Returns a new instance of VulnerabilityAssessmentNote.



7495
7496
7497
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assessmentGoogle::Apis::ContaineranalysisV1::Assessment

Assessment provides all information that is related to a single vulnerability for this product. Corresponds to the JSON property assessment



7462
7463
7464
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7462

def assessment
  @assessment
end

#language_codeString

Identifies the language used by this document, corresponding to IETF BCP 47 / RFC 5646. Corresponds to the JSON property languageCode

Returns:

  • (String)


7468
7469
7470
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7468

def language_code
  @language_code
end

#long_descriptionString

A detailed description of this Vex. Corresponds to the JSON property longDescription

Returns:

  • (String)


7473
7474
7475
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7473

def long_description
  @long_description
end

#productGoogle::Apis::ContaineranalysisV1::Product

Product contains information about a product and how to uniquely identify it. Corresponds to the JSON property product



7478
7479
7480
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7478

def product
  @product
end

#publisherGoogle::Apis::ContaineranalysisV1::Publisher

Publisher contains information about the publisher of this Note. Corresponds to the JSON property publisher



7483
7484
7485
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7483

def publisher
  @publisher
end

#short_descriptionString

A one sentence description of this Vex. Corresponds to the JSON property shortDescription

Returns:

  • (String)


7488
7489
7490
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7488

def short_description
  @short_description
end

#titleString

The title of the note. E.g. Vex-Debian-11.4 Corresponds to the JSON property title

Returns:

  • (String)


7493
7494
7495
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7493

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7500
7501
7502
7503
7504
7505
7506
7507
7508
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7500

def update!(**args)
  @assessment = args[:assessment] if args.key?(:assessment)
  @language_code = args[:language_code] if args.key?(:language_code)
  @long_description = args[:long_description] if args.key?(:long_description)
  @product = args[:product] if args.key?(:product)
  @publisher = args[:publisher] if args.key?(:publisher)
  @short_description = args[:short_description] if args.key?(:short_description)
  @title = args[:title] if args.key?(:title)
end