Class: Google::Apis::ContaineranalysisV1::VulnerabilityNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

A security vulnerability that can be found in resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityNote

Returns a new instance of VulnerabilityNote.



7506
7507
7508
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advisory_publish_timeString

The time this advisory was published by the source. Corresponds to the JSON property advisoryPublishTime

Returns:

  • (String)


7454
7455
7456
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7454

def advisory_publish_time
  @advisory_publish_time
end

#cvss_scoreFloat

The CVSS score of this vulnerability. CVSS score is on a scale of 0 - 10 where 0 indicates low severity and 10 indicates high severity. Corresponds to the JSON property cvssScore

Returns:

  • (Float)


7460
7461
7462
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7460

def cvss_score
  @cvss_score
end

#cvss_v2Google::Apis::ContaineranalysisV1::Cvss

Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version. Corresponds to the JSON property cvssV2



7468
7469
7470
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7468

def cvss_v2
  @cvss_v2
end

#cvss_v3Google::Apis::ContaineranalysisV1::CvsSv3

Common Vulnerability Scoring System version 3. For details, see https://www. first.org/cvss/specification-document Corresponds to the JSON property cvssV3



7474
7475
7476
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7474

def cvss_v3
  @cvss_v3
end

#cvss_versionString

CVSS version used to populate cvss_score and severity. Corresponds to the JSON property cvssVersion

Returns:

  • (String)


7479
7480
7481
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7479

def cvss_version
  @cvss_version
end

#detailsArray<Google::Apis::ContaineranalysisV1::Detail>

Details of all known distros and packages affected by this vulnerability. Corresponds to the JSON property details



7484
7485
7486
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7484

def details
  @details
end

#severityString

The note provider assigned severity of this vulnerability. Corresponds to the JSON property severity

Returns:

  • (String)


7489
7490
7491
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7489

def severity
  @severity
end

#source_update_timeString

The time this information was last changed at the source. This is an upstream timestamp from the underlying information source - e.g. Ubuntu security tracker. Corresponds to the JSON property sourceUpdateTime

Returns:

  • (String)


7496
7497
7498
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7496

def source_update_time
  @source_update_time
end

#windows_detailsArray<Google::Apis::ContaineranalysisV1::WindowsDetail>

Windows details get their own format because the information format and model don't match a normal detail. Specifically Windows updates are done as patches, thus Windows vulnerabilities really are a missing package, rather than a package being at an incorrect version. Corresponds to the JSON property windowsDetails



7504
7505
7506
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7504

def windows_details
  @windows_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7511
7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7511

def update!(**args)
  @advisory_publish_time = args[:advisory_publish_time] if args.key?(:advisory_publish_time)
  @cvss_score = args[:cvss_score] if args.key?(:cvss_score)
  @cvss_v2 = args[:cvss_v2] if args.key?(:cvss_v2)
  @cvss_v3 = args[:cvss_v3] if args.key?(:cvss_v3)
  @cvss_version = args[:cvss_version] if args.key?(:cvss_version)
  @details = args[:details] if args.key?(:details)
  @severity = args[:severity] if args.key?(:severity)
  @source_update_time = args[:source_update_time] if args.key?(:source_update_time)
  @windows_details = args[:windows_details] if args.key?(:windows_details)
end