Class: Google::Apis::ContaineranalysisV1::VulnerabilityNote
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::VulnerabilityNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
A security vulnerability that can be found in resources.
Instance Attribute Summary collapse
-
#cvss_score ⇒ Float
The CVSS score of this vulnerability.
-
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1::Cvss
Common Vulnerability Scoring System.
-
#cvss_v3 ⇒ Google::Apis::ContaineranalysisV1::CvsSv3
Common Vulnerability Scoring System version 3.
-
#cvss_version ⇒ String
CVSS version used to populate cvss_score and severity.
-
#details ⇒ Array<Google::Apis::ContaineranalysisV1::Detail>
Details of all known distros and packages affected by this vulnerability.
-
#severity ⇒ String
The note provider assigned severity of this vulnerability.
-
#source_update_time ⇒ String
The time this information was last changed at the source.
-
#windows_details ⇒ Array<Google::Apis::ContaineranalysisV1::WindowsDetail>
Windows details get their own format because the information format and model don't match a normal detail.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityNote
constructor
A new instance of VulnerabilityNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityNote
Returns a new instance of VulnerabilityNote.
7489 7490 7491 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7489 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cvss_score ⇒ Float
The CVSS score of this vulnerability. CVSS score is on a scale of 0 - 10 where
0 indicates low severity and 10 indicates high severity.
Corresponds to the JSON property cvssScore
7443 7444 7445 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7443 def cvss_score @cvss_score end |
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1::Cvss
Common Vulnerability Scoring System. For details, see https://www.first.org/
cvss/specification-document This is a message we will try to use for storing
various versions of CVSS rather than making a separate proto for storing a
specific version.
Corresponds to the JSON property cvssV2
7451 7452 7453 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7451 def cvss_v2 @cvss_v2 end |
#cvss_v3 ⇒ Google::Apis::ContaineranalysisV1::CvsSv3
Common Vulnerability Scoring System version 3. For details, see https://www.
first.org/cvss/specification-document
Corresponds to the JSON property cvssV3
7457 7458 7459 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7457 def cvss_v3 @cvss_v3 end |
#cvss_version ⇒ String
CVSS version used to populate cvss_score and severity.
Corresponds to the JSON property cvssVersion
7462 7463 7464 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7462 def cvss_version @cvss_version end |
#details ⇒ Array<Google::Apis::ContaineranalysisV1::Detail>
Details of all known distros and packages affected by this vulnerability.
Corresponds to the JSON property details
7467 7468 7469 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7467 def details @details end |
#severity ⇒ String
The note provider assigned severity of this vulnerability.
Corresponds to the JSON property severity
7472 7473 7474 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7472 def severity @severity end |
#source_update_time ⇒ String
The time this information was last changed at the source. This is an upstream
timestamp from the underlying information source - e.g. Ubuntu security
tracker.
Corresponds to the JSON property sourceUpdateTime
7479 7480 7481 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7479 def source_update_time @source_update_time end |
#windows_details ⇒ Array<Google::Apis::ContaineranalysisV1::WindowsDetail>
Windows details get their own format because the information format and model
don't match a normal detail. Specifically Windows updates are done as patches,
thus Windows vulnerabilities really are a missing package, rather than a
package being at an incorrect version.
Corresponds to the JSON property windowsDetails
7487 7488 7489 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7487 def windows_details @windows_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7494 def update!(**args) @cvss_score = args[:cvss_score] if args.key?(:cvss_score) @cvss_v2 = args[:cvss_v2] if args.key?(:cvss_v2) @cvss_v3 = args[:cvss_v3] if args.key?(:cvss_v3) @cvss_version = args[:cvss_version] if args.key?(:cvss_version) @details = args[:details] if args.key?(:details) @severity = args[:severity] if args.key?(:severity) @source_update_time = args[:source_update_time] if args.key?(:source_update_time) @windows_details = args[:windows_details] if args.key?(:windows_details) end |