Class: Google::Apis::ContaineranalysisV1::VulnerabilityOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

An occurrence of a severity vulnerability on a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityOccurrence

Returns a new instance of VulnerabilityOccurrence.



7988
7989
7990
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cvss_scoreFloat

Output only. The CVSS score of this vulnerability. CVSS score is on a scale of 0 - 10 where 0 indicates low severity and 10 indicates high severity. Corresponds to the JSON property cvssScore

Returns:

  • (Float)


7899
7900
7901
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7899

def cvss_score
  @cvss_score
end

#cvss_v2Google::Apis::ContaineranalysisV1::Cvss

Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version. Corresponds to the JSON property cvssV2



7907
7908
7909
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7907

def cvss_v2
  @cvss_v2
end

#cvss_versionString

Output only. CVSS version used to populate cvss_score and severity. Corresponds to the JSON property cvssVersion

Returns:

  • (String)


7912
7913
7914
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7912

def cvss_version
  @cvss_version
end

#cvssv3Google::Apis::ContaineranalysisV1::Cvss

Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version. Corresponds to the JSON property cvssv3



7920
7921
7922
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7920

def cvssv3
  @cvssv3
end

#effective_severityString

The distro assigned severity for this vulnerability when it is available, otherwise this is the note provider assigned severity. When there are multiple PackageIssues for this vulnerability, they can have different effective severities because some might be provided by the distro while others are provided by the language ecosystem for a language pack. For this reason, it is advised to use the effective severity on the PackageIssue level. In the case where multiple PackageIssues have differing effective severities, this field should be the highest severity for any of the PackageIssues. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


7932
7933
7934
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7932

def effective_severity
  @effective_severity
end

#extra_detailsString

Occurrence-specific extra details about the vulnerability. Corresponds to the JSON property extraDetails

Returns:

  • (String)


7937
7938
7939
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7937

def extra_details
  @extra_details
end

#fix_availableBoolean Also known as: fix_available?

Output only. Whether at least one of the affected packages has a fix available. Corresponds to the JSON property fixAvailable

Returns:

  • (Boolean)


7942
7943
7944
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7942

def fix_available
  @fix_available
end

#long_descriptionString

Output only. A detailed description of this vulnerability. Corresponds to the JSON property longDescription

Returns:

  • (String)


7948
7949
7950
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7948

def long_description
  @long_description
end

#package_issueArray<Google::Apis::ContaineranalysisV1::PackageIssue>

Required. The set of affected locations and their fixes (if available) within the associated resource. Corresponds to the JSON property packageIssue



7954
7955
7956
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7954

def package_issue
  @package_issue
end

Output only. URLs related to this vulnerability. Corresponds to the JSON property relatedUrls



7959
7960
7961
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7959

def related_urls
  @related_urls
end

#riskGoogle::Apis::ContaineranalysisV1::Risk

Risk information about the vulnerability, such as CISA, EPSS, etc. Corresponds to the JSON property risk



7964
7965
7966
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7964

def risk
  @risk
end

#severityString

Output only. The note provider assigned severity of this vulnerability. Corresponds to the JSON property severity

Returns:

  • (String)


7969
7970
7971
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7969

def severity
  @severity
end

#short_descriptionString

Output only. A one sentence description of this vulnerability. Corresponds to the JSON property shortDescription

Returns:

  • (String)


7974
7975
7976
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7974

def short_description
  @short_description
end

#typeString

The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.). Corresponds to the JSON property type

Returns:

  • (String)


7980
7981
7982
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7980

def type
  @type
end

#vex_assessmentGoogle::Apis::ContaineranalysisV1::VexAssessment

VexAssessment provides all publisher provided Vex information that is related to this vulnerability. Corresponds to the JSON property vexAssessment



7986
7987
7988
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7986

def vex_assessment
  @vex_assessment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7993

def update!(**args)
  @cvss_score = args[:cvss_score] if args.key?(:cvss_score)
  @cvss_v2 = args[:cvss_v2] if args.key?(:cvss_v2)
  @cvss_version = args[:cvss_version] if args.key?(:cvss_version)
  @cvssv3 = args[:cvssv3] if args.key?(:cvssv3)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @extra_details = args[:extra_details] if args.key?(:extra_details)
  @fix_available = args[:fix_available] if args.key?(:fix_available)
  @long_description = args[:long_description] if args.key?(:long_description)
  @package_issue = args[:package_issue] if args.key?(:package_issue)
  @related_urls = args[:related_urls] if args.key?(:related_urls)
  @risk = args[:risk] if args.key?(:risk)
  @severity = args[:severity] if args.key?(:severity)
  @short_description = args[:short_description] if args.key?(:short_description)
  @type = args[:type] if args.key?(:type)
  @vex_assessment = args[:vex_assessment] if args.key?(:vex_assessment)
end