Class: Google::Apis::ContaineranalysisV1::VulnerabilityOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::VulnerabilityOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
An occurrence of a severity vulnerability on a resource.
Instance Attribute Summary collapse
-
#cvss_score ⇒ Float
Output only.
-
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1::Cvss
Common Vulnerability Scoring System.
-
#cvss_version ⇒ String
Output only.
-
#cvssv3 ⇒ Google::Apis::ContaineranalysisV1::Cvss
Common Vulnerability Scoring System.
-
#effective_severity ⇒ String
The distro assigned severity for this vulnerability when it is available, otherwise this is the note provider assigned severity.
-
#extra_details ⇒ String
Occurrence-specific extra details about the vulnerability.
-
#fix_available ⇒ Boolean
(also: #fix_available?)
Output only.
-
#long_description ⇒ String
Output only.
-
#package_issue ⇒ Array<Google::Apis::ContaineranalysisV1::PackageIssue>
Required.
-
#related_urls ⇒ Array<Google::Apis::ContaineranalysisV1::RelatedUrl>
Output only.
-
#risk ⇒ Google::Apis::ContaineranalysisV1::Risk
Risk information about the vulnerability, such as CISA, EPSS, etc.
-
#severity ⇒ String
Output only.
-
#short_description ⇒ String
Output only.
-
#type ⇒ String
The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.).
-
#vex_assessment ⇒ Google::Apis::ContaineranalysisV1::VexAssessment
VexAssessment provides all publisher provided Vex information that is related to this vulnerability.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityOccurrence
constructor
A new instance of VulnerabilityOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityOccurrence
Returns a new instance of VulnerabilityOccurrence.
7975 7976 7977 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7975 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cvss_score ⇒ Float
Output only. The CVSS score of this vulnerability. CVSS score is on a scale of
0 - 10 where 0 indicates low severity and 10 indicates high severity.
Corresponds to the JSON property cvssScore
7886 7887 7888 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7886 def cvss_score @cvss_score end |
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1::Cvss
Common Vulnerability Scoring System. For details, see https://www.first.org/
cvss/specification-document This is a message we will try to use for storing
various versions of CVSS rather than making a separate proto for storing a
specific version.
Corresponds to the JSON property cvssV2
7894 7895 7896 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7894 def cvss_v2 @cvss_v2 end |
#cvss_version ⇒ String
Output only. CVSS version used to populate cvss_score and severity.
Corresponds to the JSON property cvssVersion
7899 7900 7901 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7899 def cvss_version @cvss_version end |
#cvssv3 ⇒ Google::Apis::ContaineranalysisV1::Cvss
Common Vulnerability Scoring System. For details, see https://www.first.org/
cvss/specification-document This is a message we will try to use for storing
various versions of CVSS rather than making a separate proto for storing a
specific version.
Corresponds to the JSON property cvssv3
7907 7908 7909 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7907 def cvssv3 @cvssv3 end |
#effective_severity ⇒ String
The distro assigned severity for this vulnerability when it is available,
otherwise this is the note provider assigned severity. When there are multiple
PackageIssues for this vulnerability, they can have different effective
severities because some might be provided by the distro while others are
provided by the language ecosystem for a language pack. For this reason, it is
advised to use the effective severity on the PackageIssue level. In the case
where multiple PackageIssues have differing effective severities, this field
should be the highest severity for any of the PackageIssues.
Corresponds to the JSON property effectiveSeverity
7919 7920 7921 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7919 def effective_severity @effective_severity end |
#extra_details ⇒ String
Occurrence-specific extra details about the vulnerability.
Corresponds to the JSON property extraDetails
7924 7925 7926 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7924 def extra_details @extra_details end |
#fix_available ⇒ Boolean Also known as: fix_available?
Output only. Whether at least one of the affected packages has a fix available.
Corresponds to the JSON property fixAvailable
7929 7930 7931 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7929 def fix_available @fix_available end |
#long_description ⇒ String
Output only. A detailed description of this vulnerability.
Corresponds to the JSON property longDescription
7935 7936 7937 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7935 def long_description @long_description end |
#package_issue ⇒ Array<Google::Apis::ContaineranalysisV1::PackageIssue>
Required. The set of affected locations and their fixes (if available) within
the associated resource.
Corresponds to the JSON property packageIssue
7941 7942 7943 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7941 def package_issue @package_issue end |
#related_urls ⇒ Array<Google::Apis::ContaineranalysisV1::RelatedUrl>
Output only. URLs related to this vulnerability.
Corresponds to the JSON property relatedUrls
7946 7947 7948 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7946 def @related_urls end |
#risk ⇒ Google::Apis::ContaineranalysisV1::Risk
Risk information about the vulnerability, such as CISA, EPSS, etc.
Corresponds to the JSON property risk
7951 7952 7953 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7951 def risk @risk end |
#severity ⇒ String
Output only. The note provider assigned severity of this vulnerability.
Corresponds to the JSON property severity
7956 7957 7958 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7956 def severity @severity end |
#short_description ⇒ String
Output only. A one sentence description of this vulnerability.
Corresponds to the JSON property shortDescription
7961 7962 7963 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7961 def short_description @short_description end |
#type ⇒ String
The type of package; whether native or non native (e.g., ruby gems, node.js
packages, etc.).
Corresponds to the JSON property type
7967 7968 7969 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7967 def type @type end |
#vex_assessment ⇒ Google::Apis::ContaineranalysisV1::VexAssessment
VexAssessment provides all publisher provided Vex information that is related
to this vulnerability.
Corresponds to the JSON property vexAssessment
7973 7974 7975 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7973 def vex_assessment @vex_assessment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7980 def update!(**args) @cvss_score = args[:cvss_score] if args.key?(:cvss_score) @cvss_v2 = args[:cvss_v2] if args.key?(:cvss_v2) @cvss_version = args[:cvss_version] if args.key?(:cvss_version) @cvssv3 = args[:cvssv3] if args.key?(:cvssv3) @effective_severity = args[:effective_severity] if args.key?(:effective_severity) @extra_details = args[:extra_details] if args.key?(:extra_details) @fix_available = args[:fix_available] if args.key?(:fix_available) @long_description = args[:long_description] if args.key?(:long_description) @package_issue = args[:package_issue] if args.key?(:package_issue) @related_urls = args[:related_urls] if args.key?(:related_urls) @risk = args[:risk] if args.key?(:risk) @severity = args[:severity] if args.key?(:severity) @short_description = args[:short_description] if args.key?(:short_description) @type = args[:type] if args.key?(:type) @vex_assessment = args[:vex_assessment] if args.key?(:vex_assessment) end |