Class: Google::Apis::ContaineranalysisV1::VulnerabilityOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb

Overview

An occurrence of a severity vulnerability on a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityOccurrence

Returns a new instance of VulnerabilityOccurrence.



7621
7622
7623
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cvss_scoreFloat

Output only. The CVSS score of this vulnerability. CVSS score is on a scale of 0 - 10 where 0 indicates low severity and 10 indicates high severity. Corresponds to the JSON property cvssScore

Returns:

  • (Float)


7532
7533
7534
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7532

def cvss_score
  @cvss_score
end

#cvss_v2Google::Apis::ContaineranalysisV1::Cvss

Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version. Corresponds to the JSON property cvssV2



7540
7541
7542
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7540

def cvss_v2
  @cvss_v2
end

#cvss_versionString

Output only. CVSS version used to populate cvss_score and severity. Corresponds to the JSON property cvssVersion

Returns:

  • (String)


7545
7546
7547
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7545

def cvss_version
  @cvss_version
end

#cvssv3Google::Apis::ContaineranalysisV1::Cvss

Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version. Corresponds to the JSON property cvssv3



7553
7554
7555
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7553

def cvssv3
  @cvssv3
end

#effective_severityString

The distro assigned severity for this vulnerability when it is available, otherwise this is the note provider assigned severity. When there are multiple PackageIssues for this vulnerability, they can have different effective severities because some might be provided by the distro while others are provided by the language ecosystem for a language pack. For this reason, it is advised to use the effective severity on the PackageIssue level. In the case where multiple PackageIssues have differing effective severities, this field should be the highest severity for any of the PackageIssues. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


7565
7566
7567
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7565

def effective_severity
  @effective_severity
end

#extra_detailsString

Occurrence-specific extra details about the vulnerability. Corresponds to the JSON property extraDetails

Returns:

  • (String)


7570
7571
7572
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7570

def extra_details
  @extra_details
end

#fix_availableBoolean Also known as: fix_available?

Output only. Whether at least one of the affected packages has a fix available. Corresponds to the JSON property fixAvailable

Returns:

  • (Boolean)


7575
7576
7577
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7575

def fix_available
  @fix_available
end

#long_descriptionString

Output only. A detailed description of this vulnerability. Corresponds to the JSON property longDescription

Returns:

  • (String)


7581
7582
7583
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7581

def long_description
  @long_description
end

#package_issueArray<Google::Apis::ContaineranalysisV1::PackageIssue>

Required. The set of affected locations and their fixes (if available) within the associated resource. Corresponds to the JSON property packageIssue



7587
7588
7589
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7587

def package_issue
  @package_issue
end

Output only. URLs related to this vulnerability. Corresponds to the JSON property relatedUrls



7592
7593
7594
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7592

def related_urls
  @related_urls
end

#riskGoogle::Apis::ContaineranalysisV1::Risk

Risk information about the vulnerability, such as CISA, EPSS, etc. Corresponds to the JSON property risk



7597
7598
7599
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7597

def risk
  @risk
end

#severityString

Output only. The note provider assigned severity of this vulnerability. Corresponds to the JSON property severity

Returns:

  • (String)


7602
7603
7604
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7602

def severity
  @severity
end

#short_descriptionString

Output only. A one sentence description of this vulnerability. Corresponds to the JSON property shortDescription

Returns:

  • (String)


7607
7608
7609
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7607

def short_description
  @short_description
end

#typeString

The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.). Corresponds to the JSON property type

Returns:

  • (String)


7613
7614
7615
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7613

def type
  @type
end

#vex_assessmentGoogle::Apis::ContaineranalysisV1::VexAssessment

VexAssessment provides all publisher provided Vex information that is related to this vulnerability. Corresponds to the JSON property vexAssessment



7619
7620
7621
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7619

def vex_assessment
  @vex_assessment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7626
7627
7628
7629
7630
7631
7632
7633
7634
7635
7636
7637
7638
7639
7640
7641
7642
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7626

def update!(**args)
  @cvss_score = args[:cvss_score] if args.key?(:cvss_score)
  @cvss_v2 = args[:cvss_v2] if args.key?(:cvss_v2)
  @cvss_version = args[:cvss_version] if args.key?(:cvss_version)
  @cvssv3 = args[:cvssv3] if args.key?(:cvssv3)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @extra_details = args[:extra_details] if args.key?(:extra_details)
  @fix_available = args[:fix_available] if args.key?(:fix_available)
  @long_description = args[:long_description] if args.key?(:long_description)
  @package_issue = args[:package_issue] if args.key?(:package_issue)
  @related_urls = args[:related_urls] if args.key?(:related_urls)
  @risk = args[:risk] if args.key?(:risk)
  @severity = args[:severity] if args.key?(:severity)
  @short_description = args[:short_description] if args.key?(:short_description)
  @type = args[:type] if args.key?(:type)
  @vex_assessment = args[:vex_assessment] if args.key?(:vex_assessment)
end