Class: Google::Apis::ContaineranalysisV1::VulnerabilityOccurrencesSummary
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1::VulnerabilityOccurrencesSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1/classes.rb,
lib/google/apis/containeranalysis_v1/representations.rb,
lib/google/apis/containeranalysis_v1/representations.rb
Overview
A summary of how many vulnerability occurrences there are per resource and severity type.
Instance Attribute Summary collapse
-
#counts ⇒ Array<Google::Apis::ContaineranalysisV1::FixableTotalByDigest>
A listing by resource of the number of fixable and total vulnerabilities.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityOccurrencesSummary
constructor
A new instance of VulnerabilityOccurrencesSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityOccurrencesSummary
Returns a new instance of VulnerabilityOccurrencesSummary.
7644 7645 7646 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7644 def initialize(**args) update!(**args) end |
Instance Attribute Details
#counts ⇒ Array<Google::Apis::ContaineranalysisV1::FixableTotalByDigest>
A listing by resource of the number of fixable and total vulnerabilities.
Corresponds to the JSON property counts
7635 7636 7637 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7635 def counts @counts end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable regions. Populated for requests from the global
region when return_partial_success is set. Format: projects/[PROJECT_ID]/
locations/[LOCATION]
Corresponds to the JSON property unreachable
7642 7643 7644 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7642 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7649 7650 7651 7652 |
# File 'lib/google/apis/containeranalysis_v1/classes.rb', line 7649 def update!(**args) @counts = args[:counts] if args.key?(:counts) @unreachable = args[:unreachable] if args.key?(:unreachable) end |